@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodeassignment.h"
+#include <ccode/valaccodeassignment.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodenode.h>
@@ -38,12 +38,13 @@ enum  {
 	VALA_CCODE_ASSIGNMENT_RIGHT
 };
 static void vala_ccode_assignment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
+static void vala_ccode_assignment_set_left (ValaCCodeAssignment* self, ValaCCodeExpression* value);
+static void vala_ccode_assignment_set_right (ValaCCodeAssignment* self, ValaCCodeExpression* value);
 static gpointer vala_ccode_assignment_parent_class = NULL;
 static void vala_ccode_assignment_dispose (GObject * obj);
 
 
-ValaCCodeAssignment* vala_ccode_assignment_new (ValaCCodeExpression* l, ValaCCodeExpression* r, ValaCCodeAssignmentOperator op)
-{
+ValaCCodeAssignment* vala_ccode_assignment_new (ValaCCodeExpression* l, ValaCCodeExpression* r, ValaCCodeAssignmentOperator op) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeAssignment * self;
@@ -64,11 +65,10 @@ ValaCCodeAssignment* vala_ccode_assignment_new (ValaCCodeExpression* l, ValaCCod
 }
 
 
-static void vala_ccode_assignment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_assignment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeAssignment * self;
-	self = ((ValaCCodeAssignment*) base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	self = VALA_CCODE_ASSIGNMENT (base);
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	if (vala_ccode_assignment_get_left (self) != NULL) {
 		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_assignment_get_left (self)), writer);
 	}
@@ -119,58 +119,51 @@ static void vala_ccode_assignment_real_write (ValaCCodeNode* base, ValaCCodeWrit
 }
 
 
-ValaCCodeExpression* vala_ccode_assignment_get_left (ValaCCodeAssignment* self)
-{
+ValaCCodeExpression* vala_ccode_assignment_get_left (ValaCCodeAssignment* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_ASSIGNMENT (self), NULL);
 	return self->priv->_left;
 }
 
 
-void vala_ccode_assignment_set_left (ValaCCodeAssignment* self, ValaCCodeExpression* value)
-{
-	ValaCCodeExpression* __temp2;
-	ValaCCodeExpression* __temp1;
+static void vala_ccode_assignment_set_left (ValaCCodeAssignment* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_ASSIGNMENT (self));
-	__temp2 = NULL;
-	__temp1 = NULL;
-	self->priv->_left = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL))), __temp2);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_left = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL))), _tmp2);
 }
 
 
-ValaCCodeAssignmentOperator vala_ccode_assignment_get_operator (ValaCCodeAssignment* self)
-{
+ValaCCodeAssignmentOperator vala_ccode_assignment_get_operator (ValaCCodeAssignment* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_ASSIGNMENT (self), 0);
 	return self->priv->_operator;
 }
 
 
-void vala_ccode_assignment_set_operator (ValaCCodeAssignment* self, ValaCCodeAssignmentOperator value)
-{
+void vala_ccode_assignment_set_operator (ValaCCodeAssignment* self, ValaCCodeAssignmentOperator value) {
 	g_return_if_fail (VALA_IS_CCODE_ASSIGNMENT (self));
 	self->priv->_operator = value;
 }
 
 
-ValaCCodeExpression* vala_ccode_assignment_get_right (ValaCCodeAssignment* self)
-{
+ValaCCodeExpression* vala_ccode_assignment_get_right (ValaCCodeAssignment* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_ASSIGNMENT (self), NULL);
 	return self->priv->_right;
 }
 
 
-void vala_ccode_assignment_set_right (ValaCCodeAssignment* self, ValaCCodeExpression* value)
-{
-	ValaCCodeExpression* __temp6;
-	ValaCCodeExpression* __temp5;
+static void vala_ccode_assignment_set_right (ValaCCodeAssignment* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_ASSIGNMENT (self));
-	__temp6 = NULL;
-	__temp5 = NULL;
-	self->priv->_right = (__temp6 = (__temp5 = value, (__temp5 == NULL ? NULL : g_object_ref (__temp5))), (self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL))), __temp6);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_right = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL))), _tmp2);
 }
 
 
-static void vala_ccode_assignment_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_assignment_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeAssignment * self;
 	self = VALA_CCODE_ASSIGNMENT (object);
 	switch (property_id) {
@@ -183,12 +176,14 @@ static void vala_ccode_assignment_get_property (GObject * object, guint property
 		case VALA_CCODE_ASSIGNMENT_RIGHT:
 		g_value_set_object (value, vala_ccode_assignment_get_right (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_ccode_assignment_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_assignment_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeAssignment * self;
 	self = VALA_CCODE_ASSIGNMENT (object);
 	switch (property_id) {
@@ -201,46 +196,41 @@ static void vala_ccode_assignment_set_property (GObject * object, guint property
 		case VALA_CCODE_ASSIGNMENT_RIGHT:
 		vala_ccode_assignment_set_right (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_ccode_assignment_class_init (ValaCCodeAssignmentClass * klass)
-{
+static void vala_ccode_assignment_class_init (ValaCCodeAssignmentClass * klass) {
 	vala_ccode_assignment_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeAssignmentPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_assignment_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_assignment_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_assignment_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_assignment_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ASSIGNMENT_LEFT, g_param_spec_object ("left", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ASSIGNMENT_OPERATOR, g_param_spec_int ("operator", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ASSIGNMENT_RIGHT, g_param_spec_object ("right", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ASSIGNMENT_LEFT, g_param_spec_object ("left", "left", "left", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ASSIGNMENT_OPERATOR, g_param_spec_int ("operator", "operator", "operator", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ASSIGNMENT_RIGHT, g_param_spec_object ("right", "right", "right", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 
-static void vala_ccode_assignment_init (ValaCCodeAssignment * self)
-{
+static void vala_ccode_assignment_init (ValaCCodeAssignment * self) {
 	self->priv = VALA_CCODE_ASSIGNMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_assignment_dispose (GObject * obj)
-{
+static void vala_ccode_assignment_dispose (GObject * obj) {
 	ValaCCodeAssignment * self;
-	ValaCCodeAssignmentClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_ASSIGNMENT (obj);
 	(self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL)));
 	(self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL)));
-	klass = VALA_CCODE_ASSIGNMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_ASSIGNMENT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_assignment_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_assignment_get_type (void)
-{
+GType vala_ccode_assignment_get_type (void) {
 	static GType vala_ccode_assignment_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_assignment_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeAssignmentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_assignment_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeAssignment), 0, (GInstanceInitFunc) vala_ccode_assignment_init };
