@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodebinaryexpression.h"
+#include <ccode/valaccodebinaryexpression.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodenode.h>
@@ -42,13 +42,12 @@ static gpointer vala_ccode_binary_expression_parent_class = NULL;
 static void vala_ccode_binary_expression_dispose (GObject * obj);
 
 
-ValaCCodeBinaryExpression* vala_ccode_binary_expression_new (ValaCCodeBinaryOperator op, ValaCCodeExpression* l, ValaCCodeExpression* r)
-{
+ValaCCodeBinaryExpression* vala_ccode_binary_expression_new (ValaCCodeBinaryOperator op, ValaCCodeExpression* l, ValaCCodeExpression* r) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeBinaryExpression * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (l), NULL);
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (r), NULL);
+	g_return_val_if_fail (l == NULL || VALA_IS_CCODE_EXPRESSION (l), NULL);
+	g_return_val_if_fail (r == NULL || VALA_IS_CCODE_EXPRESSION (r), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	(__params_it->name = "left", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, l), __params_it++);
@@ -64,11 +63,10 @@ ValaCCodeBinaryExpression* vala_ccode_binary_expression_new (ValaCCodeBinaryOper
 }
 
 
-static void vala_ccode_binary_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_binary_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeBinaryExpression * self;
-	self = ((ValaCCodeBinaryExpression*) base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	self = VALA_CCODE_BINARY_EXPRESSION (base);
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	if (vala_ccode_binary_expression_get_left (self) != NULL) {
 		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_binary_expression_get_left (self)), writer);
 	}
@@ -151,54 +149,51 @@ static void vala_ccode_binary_expression_real_write (ValaCCodeNode* base, ValaCC
 }
 
 
-ValaCCodeBinaryOperator vala_ccode_binary_expression_get_operator (ValaCCodeBinaryExpression* self)
-{
+ValaCCodeBinaryOperator vala_ccode_binary_expression_get_operator (ValaCCodeBinaryExpression* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_BINARY_EXPRESSION (self), 0);
 	return self->priv->_operator;
 }
 
 
-void vala_ccode_binary_expression_set_operator (ValaCCodeBinaryExpression* self, ValaCCodeBinaryOperator value)
-{
+void vala_ccode_binary_expression_set_operator (ValaCCodeBinaryExpression* self, ValaCCodeBinaryOperator value) {
 	g_return_if_fail (VALA_IS_CCODE_BINARY_EXPRESSION (self));
 	self->priv->_operator = value;
 }
 
 
-ValaCCodeExpression* vala_ccode_binary_expression_get_left (ValaCCodeBinaryExpression* self)
-{
+ValaCCodeExpression* vala_ccode_binary_expression_get_left (ValaCCodeBinaryExpression* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_BINARY_EXPRESSION (self), NULL);
 	return self->priv->_left;
 }
 
 
-void vala_ccode_binary_expression_set_left (ValaCCodeBinaryExpression* self, ValaCCodeExpression* value)
-{
+void vala_ccode_binary_expression_set_left (ValaCCodeBinaryExpression* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_BINARY_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_left = (_tmp1 = g_object_ref (value), (self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL))), _tmp1);
+	self->priv->_left = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL))), _tmp2);
 }
 
 
-ValaCCodeExpression* vala_ccode_binary_expression_get_right (ValaCCodeBinaryExpression* self)
-{
+ValaCCodeExpression* vala_ccode_binary_expression_get_right (ValaCCodeBinaryExpression* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_BINARY_EXPRESSION (self), NULL);
 	return self->priv->_right;
 }
 
 
-void vala_ccode_binary_expression_set_right (ValaCCodeBinaryExpression* self, ValaCCodeExpression* value)
-{
+void vala_ccode_binary_expression_set_right (ValaCCodeBinaryExpression* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_BINARY_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_right = (_tmp1 = g_object_ref (value), (self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL))), _tmp1);
+	self->priv->_right = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL))), _tmp2);
 }
 
 
-static void vala_ccode_binary_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_binary_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeBinaryExpression * self;
 	self = VALA_CCODE_BINARY_EXPRESSION (object);
 	switch (property_id) {
@@ -218,8 +213,7 @@ static void vala_ccode_binary_expression_get_property (GObject * object, guint p
 }
 
 
-static void vala_ccode_binary_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_binary_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeBinaryExpression * self;
 	self = VALA_CCODE_BINARY_EXPRESSION (object);
 	switch (property_id) {
@@ -239,42 +233,34 @@ static void vala_ccode_binary_expression_set_property (GObject * object, guint p
 }
 
 
-static void vala_ccode_binary_expression_class_init (ValaCCodeBinaryExpressionClass * klass)
-{
+static void vala_ccode_binary_expression_class_init (ValaCCodeBinaryExpressionClass * klass) {
 	vala_ccode_binary_expression_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeBinaryExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_binary_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_binary_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_binary_expression_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_binary_expression_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_BINARY_EXPRESSION_OPERATOR, g_param_spec_int ("operator", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_BINARY_EXPRESSION_LEFT, g_param_spec_object ("left", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_BINARY_EXPRESSION_RIGHT, g_param_spec_object ("right", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_BINARY_EXPRESSION_OPERATOR, g_param_spec_int ("operator", "operator", "operator", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_BINARY_EXPRESSION_LEFT, g_param_spec_object ("left", "left", "left", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_BINARY_EXPRESSION_RIGHT, g_param_spec_object ("right", "right", "right", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_ccode_binary_expression_init (ValaCCodeBinaryExpression * self)
-{
+static void vala_ccode_binary_expression_init (ValaCCodeBinaryExpression * self) {
 	self->priv = VALA_CCODE_BINARY_EXPRESSION_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_binary_expression_dispose (GObject * obj)
-{
+static void vala_ccode_binary_expression_dispose (GObject * obj) {
 	ValaCCodeBinaryExpression * self;
-	ValaCCodeBinaryExpressionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_BINARY_EXPRESSION (obj);
 	(self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL)));
 	(self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL)));
-	klass = VALA_CCODE_BINARY_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_CCODE_BINARY_EXPRESSION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_binary_expression_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_binary_expression_get_type (void)
-{
+GType vala_ccode_binary_expression_get_type (void) {
 	static GType vala_ccode_binary_expression_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_binary_expression_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeBinaryExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_binary_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeBinaryExpression), 0, (GInstanceInitFunc) vala_ccode_binary_expression_init };
