@@ -24,6 +24,11 @@
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/collection.h>
+#include <ccode/valaccodereturnstatement.h>
+#include <ccode/valaccodegotostatement.h>
+#include <ccode/valaccodecontinuestatement.h>
+#include <ccode/valaccodebreakstatement.h>
+#include <ccode/valaccodelabel.h>
 
 struct _ValaCCodeBlockPrivate {
 	gboolean _suppress_newline;
@@ -44,7 +49,7 @@ static void vala_ccode_block_dispose (GObject * obj);
  */
 void vala_ccode_block_prepend_statement (ValaCCodeBlock* self, ValaCCodeNode* statement) {
 	g_return_if_fail (VALA_IS_CCODE_BLOCK (self));
-	g_return_if_fail (VALA_IS_CCODE_NODE (statement));
+	g_return_if_fail (statement == NULL || VALA_IS_CCODE_NODE (statement));
 	gee_list_insert (self->priv->statements, 0, statement);
 }
 
@@ -54,7 +59,7 @@ void vala_ccode_block_prepend_statement (ValaCCodeBlock* self, ValaCCodeNode* st
  */
 void vala_ccode_block_add_statement (ValaCCodeBlock* self, ValaCCodeNode* statement) {
 	g_return_if_fail (VALA_IS_CCODE_BLOCK (self));
-	g_return_if_fail (VALA_IS_CCODE_NODE (statement));
+	g_return_if_fail (statement == NULL || VALA_IS_CCODE_NODE (statement));
 	/* allow generic nodes to include comments */
 	gee_collection_add (GEE_COLLECTION (self->priv->statements), statement);
 }
@@ -62,8 +67,9 @@ void vala_ccode_block_add_statement (ValaCCodeBlock* self, ValaCCodeNode* statem
 
 static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeBlock * self;
+	ValaCCodeNode* last_statement;
 	self = VALA_CCODE_BLOCK (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_begin_block (writer);
 	{
 		GeeList* statement_collection;
@@ -80,6 +86,34 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 		}
 		(statement_it == NULL ? NULL : (statement_it = (g_object_unref (statement_it), NULL)));
 	}
+	/* compute last reachable statement*/
+	last_statement = NULL;
+	{
+		GeeList* statement_collection;
+		GeeIterator* statement_it;
+		statement_collection = self->priv->statements;
+		statement_it = gee_iterable_iterator (GEE_ITERABLE (statement_collection));
+		while (gee_iterator_next (statement_it)) {
+			ValaCCodeNode* statement;
+			statement = gee_iterator_get (statement_it);
+			{
+				if (VALA_IS_CCODE_RETURN_STATEMENT (statement) || VALA_IS_CCODE_GOTO_STATEMENT (statement) || VALA_IS_CCODE_CONTINUE_STATEMENT (statement) || VALA_IS_CCODE_BREAK_STATEMENT (statement)) {
+					ValaCCodeNode* _tmp1;
+					ValaCCodeNode* _tmp0;
+					_tmp1 = NULL;
+					_tmp0 = NULL;
+					last_statement = (_tmp1 = (_tmp0 = statement, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (last_statement == NULL ? NULL : (last_statement = (g_object_unref (last_statement), NULL))), _tmp1);
+				}
+				if (VALA_IS_CCODE_LABEL (statement)) {
+					ValaCCodeNode* _tmp2;
+					_tmp2 = NULL;
+					last_statement = (_tmp2 = NULL, (last_statement == NULL ? NULL : (last_statement = (g_object_unref (last_statement), NULL))), _tmp2);
+				}
+				(statement == NULL ? NULL : (statement = (g_object_unref (statement), NULL)));
+			}
+		}
+		(statement_it == NULL ? NULL : (statement_it = (g_object_unref (statement_it), NULL)));
+	}
 	{
 		GeeList* statement_collection;
 		GeeIterator* statement_it;
@@ -90,6 +124,11 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 			statement = gee_iterator_get (statement_it);
 			{
 				vala_ccode_node_write (statement, writer);
+				/* only output reachable code*/
+				if (statement == last_statement) {
+					(statement == NULL ? NULL : (statement = (g_object_unref (statement), NULL)));
+					break;
+				}
 				(statement == NULL ? NULL : (statement = (g_object_unref (statement), NULL)));
 			}
 		}
@@ -99,6 +138,7 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 	if (!vala_ccode_block_get_suppress_newline (self)) {
 		vala_ccode_writer_write_newline (writer);
 	}
+	(last_statement == NULL ? NULL : (last_statement = (g_object_unref (last_statement), NULL)));
 }
 
 
@@ -165,7 +205,7 @@ static void vala_ccode_block_class_init (ValaCCodeBlockClass * klass) {
 
 static void vala_ccode_block_init (ValaCCodeBlock * self) {
 	self->priv = VALA_CCODE_BLOCK_GET_PRIVATE (self);
-	self->priv->statements = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
