@@ -42,8 +42,7 @@ ValaCCodeCastExpression* vala_ccode_cast_expression_new (ValaCCodeExpression* ex
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeCastExpression * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
-	g_return_val_if_fail (type != NULL, NULL);
+	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
@@ -61,7 +60,7 @@ ValaCCodeCastExpression* vala_ccode_cast_expression_new (ValaCCodeExpression* ex
 static void vala_ccode_cast_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeCastExpression * self;
 	self = VALA_CCODE_CAST_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "((");
 	vala_ccode_writer_write_string (writer, vala_ccode_cast_expression_get_type_name (self));
 	vala_ccode_writer_write_string (writer, ") ");
@@ -77,10 +76,12 @@ ValaCCodeExpression* vala_ccode_cast_expression_get_inner (ValaCCodeCastExpressi
 
 
 void vala_ccode_cast_expression_set_inner (ValaCCodeCastExpression* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_CAST_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 }
 
 
@@ -91,10 +92,12 @@ char* vala_ccode_cast_expression_get_type_name (ValaCCodeCastExpression* self) {
 
 
 void vala_ccode_cast_expression_set_type_name (ValaCCodeCastExpression* self, const char* value) {
-	char* _tmp1;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_CAST_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_type_name = (_tmp1 = g_strdup (value), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), _tmp1);
+	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), _tmp2);
 }
 
 
