@@ -47,7 +47,7 @@ static void vala_ccode_comma_expression_dispose (GObject * obj);
  */
 void vala_ccode_comma_expression_append_expression (ValaCCodeCommaExpression* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_COMMA_EXPRESSION (self));
-	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
+	g_return_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr));
 	gee_collection_add (GEE_COLLECTION (self->priv->inner), expr);
 }
 
@@ -56,7 +56,7 @@ static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCo
 	ValaCCodeCommaExpression * self;
 	gboolean first;
 	self = VALA_CCODE_COMMA_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	first = TRUE;
 	vala_ccode_writer_write_string (writer, "(");
 	{
