@@ -46,11 +46,11 @@ typedef struct _ValaCCodeCommaExpressionPrivate ValaCCodeCommaExpressionPrivate;
  * Represents a comma separated expression list in the C code.
  */
 struct _ValaCCodeCommaExpression {
-	ValaCCodeExpression parent;
+	ValaCCodeExpression parent_instance;
 	ValaCCodeCommaExpressionPrivate * priv;
 };
 struct _ValaCCodeCommaExpressionClass {
-	ValaCCodeExpressionClass parent;
+	ValaCCodeExpressionClass parent_class;
 };
 
 void vala_ccode_comma_expression_append_expression (ValaCCodeCommaExpression* self, ValaCCodeExpression* expr);
