@@ -46,11 +46,11 @@ typedef struct _ValaCCodeConditionalExpressionPrivate ValaCCodeConditionalExpres
  * Represents a conditional expression in C code.
  */
 struct _ValaCCodeConditionalExpression {
-	ValaCCodeExpression parent;
+	ValaCCodeExpression parent_instance;
 	ValaCCodeConditionalExpressionPrivate * priv;
 };
 struct _ValaCCodeConditionalExpressionClass {
-	ValaCCodeExpressionClass parent;
+	ValaCCodeExpressionClass parent_class;
 };
 
 ValaCCodeConditionalExpression* vala_ccode_conditional_expression_new (ValaCCodeExpression* cond, ValaCCodeExpression* true_expr, ValaCCodeExpression* false_expr);
