@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,6 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodeconstant.h"
 #include <ccode/valaccodeconstant.h>
 
 struct _ValaCCodeConstantPrivate {
@@ -36,12 +35,10 @@ static gpointer vala_ccode_constant_parent_class = NULL;
 static void vala_ccode_constant_dispose (GObject * obj);
 
 
-ValaCCodeConstant* vala_ccode_constant_new (const char* _name)
-{
+ValaCCodeConstant* vala_ccode_constant_new (const char* _name) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeConstant * self;
-	g_return_val_if_fail (_name != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
@@ -55,33 +52,31 @@ ValaCCodeConstant* vala_ccode_constant_new (const char* _name)
 }
 
 
-static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeConstant * self;
-	self = ((ValaCCodeConstant*) base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	self = VALA_CCODE_CONSTANT (base);
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, vala_ccode_constant_get_name (self));
 }
 
 
-char* vala_ccode_constant_get_name (ValaCCodeConstant* self)
-{
+char* vala_ccode_constant_get_name (ValaCCodeConstant* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_CONSTANT (self), NULL);
 	return self->priv->_name;
 }
 
 
-void vala_ccode_constant_set_name (ValaCCodeConstant* self, const char* value)
-{
-	char* _tmp1;
+void vala_ccode_constant_set_name (ValaCCodeConstant* self, const char* value) {
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_CONSTANT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_name = (_tmp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp1);
+	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
 }
 
 
-static void vala_ccode_constant_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_constant_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeConstant * self;
 	self = VALA_CCODE_CONSTANT (object);
 	switch (property_id) {
@@ -95,8 +90,7 @@ static void vala_ccode_constant_get_property (GObject * object, guint property_i
 }
 
 
-static void vala_ccode_constant_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_constant_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeConstant * self;
 	self = VALA_CCODE_CONSTANT (object);
 	switch (property_id) {
@@ -110,39 +104,31 @@ static void vala_ccode_constant_set_property (GObject * object, guint property_i
 }
 
 
-static void vala_ccode_constant_class_init (ValaCCodeConstantClass * klass)
-{
+static void vala_ccode_constant_class_init (ValaCCodeConstantClass * klass) {
 	vala_ccode_constant_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeConstantPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_constant_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_constant_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_constant_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_constant_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_CONSTANT_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_CONSTANT_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_ccode_constant_init (ValaCCodeConstant * self)
-{
+static void vala_ccode_constant_init (ValaCCodeConstant * self) {
 	self->priv = VALA_CCODE_CONSTANT_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_constant_dispose (GObject * obj)
-{
+static void vala_ccode_constant_dispose (GObject * obj) {
 	ValaCCodeConstant * self;
-	ValaCCodeConstantClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_CONSTANT (obj);
 	(self->priv->_name = (g_free (self->priv->_name), NULL));
-	klass = VALA_CCODE_CONSTANT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_CONSTANT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_constant_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_constant_get_type (void)
-{
+GType vala_ccode_constant_get_type (void) {
 	static GType vala_ccode_constant_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_constant_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeConstantClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_constant_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeConstant), 0, (GInstanceInitFunc) vala_ccode_constant_init };
