@@ -1,11 +1,11 @@
 /* valaccodecontinuestatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODECONTINUESTATEMENT_H__
-#define __VALACCODECONTINUESTATEMENT_H__
+#ifndef __CCODE_VALACCODECONTINUESTATEMENT_H__
+#define __CCODE_VALACCODECONTINUESTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -46,14 +46,15 @@ typedef struct _ValaCCodeContinueStatementPrivate ValaCCodeContinueStatementPriv
  * Represents a continue statement in the C code.
  */
 struct _ValaCCodeContinueStatement {
-	ValaCCodeStatement parent;
+	ValaCCodeStatement parent_instance;
 	ValaCCodeContinueStatementPrivate * priv;
 };
 struct _ValaCCodeContinueStatementClass {
-	ValaCCodeStatementClass parent;
+	ValaCCodeStatementClass parent_class;
 };
 
-GType vala_ccode_continue_statement_get_type ();
+ValaCCodeContinueStatement* vala_ccode_continue_statement_new (void);
+GType vala_ccode_continue_statement_get_type (void);
 
 G_END_DECLS
 
