@@ -50,11 +50,11 @@ typedef struct _ValaCCodeDeclarationPrivate ValaCCodeDeclarationPrivate;
  * Represents a local variable declaration in the C code.
  */
 struct _ValaCCodeDeclaration {
-	ValaCCodeStatement parent;
+	ValaCCodeStatement parent_instance;
 	ValaCCodeDeclarationPrivate * priv;
 };
 struct _ValaCCodeDeclarationClass {
-	ValaCCodeStatementClass parent;
+	ValaCCodeStatementClass parent_class;
 };
 
 ValaCCodeDeclaration* vala_ccode_declaration_new (const char* type_name);
