@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,9 +20,10 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodeemptystatement.h"
+#include <ccode/valaccodeemptystatement.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ccode/valaccodelinedirective.h>
 
 enum  {
 	VALA_CCODE_EMPTY_STATEMENT_DUMMY_PROPERTY
@@ -31,31 +32,37 @@ static void vala_ccode_empty_statement_real_write (ValaCCodeNode* base, ValaCCod
 static gpointer vala_ccode_empty_statement_parent_class = NULL;
 
 
-static void vala_ccode_empty_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_empty_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeEmptyStatement * self;
-	self = ((ValaCCodeEmptyStatement*) base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_writer_write_indent (writer);
+	self = VALA_CCODE_EMPTY_STATEMENT (base);
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, ";");
 	vala_ccode_writer_write_newline (writer);
 }
 
 
-static void vala_ccode_empty_statement_class_init (ValaCCodeEmptyStatementClass * klass)
-{
+/**
+ * Represents an empty statement in the C code.
+ */
+ValaCCodeEmptyStatement* vala_ccode_empty_statement_new (void) {
+	ValaCCodeEmptyStatement * self;
+	self = g_object_newv (VALA_TYPE_CCODE_EMPTY_STATEMENT, 0, NULL);
+	return self;
+}
+
+
+static void vala_ccode_empty_statement_class_init (ValaCCodeEmptyStatementClass * klass) {
 	vala_ccode_empty_statement_parent_class = g_type_class_peek_parent (klass);
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_empty_statement_real_write;
 }
 
 
-static void vala_ccode_empty_statement_init (ValaCCodeEmptyStatement * self)
-{
+static void vala_ccode_empty_statement_init (ValaCCodeEmptyStatement * self) {
 }
 
 
-GType vala_ccode_empty_statement_get_type (void)
-{
+GType vala_ccode_empty_statement_get_type (void) {
 	static GType vala_ccode_empty_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_empty_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeEmptyStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_empty_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeEmptyStatement), 0, (GInstanceInitFunc) vala_ccode_empty_statement_init };
