@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEEMPTYSTATEMENT_H__
-#define __VALACCODEEMPTYSTATEMENT_H__
+#ifndef __CCODE_VALACCODEEMPTYSTATEMENT_H__
+#define __CCODE_VALACCODEEMPTYSTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -46,13 +46,14 @@ typedef struct _ValaCCodeEmptyStatementPrivate ValaCCodeEmptyStatementPrivate;
  * Represents an empty statement in the C code.
  */
 struct _ValaCCodeEmptyStatement {
-	ValaCCodeStatement parent;
+	ValaCCodeStatement parent_instance;
 	ValaCCodeEmptyStatementPrivate * priv;
 };
 struct _ValaCCodeEmptyStatementClass {
-	ValaCCodeStatementClass parent;
+	ValaCCodeStatementClass parent_class;
 };
 
+ValaCCodeEmptyStatement* vala_ccode_empty_statement_new (void);
 GType vala_ccode_empty_statement_get_type (void);
 
 G_END_DECLS
