@@ -54,17 +54,10 @@ ValaCCodeEnum* vala_ccode_enum_new (const char* name) {
  * @param name  enum value name
  * @param value optional numerical value
  */
-void vala_ccode_enum_add_value (ValaCCodeEnum* self, const char* name, const char* value) {
+void vala_ccode_enum_add_value (ValaCCodeEnum* self, ValaCCodeEnumValue* value) {
 	g_return_if_fail (VALA_IS_CCODE_ENUM (self));
-	g_return_if_fail (name != NULL);
-	if (value == NULL) {
-		gee_collection_add (GEE_COLLECTION (self->priv->values), name);
-	} else {
-		char* _tmp0;
-		_tmp0 = NULL;
-		gee_collection_add (GEE_COLLECTION (self->priv->values), (_tmp0 = g_strdup_printf ("%s = %s", name, value)));
-		(_tmp0 = (g_free (_tmp0), NULL));
-	}
+	g_return_if_fail (value == NULL || VALA_IS_CCODE_ENUM_VALUE (value));
+	gee_collection_add (GEE_COLLECTION (self->priv->values), value);
 }
 
 
@@ -72,7 +65,7 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 	ValaCCodeEnum * self;
 	gboolean first;
 	self = VALA_CCODE_ENUM (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	if (vala_ccode_enum_get_name (self) != NULL) {
 		vala_ccode_writer_write_string (writer, "typedef ");
 	}
@@ -85,7 +78,7 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 		value_collection = self->priv->values;
 		value_it = gee_iterable_iterator (GEE_ITERABLE (value_collection));
 		while (gee_iterator_next (value_it)) {
-			char* value;
+			ValaCCodeEnumValue* value;
 			value = gee_iterator_get (value_it);
 			{
 				if (!first) {
@@ -93,9 +86,9 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 					vala_ccode_writer_write_newline (writer);
 				}
 				vala_ccode_writer_write_indent (writer, NULL);
-				vala_ccode_writer_write_string (writer, value);
+				vala_ccode_node_write (VALA_CCODE_NODE (value), writer);
 				first = FALSE;
-				(value = (g_free (value), NULL));
+				(value == NULL ? NULL : (value = (g_object_unref (value), NULL)));
 			}
 		}
 		(value_it == NULL ? NULL : (value_it = (g_object_unref (value_it), NULL)));
@@ -170,7 +163,7 @@ static void vala_ccode_enum_class_init (ValaCCodeEnumClass * klass) {
 
 static void vala_ccode_enum_init (ValaCCodeEnum * self) {
 	self->priv = VALA_CCODE_ENUM_GET_PRIVATE (self);
-	self->priv->values = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_direct_equal));
+	self->priv->values = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_ENUM_VALUE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
