@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEEXPRESSION_H__
-#define __VALACCODEEXPRESSION_H__
+#ifndef __CCODE_VALACCODEEXPRESSION_H__
+#define __CCODE_VALACCODEEXPRESSION_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -45,11 +45,11 @@ typedef struct _ValaCCodeExpressionPrivate ValaCCodeExpressionPrivate;
  * Represents an expression node in the C code tree.
  */
 struct _ValaCCodeExpression {
-	ValaCCodeNode parent;
+	ValaCCodeNode parent_instance;
 	ValaCCodeExpressionPrivate * priv;
 };
 struct _ValaCCodeExpressionClass {
-	ValaCCodeNodeClass parent;
+	ValaCCodeNodeClass parent_class;
 };
 
 GType vala_ccode_expression_get_type (void);
