@@ -1,11 +1,11 @@
 /* valaccodeexpressionstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,11 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodeexpressionstatement.h"
+#include <ccode/valaccodeexpressionstatement.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ccode/valaccodeexpressionstatement.h>
 #include <ccode/valaccodenode.h>
+#include <ccode/valaccodelinedirective.h>
 
 struct _ValaCCodeExpressionStatementPrivate {
 	ValaCCodeExpression* _expression;
@@ -39,8 +39,7 @@ static gpointer vala_ccode_expression_statement_parent_class = NULL;
 static void vala_ccode_expression_statement_dispose (GObject * obj);
 
 
-ValaCCodeExpressionStatement* vala_ccode_expression_statement_new (ValaCCodeExpression* expr)
-{
+ValaCCodeExpressionStatement* vala_ccode_expression_statement_new (ValaCCodeExpression* expr) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeExpressionStatement * self;
@@ -58,12 +57,11 @@ ValaCCodeExpressionStatement* vala_ccode_expression_statement_new (ValaCCodeExpr
 }
 
 
-static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeExpressionStatement * self;
-	self = ((ValaCCodeExpressionStatement*) base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_writer_write_indent (writer);
+	self = VALA_CCODE_EXPRESSION_STATEMENT (base);
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	if (vala_ccode_expression_statement_get_expression (self) != NULL) {
 		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_expression_statement_get_expression (self)), writer);
 	}
@@ -72,79 +70,75 @@ static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, Val
 }
 
 
-ValaCCodeExpression* vala_ccode_expression_statement_get_expression (ValaCCodeExpressionStatement* self)
-{
+ValaCCodeExpression* vala_ccode_expression_statement_get_expression (ValaCCodeExpressionStatement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION_STATEMENT (self), NULL);
 	return self->priv->_expression;
 }
 
 
-void vala_ccode_expression_statement_set_expression (ValaCCodeExpressionStatement* self, ValaCCodeExpression* value)
-{
-	ValaCCodeExpression* __temp1;
+void vala_ccode_expression_statement_set_expression (ValaCCodeExpressionStatement* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_EXPRESSION_STATEMENT (self));
-	__temp1 = NULL;
-	self->priv->_expression = (__temp1 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), __temp1);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp2);
 }
 
 
-static void vala_ccode_expression_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_expression_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeExpressionStatement * self;
 	self = VALA_CCODE_EXPRESSION_STATEMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_EXPRESSION_STATEMENT_EXPRESSION:
 		g_value_set_object (value, vala_ccode_expression_statement_get_expression (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_ccode_expression_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_expression_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeExpressionStatement * self;
 	self = VALA_CCODE_EXPRESSION_STATEMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_EXPRESSION_STATEMENT_EXPRESSION:
 		vala_ccode_expression_statement_set_expression (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_ccode_expression_statement_class_init (ValaCCodeExpressionStatementClass * klass)
-{
+static void vala_ccode_expression_statement_class_init (ValaCCodeExpressionStatementClass * klass) {
 	vala_ccode_expression_statement_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeExpressionStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_expression_statement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_expression_statement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_expression_statement_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_expression_statement_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_EXPRESSION_STATEMENT_EXPRESSION, g_param_spec_object ("expression", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_EXPRESSION_STATEMENT_EXPRESSION, g_param_spec_object ("expression", "expression", "expression", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_ccode_expression_statement_init (ValaCCodeExpressionStatement * self)
-{
+static void vala_ccode_expression_statement_init (ValaCCodeExpressionStatement * self) {
 	self->priv = VALA_CCODE_EXPRESSION_STATEMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_expression_statement_dispose (GObject * obj)
-{
+static void vala_ccode_expression_statement_dispose (GObject * obj) {
 	ValaCCodeExpressionStatement * self;
-	ValaCCodeExpressionStatementClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_EXPRESSION_STATEMENT (obj);
 	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
-	klass = VALA_CCODE_EXPRESSION_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_EXPRESSION_STATEMENT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_expression_statement_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_expression_statement_get_type (void)
-{
+GType vala_ccode_expression_statement_get_type (void) {
 	static GType vala_ccode_expression_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_expression_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeExpressionStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_expression_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeExpressionStatement), 0, (GInstanceInitFunc) vala_ccode_expression_statement_init };
