@@ -48,7 +48,7 @@ static void vala_ccode_for_statement_dispose (GObject * obj);
 
 ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* condition, ValaCCodeStatement* body) {
 	ValaCCodeForStatement * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (condition), NULL);
+	g_return_val_if_fail (condition == NULL || VALA_IS_CCODE_EXPRESSION (condition), NULL);
 	g_return_val_if_fail (body == NULL || VALA_IS_CCODE_STATEMENT (body), NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_FOR_STATEMENT, 0, NULL);
 	vala_ccode_for_statement_set_condition (self, condition);
@@ -64,7 +64,7 @@ ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* condit
  */
 void vala_ccode_for_statement_add_initializer (ValaCCodeForStatement* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_FOR_STATEMENT (self));
-	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
+	g_return_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr));
 	gee_collection_add (GEE_COLLECTION (self->priv->initializer), expr);
 }
 
@@ -76,7 +76,7 @@ void vala_ccode_for_statement_add_initializer (ValaCCodeForStatement* self, Vala
  */
 void vala_ccode_for_statement_add_iterator (ValaCCodeForStatement* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_FOR_STATEMENT (self));
-	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
+	g_return_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr));
 	gee_collection_add (GEE_COLLECTION (self->priv->iterator), expr);
 }
 
@@ -85,7 +85,7 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 	ValaCCodeForStatement * self;
 	gboolean first;
 	self = VALA_CCODE_FOR_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	first = FALSE;
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "for (");
@@ -152,10 +152,12 @@ ValaCCodeExpression* vala_ccode_for_statement_get_condition (ValaCCodeForStateme
 
 
 void vala_ccode_for_statement_set_condition (ValaCCodeForStatement* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_FOR_STATEMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_condition = (_tmp1 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp1);
+	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp2);
 }
 
 
@@ -223,8 +225,8 @@ static void vala_ccode_for_statement_class_init (ValaCCodeForStatementClass * kl
 
 static void vala_ccode_for_statement_init (ValaCCodeForStatement * self) {
 	self->priv = VALA_CCODE_FOR_STATEMENT_GET_PRIVATE (self);
-	self->priv->initializer = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
-	self->priv->iterator = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->initializer = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->iterator = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
