@@ -46,7 +46,7 @@ static void vala_ccode_fragment_dispose (GObject * obj);
  */
 void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node) {
 	g_return_if_fail (VALA_IS_CCODE_FRAGMENT (self));
-	g_return_if_fail (VALA_IS_CCODE_NODE (node));
+	g_return_if_fail (node == NULL || VALA_IS_CCODE_NODE (node));
 	gee_collection_add (GEE_COLLECTION (self->priv->children), node);
 }
 
@@ -58,14 +58,14 @@ void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node) {
  */
 GeeCollection* vala_ccode_fragment_get_children (ValaCCodeFragment* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FRAGMENT (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->children)));
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->children)));
 }
 
 
 static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFragment * self;
 	self = VALA_CCODE_FRAGMENT (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	{
 		GeeList* node_collection;
 		GeeIterator* node_it;
@@ -87,7 +87,7 @@ static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter
 static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFragment * self;
 	self = VALA_CCODE_FRAGMENT (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	{
 		GeeList* node_collection;
 		GeeIterator* node_it;
@@ -109,7 +109,7 @@ static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, Val
 static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFragment * self;
 	self = VALA_CCODE_FRAGMENT (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	{
 		GeeList* node_collection;
 		GeeIterator* node_it;
@@ -150,7 +150,7 @@ static void vala_ccode_fragment_class_init (ValaCCodeFragmentClass * klass) {
 
 static void vala_ccode_fragment_init (ValaCCodeFragment * self) {
 	self->priv = VALA_CCODE_FRAGMENT_GET_PRIVATE (self);
-	self->priv->children = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->children = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
