@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,18 +19,18 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
-#include "valaccodefunctioncall.h"
+#include <ccode/valaccodefunctioncall.h>
+#include <gee/arraylist.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ccode/valaccodefunctioncall.h>
 #include <ccode/valaccodenode.h>
 
 struct _ValaCCodeFunctionCallPrivate {
 	ValaCCodeExpression* _call;
-	GList* arguments;
+	GeeList* arguments;
 };
 #define VALA_CCODE_FUNCTION_CALL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FUNCTION_CALL, ValaCCodeFunctionCallPrivate))
 enum  {
@@ -42,16 +42,11 @@ static gpointer vala_ccode_function_call_parent_class = NULL;
 static void vala_ccode_function_call_dispose (GObject * obj);
 
 
-ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call)
-{
-	GParameter * __params;
-	GParameter * __params_it;
+ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call) {
 	ValaCCodeFunctionCall * self;
 	g_return_val_if_fail (call == NULL || VALA_IS_CCODE_EXPRESSION (call), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	(__params_it->name = "call", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, call), __params_it++);
-	self = g_object_newv (VALA_TYPE_CCODE_FUNCTION_CALL, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_FUNCTION_CALL, 0, NULL);
+	vala_ccode_function_call_set_call (self, call);
 	return self;
 }
 
@@ -61,11 +56,10 @@ ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call)
  *
  * @param expr a C code expression
  */
-void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCodeExpression* expr)
-{
+void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self));
-	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
-	self->priv->arguments = g_list_append (self->priv->arguments, g_object_ref (expr));
+	g_return_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr));
+	gee_collection_add (GEE_COLLECTION (self->priv->arguments), expr);
 }
 
 
@@ -74,30 +68,28 @@ void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCo
  *
  * @return list of arguments
  */
-GList* vala_ccode_function_call_get_arguments (ValaCCodeFunctionCall* self)
-{
+GeeList* vala_ccode_function_call_get_arguments (ValaCCodeFunctionCall* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self), NULL);
-	return g_list_copy (self->priv->arguments);
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, self->priv->arguments));
 }
 
 
-static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFunctionCall * self;
 	gboolean first;
 	self = VALA_CCODE_FUNCTION_CALL (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_function_call_get_call (self)), writer);
 	vala_ccode_writer_write_string (writer, " (");
 	first = TRUE;
 	{
-		GList* __temp1;
-		GList* expr_it;
-		__temp1 = NULL;
-		__temp1 = self->priv->arguments;
-		for (expr_it = __temp1; expr_it != NULL; expr_it = expr_it->next) {
+		GeeList* expr_collection;
+		GeeIterator* expr_it;
+		expr_collection = self->priv->arguments;
+		expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
+		while (gee_iterator_next (expr_it)) {
 			ValaCCodeExpression* expr;
-			expr = expr_it->data;
+			expr = gee_iterator_get (expr_it);
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -107,89 +99,86 @@ static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeW
 				if (expr != NULL) {
 					vala_ccode_node_write (VALA_CCODE_NODE (expr), writer);
 				}
+				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
 			}
 		}
+		(expr_it == NULL ? NULL : (expr_it = (g_object_unref (expr_it), NULL)));
 	}
 	vala_ccode_writer_write_string (writer, ")");
 }
 
 
-ValaCCodeExpression* vala_ccode_function_call_get_call (ValaCCodeFunctionCall* self)
-{
+ValaCCodeExpression* vala_ccode_function_call_get_call (ValaCCodeFunctionCall* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self), NULL);
 	return self->priv->_call;
 }
 
 
-void vala_ccode_function_call_set_call (ValaCCodeFunctionCall* self, ValaCCodeExpression* value)
-{
-	ValaCCodeExpression* __temp4;
-	ValaCCodeExpression* __temp3;
+void vala_ccode_function_call_set_call (ValaCCodeFunctionCall* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self));
-	__temp4 = NULL;
-	__temp3 = NULL;
-	self->priv->_call = (__temp4 = (__temp3 = value, (__temp3 == NULL ? NULL : g_object_ref (__temp3))), (self->priv->_call == NULL ? NULL : (self->priv->_call = (g_object_unref (self->priv->_call), NULL))), __temp4);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_call = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_call == NULL ? NULL : (self->priv->_call = (g_object_unref (self->priv->_call), NULL))), _tmp2);
 }
 
 
-static void vala_ccode_function_call_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_function_call_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeFunctionCall * self;
 	self = VALA_CCODE_FUNCTION_CALL (object);
 	switch (property_id) {
 		case VALA_CCODE_FUNCTION_CALL_CALL:
 		g_value_set_object (value, vala_ccode_function_call_get_call (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_ccode_function_call_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_function_call_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeFunctionCall * self;
 	self = VALA_CCODE_FUNCTION_CALL (object);
 	switch (property_id) {
 		case VALA_CCODE_FUNCTION_CALL_CALL:
 		vala_ccode_function_call_set_call (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_ccode_function_call_class_init (ValaCCodeFunctionCallClass * klass)
-{
+static void vala_ccode_function_call_class_init (ValaCCodeFunctionCallClass * klass) {
 	vala_ccode_function_call_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeFunctionCallPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_function_call_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_function_call_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_function_call_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_function_call_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_CALL_CALL, g_param_spec_object ("call", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_CALL_CALL, g_param_spec_object ("call", "call", "call", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_ccode_function_call_init (ValaCCodeFunctionCall * self)
-{
+static void vala_ccode_function_call_init (ValaCCodeFunctionCall * self) {
 	self->priv = VALA_CCODE_FUNCTION_CALL_GET_PRIVATE (self);
+	self->priv->arguments = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_function_call_dispose (GObject * obj)
-{
+static void vala_ccode_function_call_dispose (GObject * obj) {
 	ValaCCodeFunctionCall * self;
-	ValaCCodeFunctionCallClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_FUNCTION_CALL (obj);
 	(self->priv->_call == NULL ? NULL : (self->priv->_call = (g_object_unref (self->priv->_call), NULL)));
-	(self->priv->arguments == NULL ? NULL : (self->priv->arguments = (g_list_foreach (self->priv->arguments, (GFunc) g_object_unref, NULL), g_list_free (self->priv->arguments), NULL)));
-	klass = VALA_CCODE_FUNCTION_CALL_CLASS (g_type_class_peek (VALA_TYPE_CCODE_FUNCTION_CALL));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	(self->priv->arguments == NULL ? NULL : (self->priv->arguments = (g_object_unref (self->priv->arguments), NULL)));
+	G_OBJECT_CLASS (vala_ccode_function_call_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_function_call_get_type ()
-{
+GType vala_ccode_function_call_get_type (void) {
 	static GType vala_ccode_function_call_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_function_call_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionCallClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_call_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunctionCall), 0, (GInstanceInitFunc) vala_ccode_function_call_init };
