@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,12 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEFUNCTIONCALL_H__
-#define __VALACCODEFUNCTIONCALL_H__
+#ifndef __CCODE_VALACCODEFUNCTIONCALL_H__
+#define __CCODE_VALACCODEFUNCTIONCALL_H__
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/list.h>
 #include <ccode/valaccodeexpression.h>
 #include <ccode/valaccodewriter.h>
 
@@ -46,19 +47,19 @@ typedef struct _ValaCCodeFunctionCallPrivate ValaCCodeFunctionCallPrivate;
  * Represents a function call in the C code.
  */
 struct _ValaCCodeFunctionCall {
-	ValaCCodeExpression parent;
+	ValaCCodeExpression parent_instance;
 	ValaCCodeFunctionCallPrivate * priv;
 };
 struct _ValaCCodeFunctionCallClass {
-	ValaCCodeExpressionClass parent;
+	ValaCCodeExpressionClass parent_class;
 };
 
 ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call);
 void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCodeExpression* expr);
-GList* vala_ccode_function_call_get_arguments (ValaCCodeFunctionCall* self);
+GeeList* vala_ccode_function_call_get_arguments (ValaCCodeFunctionCall* self);
 ValaCCodeExpression* vala_ccode_function_call_get_call (ValaCCodeFunctionCall* self);
 void vala_ccode_function_call_set_call (ValaCCodeFunctionCall* self, ValaCCodeExpression* value);
-GType vala_ccode_function_call_get_type ();
+GType vala_ccode_function_call_get_type (void);
 
 G_END_DECLS
 
