@@ -49,11 +49,11 @@ typedef struct _ValaCCodeFunctionDeclaratorPrivate ValaCCodeFunctionDeclaratorPr
  * Represents a function pointer declarator in the C code.
  */
 struct _ValaCCodeFunctionDeclarator {
-	ValaCCodeDeclarator parent;
+	ValaCCodeDeclarator parent_instance;
 	ValaCCodeFunctionDeclaratorPrivate * priv;
 };
 struct _ValaCCodeFunctionDeclaratorClass {
-	ValaCCodeDeclaratorClass parent;
+	ValaCCodeDeclaratorClass parent_class;
 };
 
 ValaCCodeFunctionDeclarator* vala_ccode_function_declarator_new (const char* name);
