@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEGOTOSTATEMENT_H__
-#define __VALACCODEGOTOSTATEMENT_H__
+#ifndef __CCODE_VALACCODEGOTOSTATEMENT_H__
+#define __CCODE_VALACCODEGOTOSTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -48,11 +48,11 @@ typedef struct _ValaCCodeGotoStatementPrivate ValaCCodeGotoStatementPrivate;
  * Represents a goto statement in the C code.
  */
 struct _ValaCCodeGotoStatement {
-	ValaCCodeStatement parent;
+	ValaCCodeStatement parent_instance;
 	ValaCCodeGotoStatementPrivate * priv;
 };
 struct _ValaCCodeGotoStatementClass {
-	ValaCCodeStatementClass parent;
+	ValaCCodeStatementClass parent_class;
 };
 
 ValaCCodeGotoStatement* vala_ccode_goto_statement_new (const char* name);
