@@ -39,7 +39,6 @@ ValaCCodeIdentifier* vala_ccode_identifier_new (const char* _name) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeIdentifier * self;
-	g_return_val_if_fail (_name != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
@@ -56,7 +55,7 @@ ValaCCodeIdentifier* vala_ccode_identifier_new (const char* _name) {
 static void vala_ccode_identifier_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeIdentifier * self;
 	self = VALA_CCODE_IDENTIFIER (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, vala_ccode_identifier_get_name (self));
 }
 
@@ -68,10 +67,12 @@ char* vala_ccode_identifier_get_name (ValaCCodeIdentifier* self) {
 
 
 void vala_ccode_identifier_set_name (ValaCCodeIdentifier* self, const char* value) {
-	char* _tmp1;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_IDENTIFIER (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_name = (_tmp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp1);
+	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
 }
 
 
