@@ -1,11 +1,11 @@
 /* valaccodeifstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,11 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodeifstatement.h"
+#include <ccode/valaccodeifstatement.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ccode/valaccodeifstatement.h>
 #include <ccode/valaccodenode.h>
+#include <ccode/valaccodelinedirective.h>
 #include <ccode/valaccodeblock.h>
 
 struct _ValaCCodeIfStatementPrivate {
@@ -46,13 +46,12 @@ static gpointer vala_ccode_if_statement_parent_class = NULL;
 static void vala_ccode_if_statement_dispose (GObject * obj);
 
 
-ValaCCodeIfStatement* vala_ccode_if_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* true_stmt, ValaCCodeStatement* false_stmt)
-{
+ValaCCodeIfStatement* vala_ccode_if_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* true_stmt, ValaCCodeStatement* false_stmt) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeIfStatement * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
-	g_return_val_if_fail (VALA_IS_CCODE_STATEMENT (true_stmt), NULL);
+	g_return_val_if_fail (cond == NULL || VALA_IS_CCODE_EXPRESSION (cond), NULL);
+	g_return_val_if_fail (true_stmt == NULL || VALA_IS_CCODE_STATEMENT (true_stmt), NULL);
 	g_return_val_if_fail (false_stmt == NULL || VALA_IS_CCODE_STATEMENT (false_stmt), NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
@@ -69,13 +68,12 @@ ValaCCodeIfStatement* vala_ccode_if_statement_new (ValaCCodeExpression* cond, Va
 }
 
 
-static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeIfStatement * self;
-	self = ((ValaCCodeIfStatement*) base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	self = VALA_CCODE_IF_STATEMENT (base);
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	if (!vala_ccode_if_statement_get_else_if (self)) {
-		vala_ccode_writer_write_indent (writer);
+		vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	} else {
 		vala_ccode_writer_write_string (writer, " ");
 	}
@@ -96,7 +94,7 @@ static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWr
 	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_if_statement_get_true_statement (self)), writer);
 	if (vala_ccode_if_statement_get_false_statement (self) != NULL) {
 		if (vala_ccode_writer_get_bol (writer)) {
-			vala_ccode_writer_write_indent (writer);
+			vala_ccode_writer_write_indent (writer, NULL);
 			vala_ccode_writer_write_string (writer, "else");
 		} else {
 			vala_ccode_writer_write_string (writer, " else");
@@ -115,47 +113,45 @@ static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWr
 }
 
 
-ValaCCodeExpression* vala_ccode_if_statement_get_condition (ValaCCodeIfStatement* self)
-{
+ValaCCodeExpression* vala_ccode_if_statement_get_condition (ValaCCodeIfStatement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_IF_STATEMENT (self), NULL);
 	return self->priv->_condition;
 }
 
 
-void vala_ccode_if_statement_set_condition (ValaCCodeIfStatement* self, ValaCCodeExpression* value)
-{
+void vala_ccode_if_statement_set_condition (ValaCCodeIfStatement* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_IF_STATEMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_condition = (_tmp1 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp1);
+	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp2);
 }
 
 
-ValaCCodeStatement* vala_ccode_if_statement_get_true_statement (ValaCCodeIfStatement* self)
-{
+ValaCCodeStatement* vala_ccode_if_statement_get_true_statement (ValaCCodeIfStatement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_IF_STATEMENT (self), NULL);
 	return self->priv->_true_statement;
 }
 
 
-void vala_ccode_if_statement_set_true_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value)
-{
+void vala_ccode_if_statement_set_true_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value) {
+	ValaCCodeStatement* _tmp2;
 	ValaCCodeStatement* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_IF_STATEMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_true_statement = (_tmp1 = g_object_ref (value), (self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (g_object_unref (self->priv->_true_statement), NULL))), _tmp1);
+	self->priv->_true_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (g_object_unref (self->priv->_true_statement), NULL))), _tmp2);
 }
 
 
-ValaCCodeStatement* vala_ccode_if_statement_get_false_statement (ValaCCodeIfStatement* self)
-{
+ValaCCodeStatement* vala_ccode_if_statement_get_false_statement (ValaCCodeIfStatement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_IF_STATEMENT (self), NULL);
 	return self->priv->_false_statement;
 }
 
 
-void vala_ccode_if_statement_set_false_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value)
-{
+void vala_ccode_if_statement_set_false_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value) {
 	ValaCCodeStatement* _tmp2;
 	ValaCCodeStatement* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_IF_STATEMENT (self));
@@ -165,22 +161,19 @@ void vala_ccode_if_statement_set_false_statement (ValaCCodeIfStatement* self, Va
 }
 
 
-gboolean vala_ccode_if_statement_get_else_if (ValaCCodeIfStatement* self)
-{
+gboolean vala_ccode_if_statement_get_else_if (ValaCCodeIfStatement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_IF_STATEMENT (self), FALSE);
 	return self->priv->_else_if;
 }
 
 
-void vala_ccode_if_statement_set_else_if (ValaCCodeIfStatement* self, gboolean value)
-{
+void vala_ccode_if_statement_set_else_if (ValaCCodeIfStatement* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CCODE_IF_STATEMENT (self));
 	self->priv->_else_if = value;
 }
 
 
-static void vala_ccode_if_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_if_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeIfStatement * self;
 	self = VALA_CCODE_IF_STATEMENT (object);
 	switch (property_id) {
@@ -203,8 +196,7 @@ static void vala_ccode_if_statement_get_property (GObject * object, guint proper
 }
 
 
-static void vala_ccode_if_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_if_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeIfStatement * self;
 	self = VALA_CCODE_IF_STATEMENT (object);
 	switch (property_id) {
@@ -227,44 +219,36 @@ static void vala_ccode_if_statement_set_property (GObject * object, guint proper
 }
 
 
-static void vala_ccode_if_statement_class_init (ValaCCodeIfStatementClass * klass)
-{
+static void vala_ccode_if_statement_class_init (ValaCCodeIfStatementClass * klass) {
 	vala_ccode_if_statement_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeIfStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_if_statement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_if_statement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_if_statement_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_if_statement_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_IF_STATEMENT_CONDITION, g_param_spec_object ("condition", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_IF_STATEMENT_TRUE_STATEMENT, g_param_spec_object ("true-statement", "foo", "bar", VALA_TYPE_CCODE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_IF_STATEMENT_FALSE_STATEMENT, g_param_spec_object ("false-statement", "foo", "bar", VALA_TYPE_CCODE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_IF_STATEMENT_ELSE_IF, g_param_spec_boolean ("else-if", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_IF_STATEMENT_CONDITION, g_param_spec_object ("condition", "condition", "condition", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_IF_STATEMENT_TRUE_STATEMENT, g_param_spec_object ("true-statement", "true-statement", "true-statement", VALA_TYPE_CCODE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_IF_STATEMENT_FALSE_STATEMENT, g_param_spec_object ("false-statement", "false-statement", "false-statement", VALA_TYPE_CCODE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_IF_STATEMENT_ELSE_IF, g_param_spec_boolean ("else-if", "else-if", "else-if", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_ccode_if_statement_init (ValaCCodeIfStatement * self)
-{
+static void vala_ccode_if_statement_init (ValaCCodeIfStatement * self) {
 	self->priv = VALA_CCODE_IF_STATEMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_if_statement_dispose (GObject * obj)
-{
+static void vala_ccode_if_statement_dispose (GObject * obj) {
 	ValaCCodeIfStatement * self;
-	ValaCCodeIfStatementClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_IF_STATEMENT (obj);
 	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
 	(self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (g_object_unref (self->priv->_true_statement), NULL)));
 	(self->priv->_false_statement == NULL ? NULL : (self->priv->_false_statement = (g_object_unref (self->priv->_false_statement), NULL)));
-	klass = VALA_CCODE_IF_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_IF_STATEMENT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_if_statement_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_if_statement_get_type (void)
-{
+GType vala_ccode_if_statement_get_type (void) {
 	static GType vala_ccode_if_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_if_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeIfStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_if_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeIfStatement), 0, (GInstanceInitFunc) vala_ccode_if_statement_init };
