@@ -48,11 +48,11 @@ typedef struct _ValaCCodeMemberAccessPrivate ValaCCodeMemberAccessPrivate;
  * Represents an access to a struct member in the C code.
  */
 struct _ValaCCodeMemberAccess {
-	ValaCCodeExpression parent;
+	ValaCCodeExpression parent_instance;
 	ValaCCodeMemberAccessPrivate * priv;
 };
 struct _ValaCCodeMemberAccessClass {
-	ValaCCodeExpressionClass parent;
+	ValaCCodeExpressionClass parent_class;
 };
 
 ValaCCodeMemberAccess* vala_ccode_member_access_new (ValaCCodeExpression* container, const char* member, gboolean pointer);
