@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,17 +20,18 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODENODE_H__
-#define __VALACCODENODE_H__
+#ifndef __CCODE_VALACCODENODE_H__
+#define __CCODE_VALACCODENODE_H__
 
 #include <glib.h>
 #include <glib-object.h>
-#include <ccode/valaccodewriter.h>
 
 G_BEGIN_DECLS
 
 typedef struct _ValaCCodeNode ValaCCodeNode;
 typedef struct _ValaCCodeNodeClass ValaCCodeNodeClass;
+typedef struct _ValaCCodeWriter ValaCCodeWriter;
+typedef struct _ValaCCodeWriterClass ValaCCodeWriterClass;
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
@@ -47,11 +48,11 @@ typedef struct _ValaCCodeNodePrivate ValaCCodeNodePrivate;
  * Represents a node in the C code tree.
  */
 struct _ValaCCodeNode {
-	GObject parent;
+	GObject parent_instance;
 	ValaCCodeNodePrivate * priv;
 };
 struct _ValaCCodeNodeClass {
-	GObjectClass parent;
+	GObjectClass parent_class;
 	void (*write) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 	void (*write_declaration) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
