@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,13 +19,10 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
-#include "valaccodeparenthesizedexpression.h"
+#include <ccode/valaccodeparenthesizedexpression.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ccode/valaccodeparenthesizedexpression.h>
 #include <ccode/valaccodenode.h>
 
 struct _ValaCCodeParenthesizedExpressionPrivate {
@@ -41,104 +38,103 @@ static gpointer vala_ccode_parenthesized_expression_parent_class = NULL;
 static void vala_ccode_parenthesized_expression_dispose (GObject * obj);
 
 
-ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_new (ValaCCodeExpression* expr)
-{
+ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_new (ValaCCodeExpression* expr) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeParenthesizedExpression * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
+	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
 	self = g_object_newv (VALA_TYPE_CCODE_PARENTHESIZED_EXPRESSION, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
 
-static void vala_ccode_parenthesized_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_parenthesized_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeParenthesizedExpression * self;
 	self = VALA_CCODE_PARENTHESIZED_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "(");
 	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_parenthesized_expression_get_inner (self)), writer);
 	vala_ccode_writer_write_string (writer, ")");
 }
 
 
-ValaCCodeExpression* vala_ccode_parenthesized_expression_get_inner (ValaCCodeParenthesizedExpression* self)
-{
+ValaCCodeExpression* vala_ccode_parenthesized_expression_get_inner (ValaCCodeParenthesizedExpression* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (self), NULL);
 	return self->priv->_inner;
 }
 
 
-void vala_ccode_parenthesized_expression_set_inner (ValaCCodeParenthesizedExpression* self, ValaCCodeExpression* value)
-{
-	ValaCCodeExpression* __temp1;
+void vala_ccode_parenthesized_expression_set_inner (ValaCCodeParenthesizedExpression* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (self));
-	__temp1 = NULL;
-	self->priv->_inner = (__temp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp1);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 }
 
 
-static void vala_ccode_parenthesized_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_parenthesized_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeParenthesizedExpression * self;
 	self = VALA_CCODE_PARENTHESIZED_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_CCODE_PARENTHESIZED_EXPRESSION_INNER:
 		g_value_set_object (value, vala_ccode_parenthesized_expression_get_inner (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_ccode_parenthesized_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_parenthesized_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeParenthesizedExpression * self;
 	self = VALA_CCODE_PARENTHESIZED_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_CCODE_PARENTHESIZED_EXPRESSION_INNER:
 		vala_ccode_parenthesized_expression_set_inner (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_ccode_parenthesized_expression_class_init (ValaCCodeParenthesizedExpressionClass * klass)
-{
+static void vala_ccode_parenthesized_expression_class_init (ValaCCodeParenthesizedExpressionClass * klass) {
 	vala_ccode_parenthesized_expression_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeParenthesizedExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_parenthesized_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_parenthesized_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_parenthesized_expression_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_parenthesized_expression_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_PARENTHESIZED_EXPRESSION_INNER, g_param_spec_object ("inner", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_PARENTHESIZED_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_ccode_parenthesized_expression_init (ValaCCodeParenthesizedExpression * self)
-{
+static void vala_ccode_parenthesized_expression_init (ValaCCodeParenthesizedExpression * self) {
 	self->priv = VALA_CCODE_PARENTHESIZED_EXPRESSION_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_parenthesized_expression_dispose (GObject * obj)
-{
+static void vala_ccode_parenthesized_expression_dispose (GObject * obj) {
 	ValaCCodeParenthesizedExpression * self;
-	ValaCCodeParenthesizedExpressionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_PARENTHESIZED_EXPRESSION (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	klass = VALA_CCODE_PARENTHESIZED_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_CCODE_PARENTHESIZED_EXPRESSION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_parenthesized_expression_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_parenthesized_expression_get_type ()
-{
+GType vala_ccode_parenthesized_expression_get_type (void) {
 	static GType vala_ccode_parenthesized_expression_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_parenthesized_expression_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeParenthesizedExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_parenthesized_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeParenthesizedExpression), 0, (GInstanceInitFunc) vala_ccode_parenthesized_expression_init };
