@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEPARENTHESIZEDEXPRESSION_H__
-#define __VALACCODEPARENTHESIZEDEXPRESSION_H__
+#ifndef __CCODE_VALACCODEPARENTHESIZEDEXPRESSION_H__
+#define __CCODE_VALACCODEPARENTHESIZEDEXPRESSION_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -46,11 +46,11 @@ typedef struct _ValaCCodeParenthesizedExpressionPrivate ValaCCodeParenthesizedEx
  * Represents a parenthesized expression in the C code.
  */
 struct _ValaCCodeParenthesizedExpression {
-	ValaCCodeExpression parent;
+	ValaCCodeExpression parent_instance;
 	ValaCCodeParenthesizedExpressionPrivate * priv;
 };
 struct _ValaCCodeParenthesizedExpressionClass {
-	ValaCCodeExpressionClass parent;
+	ValaCCodeExpressionClass parent_class;
 };
 
 ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_new (ValaCCodeExpression* expr);
