@@ -1,11 +1,11 @@
 /* valaccodereturnstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,11 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodereturnstatement.h"
+#include <ccode/valaccodereturnstatement.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ccode/valaccodereturnstatement.h>
 #include <ccode/valaccodenode.h>
+#include <ccode/valaccodelinedirective.h>
 
 struct _ValaCCodeReturnStatementPrivate {
 	ValaCCodeExpression* _return_expression;
@@ -39,8 +39,7 @@ static gpointer vala_ccode_return_statement_parent_class = NULL;
 static void vala_ccode_return_statement_dispose (GObject * obj);
 
 
-ValaCCodeReturnStatement* vala_ccode_return_statement_new (ValaCCodeExpression* expr)
-{
+ValaCCodeReturnStatement* vala_ccode_return_statement_new (ValaCCodeExpression* expr) {
 	ValaCCodeReturnStatement * self;
 	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_RETURN_STATEMENT, 0, NULL);
@@ -49,12 +48,11 @@ ValaCCodeReturnStatement* vala_ccode_return_statement_new (ValaCCodeExpression*
 }
 
 
-static void vala_ccode_return_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_return_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeReturnStatement * self;
-	self = ((ValaCCodeReturnStatement*) base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_writer_write_indent (writer);
+	self = VALA_CCODE_RETURN_STATEMENT (base);
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "return");
 	if (vala_ccode_return_statement_get_return_expression (self) != NULL) {
 		vala_ccode_writer_write_string (writer, " ");
@@ -65,15 +63,13 @@ static void vala_ccode_return_statement_real_write (ValaCCodeNode* base, ValaCCo
 }
 
 
-ValaCCodeExpression* vala_ccode_return_statement_get_return_expression (ValaCCodeReturnStatement* self)
-{
+ValaCCodeExpression* vala_ccode_return_statement_get_return_expression (ValaCCodeReturnStatement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_RETURN_STATEMENT (self), NULL);
 	return self->priv->_return_expression;
 }
 
 
-void vala_ccode_return_statement_set_return_expression (ValaCCodeReturnStatement* self, ValaCCodeExpression* value)
-{
+void vala_ccode_return_statement_set_return_expression (ValaCCodeReturnStatement* self, ValaCCodeExpression* value) {
 	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_RETURN_STATEMENT (self));
@@ -83,8 +79,7 @@ void vala_ccode_return_statement_set_return_expression (ValaCCodeReturnStatement
 }
 
 
-static void vala_ccode_return_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_return_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeReturnStatement * self;
 	self = VALA_CCODE_RETURN_STATEMENT (object);
 	switch (property_id) {
@@ -98,8 +93,7 @@ static void vala_ccode_return_statement_get_property (GObject * object, guint pr
 }
 
 
-static void vala_ccode_return_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_return_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeReturnStatement * self;
 	self = VALA_CCODE_RETURN_STATEMENT (object);
 	switch (property_id) {
@@ -113,39 +107,31 @@ static void vala_ccode_return_statement_set_property (GObject * object, guint pr
 }
 
 
-static void vala_ccode_return_statement_class_init (ValaCCodeReturnStatementClass * klass)
-{
+static void vala_ccode_return_statement_class_init (ValaCCodeReturnStatementClass * klass) {
 	vala_ccode_return_statement_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeReturnStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_return_statement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_return_statement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_return_statement_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_return_statement_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_RETURN_STATEMENT_RETURN_EXPRESSION, g_param_spec_object ("return-expression", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_RETURN_STATEMENT_RETURN_EXPRESSION, g_param_spec_object ("return-expression", "return-expression", "return-expression", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_ccode_return_statement_init (ValaCCodeReturnStatement * self)
-{
+static void vala_ccode_return_statement_init (ValaCCodeReturnStatement * self) {
 	self->priv = VALA_CCODE_RETURN_STATEMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_return_statement_dispose (GObject * obj)
-{
+static void vala_ccode_return_statement_dispose (GObject * obj) {
 	ValaCCodeReturnStatement * self;
-	ValaCCodeReturnStatementClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_RETURN_STATEMENT (obj);
 	(self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (g_object_unref (self->priv->_return_expression), NULL)));
-	klass = VALA_CCODE_RETURN_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_RETURN_STATEMENT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_return_statement_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_return_statement_get_type (void)
-{
+GType vala_ccode_return_statement_get_type (void) {
 	static GType vala_ccode_return_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_return_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeReturnStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_return_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeReturnStatement), 0, (GInstanceInitFunc) vala_ccode_return_statement_init };
