@@ -43,7 +43,6 @@ static void vala_ccode_struct_dispose (GObject * obj);
 
 ValaCCodeStruct* vala_ccode_struct_new (const char* name) {
 	ValaCCodeStruct * self;
-	g_return_val_if_fail (name != NULL, NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_STRUCT, 0, NULL);
 	vala_ccode_struct_set_name (self, name);
 	return self;
@@ -57,7 +56,7 @@ ValaCCodeStruct* vala_ccode_struct_new (const char* name) {
  */
 void vala_ccode_struct_add_declaration (ValaCCodeStruct* self, ValaCCodeDeclaration* decl) {
 	g_return_if_fail (VALA_IS_CCODE_STRUCT (self));
-	g_return_if_fail (VALA_IS_CCODE_DECLARATION (decl));
+	g_return_if_fail (decl == NULL || VALA_IS_CCODE_DECLARATION (decl));
 	gee_collection_add (GEE_COLLECTION (self->priv->declarations), decl);
 }
 
@@ -72,8 +71,6 @@ void vala_ccode_struct_add_field (ValaCCodeStruct* self, const char* type_name,
 	ValaCCodeDeclaration* decl;
 	ValaCCodeVariableDeclarator* _tmp0;
 	g_return_if_fail (VALA_IS_CCODE_STRUCT (self));
-	g_return_if_fail (type_name != NULL);
-	g_return_if_fail (name != NULL);
 	decl = vala_ccode_declaration_new (type_name);
 	_tmp0 = NULL;
 	vala_ccode_declaration_add_declarator (decl, VALA_CCODE_DECLARATOR ((_tmp0 = vala_ccode_variable_declarator_new (name))));
@@ -86,7 +83,7 @@ void vala_ccode_struct_add_field (ValaCCodeStruct* self, const char* type_name,
 static void vala_ccode_struct_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeStruct * self;
 	self = VALA_CCODE_STRUCT (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "struct ");
 	vala_ccode_writer_write_string (writer, vala_ccode_struct_get_name (self));
 	vala_ccode_writer_write_begin_block (writer);
@@ -118,10 +115,12 @@ char* vala_ccode_struct_get_name (ValaCCodeStruct* self) {
 
 
 void vala_ccode_struct_set_name (ValaCCodeStruct* self, const char* value) {
-	char* _tmp1;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_STRUCT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_name = (_tmp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp1);
+	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
 }
 
 
@@ -166,7 +165,7 @@ static void vala_ccode_struct_class_init (ValaCCodeStructClass * klass) {
 
 static void vala_ccode_struct_init (ValaCCodeStruct * self) {
 	self->priv = VALA_CCODE_STRUCT_GET_PRIVATE (self);
-	self->priv->declarations = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->declarations = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_DECLARATION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
