@@ -49,11 +49,11 @@ typedef struct _ValaCCodeStructPrivate ValaCCodeStructPrivate;
  * Represents a struct declaration in the C code.
  */
 struct _ValaCCodeStruct {
-	ValaCCodeNode parent;
+	ValaCCodeNode parent_instance;
 	ValaCCodeStructPrivate * priv;
 };
 struct _ValaCCodeStructClass {
-	ValaCCodeNodeClass parent;
+	ValaCCodeNodeClass parent_class;
 };
 
 ValaCCodeStruct* vala_ccode_struct_new (const char* name);
