@@ -46,7 +46,7 @@ static void vala_ccode_switch_statement_dispose (GObject * obj);
 
 ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expression) {
 	ValaCCodeSwitchStatement * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expression), NULL);
+	g_return_val_if_fail (expression == NULL || VALA_IS_CCODE_EXPRESSION (expression), NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_SWITCH_STATEMENT, 0, NULL);
 	vala_ccode_switch_statement_set_expression (self, expression);
 	return self;
@@ -60,7 +60,7 @@ ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression*
  */
 void vala_ccode_switch_statement_add_case (ValaCCodeSwitchStatement* self, ValaCCodeCaseStatement* case_stmt) {
 	g_return_if_fail (VALA_IS_CCODE_SWITCH_STATEMENT (self));
-	g_return_if_fail (VALA_IS_CCODE_CASE_STATEMENT (case_stmt));
+	g_return_if_fail (case_stmt == NULL || VALA_IS_CCODE_CASE_STATEMENT (case_stmt));
 	gee_collection_add (GEE_COLLECTION (self->priv->case_statements), case_stmt);
 }
 
@@ -72,7 +72,7 @@ void vala_ccode_switch_statement_add_case (ValaCCodeSwitchStatement* self, ValaC
  */
 void vala_ccode_switch_statement_add_default_statement (ValaCCodeSwitchStatement* self, ValaCCodeStatement* stmt) {
 	g_return_if_fail (VALA_IS_CCODE_SWITCH_STATEMENT (self));
-	g_return_if_fail (VALA_IS_CCODE_STATEMENT (stmt));
+	g_return_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt));
 	gee_collection_add (GEE_COLLECTION (self->priv->default_statements), stmt);
 }
 
@@ -80,7 +80,7 @@ void vala_ccode_switch_statement_add_default_statement (ValaCCodeSwitchStatement
 static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeSwitchStatement * self;
 	self = VALA_CCODE_SWITCH_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "switch (");
 	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_switch_statement_get_expression (self)), writer);
@@ -132,10 +132,12 @@ ValaCCodeExpression* vala_ccode_switch_statement_get_expression (ValaCCodeSwitch
 
 
 void vala_ccode_switch_statement_set_expression (ValaCCodeSwitchStatement* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_SWITCH_STATEMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_expression = (_tmp1 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp1);
+	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp2);
 }
 
 
@@ -180,8 +182,8 @@ static void vala_ccode_switch_statement_class_init (ValaCCodeSwitchStatementClas
 
 static void vala_ccode_switch_statement_init (ValaCCodeSwitchStatement * self) {
 	self->priv = VALA_CCODE_SWITCH_STATEMENT_GET_PRIVATE (self);
-	self->priv->case_statements = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
-	self->priv->default_statements = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->case_statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_CASE_STATEMENT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->default_statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_STATEMENT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
