@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodeunaryexpression.h"
+#include <ccode/valaccodeunaryexpression.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodenode.h>
@@ -40,12 +40,11 @@ static gpointer vala_ccode_unary_expression_parent_class = NULL;
 static void vala_ccode_unary_expression_dispose (GObject * obj);
 
 
-ValaCCodeUnaryExpression* vala_ccode_unary_expression_new (ValaCCodeUnaryOperator op, ValaCCodeExpression* expr)
-{
+ValaCCodeUnaryExpression* vala_ccode_unary_expression_new (ValaCCodeUnaryOperator op, ValaCCodeExpression* expr) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeUnaryExpression * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
+	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
@@ -60,11 +59,10 @@ ValaCCodeUnaryExpression* vala_ccode_unary_expression_new (ValaCCodeUnaryOperato
 }
 
 
-static void vala_ccode_unary_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_unary_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeUnaryExpression * self;
-	self = ((ValaCCodeUnaryExpression*) base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	self = VALA_CCODE_UNARY_EXPRESSION (base);
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_PLUS) {
 		vala_ccode_writer_write_string (writer, "+");
 	} else {
@@ -107,38 +105,35 @@ static void vala_ccode_unary_expression_real_write (ValaCCodeNode* base, ValaCCo
 }
 
 
-ValaCCodeUnaryOperator vala_ccode_unary_expression_get_operator (ValaCCodeUnaryExpression* self)
-{
+ValaCCodeUnaryOperator vala_ccode_unary_expression_get_operator (ValaCCodeUnaryExpression* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_UNARY_EXPRESSION (self), 0);
 	return self->priv->_operator;
 }
 
 
-void vala_ccode_unary_expression_set_operator (ValaCCodeUnaryExpression* self, ValaCCodeUnaryOperator value)
-{
+void vala_ccode_unary_expression_set_operator (ValaCCodeUnaryExpression* self, ValaCCodeUnaryOperator value) {
 	g_return_if_fail (VALA_IS_CCODE_UNARY_EXPRESSION (self));
 	self->priv->_operator = value;
 }
 
 
-ValaCCodeExpression* vala_ccode_unary_expression_get_inner (ValaCCodeUnaryExpression* self)
-{
+ValaCCodeExpression* vala_ccode_unary_expression_get_inner (ValaCCodeUnaryExpression* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_UNARY_EXPRESSION (self), NULL);
 	return self->priv->_inner;
 }
 
 
-void vala_ccode_unary_expression_set_inner (ValaCCodeUnaryExpression* self, ValaCCodeExpression* value)
-{
+void vala_ccode_unary_expression_set_inner (ValaCCodeUnaryExpression* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_UNARY_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 }
 
 
-static void vala_ccode_unary_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_unary_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeUnaryExpression * self;
 	self = VALA_CCODE_UNARY_EXPRESSION (object);
 	switch (property_id) {
@@ -155,8 +150,7 @@ static void vala_ccode_unary_expression_get_property (GObject * object, guint pr
 }
 
 
-static void vala_ccode_unary_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_unary_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeUnaryExpression * self;
 	self = VALA_CCODE_UNARY_EXPRESSION (object);
 	switch (property_id) {
@@ -173,40 +167,32 @@ static void vala_ccode_unary_expression_set_property (GObject * object, guint pr
 }
 
 
-static void vala_ccode_unary_expression_class_init (ValaCCodeUnaryExpressionClass * klass)
-{
+static void vala_ccode_unary_expression_class_init (ValaCCodeUnaryExpressionClass * klass) {
 	vala_ccode_unary_expression_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeUnaryExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_unary_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_unary_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_unary_expression_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_unary_expression_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_UNARY_EXPRESSION_OPERATOR, g_param_spec_int ("operator", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_UNARY_EXPRESSION_INNER, g_param_spec_object ("inner", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_UNARY_EXPRESSION_OPERATOR, g_param_spec_int ("operator", "operator", "operator", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_UNARY_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_ccode_unary_expression_init (ValaCCodeUnaryExpression * self)
-{
+static void vala_ccode_unary_expression_init (ValaCCodeUnaryExpression * self) {
 	self->priv = VALA_CCODE_UNARY_EXPRESSION_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_unary_expression_dispose (GObject * obj)
-{
+static void vala_ccode_unary_expression_dispose (GObject * obj) {
 	ValaCCodeUnaryExpression * self;
-	ValaCCodeUnaryExpressionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_UNARY_EXPRESSION (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	klass = VALA_CCODE_UNARY_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_CCODE_UNARY_EXPRESSION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_unary_expression_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_unary_expression_get_type (void)
-{
+GType vala_ccode_unary_expression_get_type (void) {
 	static GType vala_ccode_unary_expression_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_unary_expression_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeUnaryExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_unary_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeUnaryExpression), 0, (GInstanceInitFunc) vala_ccode_unary_expression_init };
