@@ -1,11 +1,11 @@
 /* valaccodewhilestatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,11 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodewhilestatement.h"
+#include <ccode/valaccodewhilestatement.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ccode/valaccodewhilestatement.h>
 #include <ccode/valaccodenode.h>
+#include <ccode/valaccodelinedirective.h>
 
 struct _ValaCCodeWhileStatementPrivate {
 	ValaCCodeExpression* _condition;
@@ -41,12 +41,11 @@ static gpointer vala_ccode_while_statement_parent_class = NULL;
 static void vala_ccode_while_statement_dispose (GObject * obj);
 
 
-ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* stmt)
-{
+ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* stmt) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeWhileStatement * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
+	g_return_val_if_fail (cond == NULL || VALA_IS_CCODE_EXPRESSION (cond), NULL);
 	g_return_val_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -62,12 +61,11 @@ ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* co
 }
 
 
-static void vala_ccode_while_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_while_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeWhileStatement * self;
-	self = ((ValaCCodeWhileStatement*) base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_writer_write_indent (writer);
+	self = VALA_CCODE_WHILE_STATEMENT (base);
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "while (");
 	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_while_statement_get_condition (self)), writer);
 	vala_ccode_writer_write_string (writer, ")");
@@ -75,31 +73,29 @@ static void vala_ccode_while_statement_real_write (ValaCCodeNode* base, ValaCCod
 }
 
 
-ValaCCodeExpression* vala_ccode_while_statement_get_condition (ValaCCodeWhileStatement* self)
-{
+ValaCCodeExpression* vala_ccode_while_statement_get_condition (ValaCCodeWhileStatement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self), NULL);
 	return self->priv->_condition;
 }
 
 
-void vala_ccode_while_statement_set_condition (ValaCCodeWhileStatement* self, ValaCCodeExpression* value)
-{
+void vala_ccode_while_statement_set_condition (ValaCCodeWhileStatement* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_condition = (_tmp1 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp1);
+	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp2);
 }
 
 
-ValaCCodeStatement* vala_ccode_while_statement_get_body (ValaCCodeWhileStatement* self)
-{
+ValaCCodeStatement* vala_ccode_while_statement_get_body (ValaCCodeWhileStatement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self), NULL);
 	return self->priv->_body;
 }
 
 
-void vala_ccode_while_statement_set_body (ValaCCodeWhileStatement* self, ValaCCodeStatement* value)
-{
+void vala_ccode_while_statement_set_body (ValaCCodeWhileStatement* self, ValaCCodeStatement* value) {
 	ValaCCodeStatement* _tmp2;
 	ValaCCodeStatement* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self));
@@ -109,8 +105,7 @@ void vala_ccode_while_statement_set_body (ValaCCodeWhileStatement* self, ValaCCo
 }
 
 
-static void vala_ccode_while_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_while_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeWhileStatement * self;
 	self = VALA_CCODE_WHILE_STATEMENT (object);
 	switch (property_id) {
@@ -127,8 +122,7 @@ static void vala_ccode_while_statement_get_property (GObject * object, guint pro
 }
 
 
-static void vala_ccode_while_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_while_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeWhileStatement * self;
 	self = VALA_CCODE_WHILE_STATEMENT (object);
 	switch (property_id) {
@@ -145,41 +139,33 @@ static void vala_ccode_while_statement_set_property (GObject * object, guint pro
 }
 
 
-static void vala_ccode_while_statement_class_init (ValaCCodeWhileStatementClass * klass)
-{
+static void vala_ccode_while_statement_class_init (ValaCCodeWhileStatementClass * klass) {
 	vala_ccode_while_statement_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeWhileStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_while_statement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_while_statement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_while_statement_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_while_statement_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WHILE_STATEMENT_CONDITION, g_param_spec_object ("condition", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WHILE_STATEMENT_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_CCODE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WHILE_STATEMENT_CONDITION, g_param_spec_object ("condition", "condition", "condition", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WHILE_STATEMENT_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_CCODE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_ccode_while_statement_init (ValaCCodeWhileStatement * self)
-{
+static void vala_ccode_while_statement_init (ValaCCodeWhileStatement * self) {
 	self->priv = VALA_CCODE_WHILE_STATEMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_while_statement_dispose (GObject * obj)
-{
+static void vala_ccode_while_statement_dispose (GObject * obj) {
 	ValaCCodeWhileStatement * self;
-	ValaCCodeWhileStatementClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_WHILE_STATEMENT (obj);
 	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	klass = VALA_CCODE_WHILE_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_WHILE_STATEMENT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_while_statement_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_while_statement_get_type (void)
-{
+GType vala_ccode_while_statement_get_type (void) {
 	static GType vala_ccode_while_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_while_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeWhileStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_while_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeWhileStatement), 0, (GInstanceInitFunc) vala_ccode_while_statement_init };
