@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,12 +20,13 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodewriter.h"
+#include <ccode/valaccodewriter.h>
 #include <stdio.h>
 #include <glib/gstdio.h>
-#include <ccode/valaccodewriter.h>
+#include <ccode/valaccodelinedirective.h>
 
 struct _ValaCCodeWriterPrivate {
+	gboolean _line_directives;
 	char* _filename;
 	char* temp_filename;
 	gboolean file_exists;
@@ -37,19 +38,19 @@ struct _ValaCCodeWriterPrivate {
 enum  {
 	VALA_CCODE_WRITER_DUMMY_PROPERTY,
 	VALA_CCODE_WRITER_FILENAME,
+	VALA_CCODE_WRITER_LINE_DIRECTIVES,
 	VALA_CCODE_WRITER_BOL
 };
+static void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value);
 static gpointer vala_ccode_writer_parent_class = NULL;
 static void vala_ccode_writer_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
-ValaCCodeWriter* vala_ccode_writer_new (const char* _filename)
-{
+ValaCCodeWriter* vala_ccode_writer_new (const char* _filename) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeWriter * self;
-	g_return_val_if_fail (_filename != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	(__params_it->name = "filename", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _filename), __params_it++);
@@ -66,8 +67,7 @@ ValaCCodeWriter* vala_ccode_writer_new (const char* _filename)
 /**
  * Closes the file.
  */
-void vala_ccode_writer_close (ValaCCodeWriter* self)
-{
+void vala_ccode_writer_close (ValaCCodeWriter* self) {
 	GError * inner_error;
 	FILE* _tmp0;
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
@@ -136,16 +136,21 @@ void vala_ccode_writer_close (ValaCCodeWriter* self)
 /**
  * Writes tabs according to the current indent level.
  */
-void vala_ccode_writer_write_indent (ValaCCodeWriter* self)
-{
-	gint i;
+void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line) {
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
-	i = 0;
+	g_return_if_fail (line == NULL || VALA_IS_CCODE_LINE_DIRECTIVE (line));
+	if (vala_ccode_writer_get_line_directives (self) && line != NULL) {
+		vala_ccode_node_write (VALA_CCODE_NODE (line), self);
+	}
 	if (!vala_ccode_writer_get_bol (self)) {
 		fputc ('\n', self->priv->stream);
 	}
-	for (i = 0; i < self->priv->indent; i++) {
-		fputc ('\t', self->priv->stream);
+	{
+		gint i;
+		i = 0;
+		for (i = 0; i < self->priv->indent; i++) {
+			fputc ('\t', self->priv->stream);
+		}
 	}
 	self->priv->_bol = FALSE;
 }
@@ -156,10 +161,8 @@ void vala_ccode_writer_write_indent (ValaCCodeWriter* self)
  *
  * @param s a string
  */
-void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s)
-{
+void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s) {
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
-	g_return_if_fail (s != NULL);
 	fprintf (self->priv->stream, "%s", s);
 	self->priv->_bol = FALSE;
 }
@@ -168,8 +171,7 @@ void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s)
 /**
  * Writes a newline.
  */
-void vala_ccode_writer_write_newline (ValaCCodeWriter* self)
-{
+void vala_ccode_writer_write_newline (ValaCCodeWriter* self) {
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
 	fputc ('\n', self->priv->stream);
 	self->priv->_bol = TRUE;
@@ -179,13 +181,12 @@ void vala_ccode_writer_write_newline (ValaCCodeWriter* self)
 /**
  * Opens a new block, increasing the indent level.
  */
-void vala_ccode_writer_write_begin_block (ValaCCodeWriter* self)
-{
+void vala_ccode_writer_write_begin_block (ValaCCodeWriter* self) {
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
 	if (!vala_ccode_writer_get_bol (self)) {
 		fputc (' ', self->priv->stream);
 	} else {
-		vala_ccode_writer_write_indent (self);
+		vala_ccode_writer_write_indent (self, NULL);
 	}
 	fputc ('{', self->priv->stream);
 	vala_ccode_writer_write_newline (self);
@@ -196,12 +197,11 @@ void vala_ccode_writer_write_begin_block (ValaCCodeWriter* self)
 /**
  * Closes the current block, decreasing the indent level.
  */
-void vala_ccode_writer_write_end_block (ValaCCodeWriter* self)
-{
+void vala_ccode_writer_write_end_block (ValaCCodeWriter* self) {
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
 	g_assert (self->priv->indent > 0);
 	self->priv->indent--;
-	vala_ccode_writer_write_indent (self);
+	vala_ccode_writer_write_indent (self, NULL);
 	fprintf (self->priv->stream, "}");
 }
 
@@ -211,15 +211,13 @@ void vala_ccode_writer_write_end_block (ValaCCodeWriter* self)
  *
  * @param text the comment text
  */
-void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text)
-{
+void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 	gboolean first;
 	char** _tmp0;
 	gint lines_length1;
 	char** lines;
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
-	g_return_if_fail (text != NULL);
-	vala_ccode_writer_write_indent (self);
+	vala_ccode_writer_write_indent (self, NULL);
 	fprintf (self->priv->stream, "/*");
 	first = TRUE;
 	/* separate declaration due to missing memory management in foreach statements */
@@ -236,7 +234,7 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text)
 			line = (_tmp1 = line_collection[line_it], (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 			{
 				if (!first) {
-					vala_ccode_writer_write_indent (self);
+					vala_ccode_writer_write_indent (self, NULL);
 				} else {
 					first = FALSE;
 				}
@@ -251,15 +249,13 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text)
 }
 
 
-char* vala_ccode_writer_get_filename (ValaCCodeWriter* self)
-{
+char* vala_ccode_writer_get_filename (ValaCCodeWriter* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_WRITER (self), NULL);
 	return self->priv->_filename;
 }
 
 
-void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value)
-{
+static void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
@@ -282,21 +278,34 @@ void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value)
 }
 
 
-gboolean vala_ccode_writer_get_bol (ValaCCodeWriter* self)
-{
+gboolean vala_ccode_writer_get_line_directives (ValaCCodeWriter* self) {
+	g_return_val_if_fail (VALA_IS_CCODE_WRITER (self), FALSE);
+	return self->priv->_line_directives;
+}
+
+
+void vala_ccode_writer_set_line_directives (ValaCCodeWriter* self, gboolean value) {
+	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
+	self->priv->_line_directives = value;
+}
+
+
+gboolean vala_ccode_writer_get_bol (ValaCCodeWriter* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_WRITER (self), FALSE);
 	return self->priv->_bol;
 }
 
 
-static void vala_ccode_writer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_writer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeWriter * self;
 	self = VALA_CCODE_WRITER (object);
 	switch (property_id) {
 		case VALA_CCODE_WRITER_FILENAME:
 		g_value_set_string (value, vala_ccode_writer_get_filename (self));
 		break;
+		case VALA_CCODE_WRITER_LINE_DIRECTIVES:
+		g_value_set_boolean (value, vala_ccode_writer_get_line_directives (self));
+		break;
 		case VALA_CCODE_WRITER_BOL:
 		g_value_set_boolean (value, vala_ccode_writer_get_bol (self));
 		break;
@@ -307,14 +316,16 @@ static void vala_ccode_writer_get_property (GObject * object, guint property_id,
 }
 
 
-static void vala_ccode_writer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_writer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeWriter * self;
 	self = VALA_CCODE_WRITER (object);
 	switch (property_id) {
 		case VALA_CCODE_WRITER_FILENAME:
 		vala_ccode_writer_set_filename (self, g_value_get_string (value));
 		break;
+		case VALA_CCODE_WRITER_LINE_DIRECTIVES:
+		vala_ccode_writer_set_line_directives (self, g_value_get_boolean (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -322,42 +333,35 @@ static void vala_ccode_writer_set_property (GObject * object, guint property_id,
 }
 
 
-static void vala_ccode_writer_class_init (ValaCCodeWriterClass * klass)
-{
+static void vala_ccode_writer_class_init (ValaCCodeWriterClass * klass) {
 	vala_ccode_writer_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeWriterPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_writer_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_writer_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_writer_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WRITER_FILENAME, g_param_spec_string ("filename", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WRITER_BOL, g_param_spec_boolean ("bol", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WRITER_FILENAME, g_param_spec_string ("filename", "filename", "filename", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WRITER_LINE_DIRECTIVES, g_param_spec_boolean ("line-directives", "line-directives", "line-directives", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WRITER_BOL, g_param_spec_boolean ("bol", "bol", "bol", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
 
-static void vala_ccode_writer_init (ValaCCodeWriter * self)
-{
+static void vala_ccode_writer_init (ValaCCodeWriter * self) {
 	self->priv = VALA_CCODE_WRITER_GET_PRIVATE (self);
 	self->priv->_bol = TRUE;
 }
 
 
-static void vala_ccode_writer_dispose (GObject * obj)
-{
+static void vala_ccode_writer_dispose (GObject * obj) {
 	ValaCCodeWriter * self;
-	ValaCCodeWriterClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_WRITER (obj);
 	(self->priv->_filename = (g_free (self->priv->_filename), NULL));
 	(self->priv->temp_filename = (g_free (self->priv->temp_filename), NULL));
 	(self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)));
-	klass = VALA_CCODE_WRITER_CLASS (g_type_class_peek (VALA_TYPE_CCODE_WRITER));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_writer_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_writer_get_type (void)
-{
+GType vala_ccode_writer_get_type (void) {
 	static GType vala_ccode_writer_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_writer_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeWriter), 0, (GInstanceInitFunc) vala_ccode_writer_init };
@@ -367,8 +371,7 @@ GType vala_ccode_writer_get_type (void)
 }
 
 
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func)
-{
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if (array != NULL && destroy_func != NULL) {
 		int i;
 		if (array_length >= 0)
