@@ -7,7 +7,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,7 +22,6 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "hashset.h"
 #include <gee/hashset.h>
 
 typedef struct _GeeHashSetNode GeeHashSetNode;
@@ -37,6 +36,7 @@ struct _GeeHashSetPrivate {
 	gint _stamp;
 	GHashFunc _hash_func;
 	GEqualFunc _equal_func;
+	GType g_type;
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
@@ -46,16 +46,17 @@ enum  {
 	GEE_HASH_SET_SIZE,
 	GEE_HASH_SET_HASH_FUNC,
 	GEE_HASH_SET_EQUAL_FUNC,
+	GEE_HASH_SET_G_TYPE,
 	GEE_HASH_SET_G_DUP_FUNC,
 	GEE_HASH_SET_G_DESTROY_FUNC
 };
 static const gint GEE_HASH_SET_MIN_SIZE = 11;
 static const gint GEE_HASH_SET_MAX_SIZE = 13845163;
-static GeeHashSetNode** gee_hash_set_lookup_node (GeeHashSet* self, gpointer key);
-static gboolean gee_hash_set_real_contains (GeeCollection* base, gpointer key);
+static GeeHashSetNode** gee_hash_set_lookup_node (GeeHashSet* self, gconstpointer key);
+static gboolean gee_hash_set_real_contains (GeeCollection* base, gconstpointer key);
 static GeeIterator* gee_hash_set_real_iterator (GeeIterable* base);
-static gboolean gee_hash_set_real_add (GeeCollection* base, gpointer key);
-static gboolean gee_hash_set_real_remove (GeeCollection* base, gpointer key);
+static gboolean gee_hash_set_real_add (GeeCollection* base, gconstpointer key);
+static gboolean gee_hash_set_real_remove (GeeCollection* base, gconstpointer key);
 static void gee_hash_set_real_clear (GeeCollection* base);
 static void gee_hash_set_resize (GeeHashSet* self);
 static GObject * gee_hash_set_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
@@ -66,14 +67,6 @@ struct _GeeHashSetNode {
 };
 static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash);
 static void gee_hash_set_node_free (GeeHashSetNode* self);
-static void gee_hash_set_node_free (GeeHashSetNode* self)
-{
-	NULL;
-	(self->next == NULL ? NULL : (self->next = (gee_hash_set_node_free (self->next), NULL)));
-	g_slice_free (GeeHashSetNode, self);
-}
-
-
 
 #define GEE_HASH_SET_TYPE_ITERATOR (gee_hash_set_iterator_get_type ())
 #define GEE_HASH_SET_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_HASH_SET_TYPE_ITERATOR, GeeHashSetIterator))
@@ -83,17 +76,18 @@ static void gee_hash_set_node_free (GeeHashSetNode* self)
 #define GEE_HASH_SET_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_HASH_SET_TYPE_ITERATOR, GeeHashSetIteratorClass))
 
 struct _GeeHashSetIterator {
-	GObject parent;
+	GObject parent_instance;
 	GeeHashSetIteratorPrivate * priv;
 };
 struct _GeeHashSetIteratorClass {
-	GObjectClass parent;
+	GObjectClass parent_class;
 };
 struct _GeeHashSetIteratorPrivate {
 	GeeHashSet* _set;
 	gint _index;
 	GeeHashSetNode* _node;
 	gint _stamp;
+	GType g_type;
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
@@ -101,10 +95,11 @@ struct _GeeHashSetIteratorPrivate {
 enum  {
 	GEE_HASH_SET_ITERATOR_DUMMY_PROPERTY,
 	GEE_HASH_SET_ITERATOR_SET,
+	GEE_HASH_SET_ITERATOR_G_TYPE,
 	GEE_HASH_SET_ITERATOR_G_DUP_FUNC,
 	GEE_HASH_SET_ITERATOR_G_DESTROY_FUNC
 };
-static GeeHashSetIterator* gee_hash_set_iterator_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set);
+static GeeHashSetIterator* gee_hash_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set);
 static gboolean gee_hash_set_iterator_real_next (GeeIterator* base);
 static gpointer gee_hash_set_iterator_real_get (GeeIterator* base);
 static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet* value);
@@ -120,63 +115,59 @@ static void gee_hash_set_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
-GeeHashSet* gee_hash_set_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GHashFunc hash_func, GEqualFunc equal_func)
-{
+GeeHashSet* gee_hash_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GHashFunc hash_func, GEqualFunc equal_func) {
 	GeeHashSet * self;
 	self = g_object_newv (GEE_TYPE_HASH_SET, 0, NULL);
 	gee_hash_set_set_hash_func (self, hash_func);
 	gee_hash_set_set_equal_func (self, equal_func);
+	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
 	return self;
 }
 
 
-static GeeHashSetNode** gee_hash_set_lookup_node (GeeHashSet* self, gpointer key)
-{
+static GeeHashSetNode** gee_hash_set_lookup_node (GeeHashSet* self, gconstpointer key) {
 	guint hash_value;
 	GeeHashSetNode** node;
 	g_return_val_if_fail (GEE_IS_HASH_SET (self), NULL);
 	hash_value = self->priv->_hash_func (key);
 	node = &self->priv->_nodes[hash_value % self->priv->_array_size];
-	while ((*node) != NULL && (hash_value != (*node)->key_hash || !self->priv->_equal_func ((*node)->key, key))) {
-		node = &((*node)->next);
+	while ((*node) != NULL && (hash_value != (((GeeHashSetNode*) (*node)))->key_hash || !self->priv->_equal_func ((((GeeHashSetNode*) (*node)))->key, key))) {
+		node = &((((GeeHashSetNode*) (*node)))->next);
 	}
 	return node;
 }
 
 
-static gboolean gee_hash_set_real_contains (GeeCollection* base, gpointer key)
-{
+static gboolean gee_hash_set_real_contains (GeeCollection* base, gconstpointer key) {
 	GeeHashSet * self;
 	GeeHashSetNode** node;
-	self = ((GeeHashSet*) base);
+	self = GEE_HASH_SET (base);
 	node = gee_hash_set_lookup_node (self, key);
 	return (*node != NULL);
 }
 
 
-static GeeIterator* gee_hash_set_real_iterator (GeeIterable* base)
-{
+static GeeIterator* gee_hash_set_real_iterator (GeeIterable* base) {
 	GeeHashSet * self;
-	self = ((GeeHashSet*) base);
-	return GEE_ITERATOR (gee_hash_set_iterator_new (self->priv->g_dup_func, self->priv->g_destroy_func, self));
+	self = GEE_HASH_SET (base);
+	return GEE_ITERATOR (gee_hash_set_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) self->priv->g_dup_func), self->priv->g_destroy_func, self));
 }
 
 
-static gboolean gee_hash_set_real_add (GeeCollection* base, gpointer key)
-{
+static gboolean gee_hash_set_real_add (GeeCollection* base, gconstpointer key) {
 	GeeHashSet * self;
 	GeeHashSetNode** node;
-	self = ((GeeHashSet*) base);
+	self = GEE_HASH_SET (base);
 	node = gee_hash_set_lookup_node (self, key);
 	if (*node != NULL) {
 		return FALSE;
 	} else {
 		guint hash_value;
-		gpointer _tmp1;
+		gconstpointer _tmp1;
 		hash_value = self->priv->_hash_func (key);
-		*node = gee_hash_set_node_new ((_tmp1 = key, (_tmp1 == NULL || self->priv->g_dup_func == NULL ? _tmp1 : self->priv->g_dup_func (_tmp1))), hash_value);
+		*node = gee_hash_set_node_new ((_tmp1 = key, (_tmp1 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp1) : self->priv->g_dup_func (((gpointer) _tmp1)))), hash_value);
 		self->priv->_nnodes++;
 		gee_hash_set_resize (self);
 		self->priv->_stamp++;
@@ -185,16 +176,15 @@ static gboolean gee_hash_set_real_add (GeeCollection* base, gpointer key)
 }
 
 
-static gboolean gee_hash_set_real_remove (GeeCollection* base, gpointer key)
-{
+static gboolean gee_hash_set_real_remove (GeeCollection* base, gconstpointer key) {
 	GeeHashSet * self;
 	GeeHashSetNode** node;
-	self = ((GeeHashSet*) base);
+	self = GEE_HASH_SET (base);
 	node = gee_hash_set_lookup_node (self, key);
 	if (*node != NULL) {
 		gpointer _tmp0;
-		(*node)->key = (_tmp0 = NULL, ((*node)->key == NULL || self->priv->g_destroy_func == NULL ? NULL : ((*node)->key = (self->priv->g_destroy_func ((*node)->key), NULL))), _tmp0);
-		*node = (*node)->next;
+		(((GeeHashSetNode*) (*node)))->key = (_tmp0 = NULL, ((((GeeHashSetNode*) (*node)))->key == NULL || self->priv->g_destroy_func == NULL ? NULL : ((((GeeHashSetNode*) (*node)))->key = (self->priv->g_destroy_func ((((GeeHashSetNode*) (*node)))->key), NULL))), _tmp0);
+		*node = (((GeeHashSetNode*) (*node)))->next;
 		self->priv->_nnodes--;
 		gee_hash_set_resize (self);
 		self->priv->_stamp++;
@@ -204,10 +194,9 @@ static gboolean gee_hash_set_real_remove (GeeCollection* base, gpointer key)
 }
 
 
-static void gee_hash_set_real_clear (GeeCollection* base)
-{
+static void gee_hash_set_real_clear (GeeCollection* base) {
 	GeeHashSet * self;
-	self = ((GeeHashSet*) base);
+	self = GEE_HASH_SET (base);
 	{
 		gint i;
 		i = 0;
@@ -238,8 +227,7 @@ static void gee_hash_set_real_clear (GeeCollection* base)
 }
 
 
-static void gee_hash_set_resize (GeeHashSet* self)
-{
+static void gee_hash_set_resize (GeeHashSet* self) {
 	g_return_if_fail (GEE_IS_HASH_SET (self));
 	if ((self->priv->_array_size >= 3 * self->priv->_nnodes && self->priv->_array_size >= GEE_HASH_SET_MIN_SIZE) || (3 * self->priv->_array_size <= self->priv->_nnodes && self->priv->_array_size < GEE_HASH_SET_MAX_SIZE)) {
 		gint new_array_size;
@@ -300,29 +288,25 @@ static void gee_hash_set_resize (GeeHashSet* self)
 }
 
 
-static gint gee_hash_set_real_get_size (GeeHashSet* self)
-{
+static gint gee_hash_set_real_get_size (GeeHashSet* self) {
 	g_return_val_if_fail (GEE_IS_HASH_SET (self), 0);
 	return self->priv->_nnodes;
 }
 
 
-void gee_hash_set_set_hash_func (GeeHashSet* self, GHashFunc value)
-{
+void gee_hash_set_set_hash_func (GeeHashSet* self, GHashFunc value) {
 	g_return_if_fail (GEE_IS_HASH_SET (self));
 	self->priv->_hash_func = value;
 }
 
 
-void gee_hash_set_set_equal_func (GeeHashSet* self, GEqualFunc value)
-{
+void gee_hash_set_set_equal_func (GeeHashSet* self, GEqualFunc value) {
 	g_return_if_fail (GEE_IS_HASH_SET (self));
 	self->priv->_equal_func = value;
 }
 
 
-static GObject * gee_hash_set_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties)
-{
+static GObject * gee_hash_set_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
 	GObject * obj;
 	GeeHashSetClass * klass;
 	GObjectClass * parent_class;
@@ -341,8 +325,7 @@ static GObject * gee_hash_set_constructor (GType type, guint n_construct_propert
 }
 
 
-static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash)
-{
+static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash) {
 	GeeHashSetNode* self;
 	gpointer _tmp1;
 	gpointer _tmp0;
@@ -353,22 +336,28 @@ static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash)
 }
 
 
-static GeeHashSetIterator* gee_hash_set_iterator_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set)
-{
+static void gee_hash_set_node_free (GeeHashSetNode* self) {
+	NULL;
+	(self->next == NULL ? NULL : (self->next = (gee_hash_set_node_free (self->next), NULL)));
+	g_slice_free (GeeHashSetNode, self);
+}
+
+
+static GeeHashSetIterator* gee_hash_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set) {
 	GeeHashSetIterator * self;
-	g_return_val_if_fail (GEE_IS_HASH_SET (set), NULL);
+	g_return_val_if_fail (set == NULL || GEE_IS_HASH_SET (set), NULL);
 	self = g_object_newv (GEE_HASH_SET_TYPE_ITERATOR, 0, NULL);
 	gee_hash_set_iterator_set_set (self, set);
+	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
 	return self;
 }
 
 
-static gboolean gee_hash_set_iterator_real_next (GeeIterator* base)
-{
+static gboolean gee_hash_set_iterator_real_next (GeeIterator* base) {
 	GeeHashSetIterator * self;
-	self = ((GeeHashSetIterator*) base);
+	self = GEE_HASH_SET_ITERATOR (base);
 	if (self->priv->_node != NULL) {
 		self->priv->_node = self->priv->_node->next;
 	}
@@ -380,19 +369,17 @@ static gboolean gee_hash_set_iterator_real_next (GeeIterator* base)
 }
 
 
-static gpointer gee_hash_set_iterator_real_get (GeeIterator* base)
-{
+static gpointer gee_hash_set_iterator_real_get (GeeIterator* base) {
 	GeeHashSetIterator * self;
-	gpointer _tmp0;
-	self = ((GeeHashSetIterator*) base);
+	gconstpointer _tmp0;
+	self = GEE_HASH_SET_ITERATOR (base);
 	g_assert (self->priv->_stamp == self->priv->_set->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
-	return (_tmp0 = self->priv->_node->key, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? _tmp0 : self->priv->g_dup_func (_tmp0)));
+	return (_tmp0 = self->priv->_node->key, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0))));
 }
 
 
-static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet* value)
-{
+static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet* value) {
 	GeeHashSet* _tmp1;
 	GeeHashSet* _tmp0;
 	g_return_if_fail (GEE_HASH_SET_IS_ITERATOR (self));
@@ -408,8 +395,7 @@ static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet*
 }
 
 
-static void gee_hash_set_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void gee_hash_set_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeHashSetIterator * self;
 	self = GEE_HASH_SET_ITERATOR (object);
 	switch (property_id) {
@@ -420,14 +406,19 @@ static void gee_hash_set_iterator_get_property (GObject * object, guint property
 }
 
 
-static void gee_hash_set_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void gee_hash_set_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	GeeHashSetIterator * self;
 	self = GEE_HASH_SET_ITERATOR (object);
 	switch (property_id) {
 		case GEE_HASH_SET_ITERATOR_SET:
 		gee_hash_set_iterator_set_set (self, g_value_get_object (value));
 		break;
+		case GEE_HASH_SET_ITERATOR_G_TYPE:
+		self->priv->g_type = g_value_get_gtype (value);
+		break;
+		case GEE_HASH_SET_ITERATOR_G_DUP_FUNC:
+		self->priv->g_dup_func = g_value_get_pointer (value);
+		break;
 		case GEE_HASH_SET_ITERATOR_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
@@ -438,50 +429,42 @@ static void gee_hash_set_iterator_set_property (GObject * object, guint property
 }
 
 
-static void gee_hash_set_iterator_class_init (GeeHashSetIteratorClass * klass)
-{
+static void gee_hash_set_iterator_class_init (GeeHashSetIteratorClass * klass) {
 	gee_hash_set_iterator_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeHashSetIteratorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_hash_set_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_set_iterator_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_set_iterator_dispose;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_SET, g_param_spec_object ("set", "foo", "bar", GEE_TYPE_HASH_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_SET, g_param_spec_object ("set", "set", "set", GEE_TYPE_HASH_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
 
-static void gee_hash_set_iterator_gee_iterator_interface_init (GeeIteratorIface * iface)
-{
+static void gee_hash_set_iterator_gee_iterator_interface_init (GeeIteratorIface * iface) {
 	gee_hash_set_iterator_gee_iterator_parent_iface = g_type_interface_peek_parent (iface);
 	iface->next = gee_hash_set_iterator_real_next;
 	iface->get = gee_hash_set_iterator_real_get;
 }
 
 
-static void gee_hash_set_iterator_init (GeeHashSetIterator * self)
-{
+static void gee_hash_set_iterator_init (GeeHashSetIterator * self) {
 	self->priv = GEE_HASH_SET_ITERATOR_GET_PRIVATE (self);
 	self->priv->_index = -1;
 	self->priv->_stamp = 0;
 }
 
 
-static void gee_hash_set_iterator_dispose (GObject * obj)
-{
+static void gee_hash_set_iterator_dispose (GObject * obj) {
 	GeeHashSetIterator * self;
-	GeeHashSetIteratorClass * klass;
-	GObjectClass * parent_class;
 	self = GEE_HASH_SET_ITERATOR (obj);
 	(self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL)));
-	klass = GEE_HASH_SET_ITERATOR_CLASS (g_type_class_peek (GEE_HASH_SET_TYPE_ITERATOR));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (gee_hash_set_iterator_parent_class)->dispose (obj);
 }
 
 
-static GType gee_hash_set_iterator_get_type (void)
-{
+static GType gee_hash_set_iterator_get_type (void) {
 	static GType gee_hash_set_iterator_type_id = 0;
 	if (G_UNLIKELY (gee_hash_set_iterator_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeHashSetIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_set_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashSetIterator), 0, (GInstanceInitFunc) gee_hash_set_iterator_init };
@@ -493,8 +476,7 @@ static GType gee_hash_set_iterator_get_type (void)
 }
 
 
-static void gee_hash_set_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void gee_hash_set_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeHashSet * self;
 	self = GEE_HASH_SET (object);
 	switch (property_id) {
@@ -508,8 +490,7 @@ static void gee_hash_set_get_property (GObject * object, guint property_id, GVal
 }
 
 
-static void gee_hash_set_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void gee_hash_set_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	GeeHashSet * self;
 	self = GEE_HASH_SET (object);
 	switch (property_id) {
@@ -519,6 +500,12 @@ static void gee_hash_set_set_property (GObject * object, guint property_id, cons
 		case GEE_HASH_SET_EQUAL_FUNC:
 		gee_hash_set_set_equal_func (self, g_value_get_pointer (value));
 		break;
+		case GEE_HASH_SET_G_TYPE:
+		self->priv->g_type = g_value_get_gtype (value);
+		break;
+		case GEE_HASH_SET_G_DUP_FUNC:
+		self->priv->g_dup_func = g_value_get_pointer (value);
+		break;
 		case GEE_HASH_SET_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
@@ -529,31 +516,29 @@ static void gee_hash_set_set_property (GObject * object, guint property_id, cons
 }
 
 
-static void gee_hash_set_class_init (GeeHashSetClass * klass)
-{
+static void gee_hash_set_class_init (GeeHashSetClass * klass) {
 	gee_hash_set_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeHashSetPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_hash_set_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_set_set_property;
 	G_OBJECT_CLASS (klass)->constructor = gee_hash_set_constructor;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_set_dispose;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_SIZE, "size");
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_HASH_FUNC, g_param_spec_pointer ("hash-func", "foo", "bar", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_EQUAL_FUNC, g_param_spec_pointer ("equal-func", "foo", "bar", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_HASH_FUNC, g_param_spec_pointer ("hash-func", "hash-func", "hash-func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_EQUAL_FUNC, g_param_spec_pointer ("equal-func", "equal-func", "equal-func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
 
-static void gee_hash_set_gee_iterable_interface_init (GeeIterableIface * iface)
-{
+static void gee_hash_set_gee_iterable_interface_init (GeeIterableIface * iface) {
 	gee_hash_set_gee_iterable_parent_iface = g_type_interface_peek_parent (iface);
 	iface->iterator = gee_hash_set_real_iterator;
 }
 
 
-static void gee_hash_set_gee_collection_interface_init (GeeCollectionIface * iface)
-{
+static void gee_hash_set_gee_collection_interface_init (GeeCollectionIface * iface) {
 	gee_hash_set_gee_collection_parent_iface = g_type_interface_peek_parent (iface);
 	iface->contains = gee_hash_set_real_contains;
 	iface->add = gee_hash_set_real_add;
@@ -562,37 +547,29 @@ static void gee_hash_set_gee_collection_interface_init (GeeCollectionIface * ifa
 }
 
 
-static void gee_hash_set_gee_set_interface_init (GeeSetIface * iface)
-{
+static void gee_hash_set_gee_set_interface_init (GeeSetIface * iface) {
 	gee_hash_set_gee_set_parent_iface = g_type_interface_peek_parent (iface);
 }
 
 
-static void gee_hash_set_init (GeeHashSet * self)
-{
+static void gee_hash_set_init (GeeHashSet * self) {
 	self->priv = GEE_HASH_SET_GET_PRIVATE (self);
 	self->priv->_stamp = 0;
 }
 
 
-static void gee_hash_set_dispose (GObject * obj)
-{
+static void gee_hash_set_dispose (GObject * obj) {
 	GeeHashSet * self;
-	GeeHashSetClass * klass;
-	GObjectClass * parent_class;
 	self = GEE_HASH_SET (obj);
 	{
 		gee_collection_clear (GEE_COLLECTION (self));
 	}
 	(self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_set_node_free)), NULL));
-	klass = GEE_HASH_SET_CLASS (g_type_class_peek (GEE_TYPE_HASH_SET));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (gee_hash_set_parent_class)->dispose (obj);
 }
 
 
-GType gee_hash_set_get_type (void)
-{
+GType gee_hash_set_get_type (void) {
 	static GType gee_hash_set_type_id = 0;
 	if (G_UNLIKELY (gee_hash_set_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeHashSetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashSet), 0, (GInstanceInitFunc) gee_hash_set_init };
@@ -608,8 +585,7 @@ GType gee_hash_set_get_type (void)
 }
 
 
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func)
-{
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if (array != NULL && destroy_func != NULL) {
 		int i;
 		if (array_length >= 0)
