@@ -47,14 +47,14 @@ typedef struct _GeeReadOnlyCollectionPrivate GeeReadOnlyCollectionPrivate;
  * Represents a read-only collection of items.
  */
 struct _GeeReadOnlyCollection {
-	GObject parent;
+	GObject parent_instance;
 	GeeReadOnlyCollectionPrivate * priv;
 };
 struct _GeeReadOnlyCollectionClass {
-	GObjectClass parent;
+	GObjectClass parent_class;
 };
 
-GeeReadOnlyCollection* gee_read_only_collection_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeCollection* collection);
+GeeReadOnlyCollection* gee_read_only_collection_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeCollection* collection);
 void gee_read_only_collection_set_collection (GeeReadOnlyCollection* self, GeeCollection* value);
 GType gee_read_only_collection_get_type (void);
 
