@@ -47,14 +47,14 @@ typedef struct _GeeReadOnlyMapPrivate GeeReadOnlyMapPrivate;
  * Represents a read-only collection of key/value pairs.
  */
 struct _GeeReadOnlyMap {
-	GObject parent;
+	GObject parent_instance;
 	GeeReadOnlyMapPrivate * priv;
 };
 struct _GeeReadOnlyMapClass {
-	GObjectClass parent;
+	GObjectClass parent_class;
 };
 
-GeeReadOnlyMap* gee_read_only_map_new (GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeMap* map);
+GeeReadOnlyMap* gee_read_only_map_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeMap* map);
 void gee_read_only_map_set_map (GeeReadOnlyMap* self, GeeMap* value);
 GType gee_read_only_map_get_type (void);
 
