@@ -21,7 +21,7 @@
  */
 
 #include <gobject/valaclassregisterfunction.h>
-#include <vala/valatypereference.h>
+#include <vala/valadatatype.h>
 #include <vala/valainterface.h>
 #include <ccode/valaccodedeclaration.h>
 #include <ccode/valaccodemodifiers.h>
@@ -42,7 +42,7 @@ enum  {
 	VALA_CLASS_REGISTER_FUNCTION_DUMMY_PROPERTY,
 	VALA_CLASS_REGISTER_FUNCTION_CLASS_REFERENCE
 };
-static ValaDataType* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
+static ValaTypesymbol* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base);
@@ -65,17 +65,19 @@ static void vala_class_register_function_dispose (GObject * obj);
  */
 ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl) {
 	ValaClassRegisterFunction * self;
-	g_return_val_if_fail (VALA_IS_CLASS (cl), NULL);
+	g_return_val_if_fail (cl == NULL || VALA_IS_CLASS (cl), NULL);
 	self = g_object_newv (VALA_TYPE_CLASS_REGISTER_FUNCTION, 0, NULL);
 	vala_class_register_function_set_class_reference (self, cl);
 	return self;
 }
 
 
-static ValaDataType* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
+static ValaTypesymbol* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
+	ValaClass* _tmp0;
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
-	return VALA_DATA_TYPE (g_object_ref (vala_class_register_function_get_class_reference (self)));
+	_tmp0 = NULL;
+	return VALA_TYPESYMBOL ((_tmp0 = vala_class_register_function_get_class_reference (self), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))));
 }
 
 
@@ -86,7 +88,7 @@ static char* vala_class_register_function_real_get_type_struct_name (ValaTypeReg
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%sClass", (_tmp0 = vala_data_type_get_cname (VALA_DATA_TYPE (vala_class_register_function_get_class_reference (self)), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strdup_printf ("%sClass", (_tmp0 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (vala_class_register_function_get_class_reference (self)), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -115,7 +117,7 @@ static char* vala_class_register_function_real_get_instance_struct_size (ValaTyp
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("sizeof (%s)", (_tmp0 = vala_data_type_get_cname (VALA_DATA_TYPE (vala_class_register_function_get_class_reference (self)), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strdup_printf ("sizeof (%s)", (_tmp0 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (vala_class_register_function_get_class_reference (self)), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -133,7 +135,7 @@ static char* vala_class_register_function_real_get_instance_init_func_name (Vala
 static char* vala_class_register_function_real_get_parent_type_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
-	return vala_data_type_get_upper_case_cname (VALA_DATA_TYPE (vala_class_get_base_class (vala_class_register_function_get_class_reference (self))), "TYPE_");
+	return vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (vala_class_get_base_class (vala_class_register_function_get_class_reference (self))), "TYPE_");
 }
 
 
@@ -166,7 +168,7 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 		base_type_collection = vala_class_get_base_types (vala_class_register_function_get_class_reference (self));
 		base_type_it = gee_iterable_iterator (GEE_ITERABLE (base_type_collection));
 		while (gee_iterator_next (base_type_it)) {
-			ValaTypeReference* base_type;
+			ValaDataType* base_type;
 			base_type = gee_iterator_get (base_type_it);
 			{
 				ValaInterface* _tmp0;
@@ -180,12 +182,12 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 				char* _tmp5;
 				char* _tmp4;
 				char* _tmp3;
-				if (!(VALA_IS_INTERFACE (vala_type_reference_get_data_type (base_type)))) {
+				if (!(VALA_IS_INTERFACE (vala_data_type_get_data_type (base_type)))) {
 					(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
 					continue;
 				}
 				_tmp0 = NULL;
-				iface = (_tmp0 = VALA_INTERFACE (vala_type_reference_get_data_type (base_type)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+				iface = (_tmp0 = VALA_INTERFACE (vala_data_type_get_data_type (base_type)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 				_tmp1 = NULL;
 				_tmp2 = NULL;
 				iface_info_name = (_tmp2 = g_strdup_printf ("%s_info", (_tmp1 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (iface), NULL))), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
@@ -213,7 +215,6 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 		(base_type_it == NULL ? NULL : (base_type_it = (g_object_unref (base_type_it), NULL)));
 	}
 	return frag;
-	(frag == NULL ? NULL : (frag = (g_object_unref (frag), NULL)));
 }
 
 
@@ -228,7 +229,7 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 		base_type_collection = vala_class_get_base_types (vala_class_register_function_get_class_reference (self));
 		base_type_it = gee_iterable_iterator (GEE_ITERABLE (base_type_collection));
 		while (gee_iterator_next (base_type_it)) {
-			ValaTypeReference* base_type;
+			ValaDataType* base_type;
 			base_type = gee_iterator_get (base_type_it);
 			{
 				ValaInterface* _tmp0;
@@ -247,12 +248,12 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 				ValaCCodeIdentifier* _tmp11;
 				char* _tmp10;
 				ValaCCodeExpressionStatement* _tmp12;
-				if (!(VALA_IS_INTERFACE (vala_type_reference_get_data_type (base_type)))) {
+				if (!(VALA_IS_INTERFACE (vala_data_type_get_data_type (base_type)))) {
 					(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
 					continue;
 				}
 				_tmp0 = NULL;
-				iface = (_tmp0 = VALA_INTERFACE (vala_type_reference_get_data_type (base_type)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+				iface = (_tmp0 = VALA_INTERFACE (vala_data_type_get_data_type (base_type)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 				_tmp1 = NULL;
 				_tmp2 = NULL;
 				iface_info_name = (_tmp2 = g_strdup_printf ("%s_info", (_tmp1 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (iface), NULL))), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
@@ -268,7 +269,7 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 				(_tmp5 = (g_free (_tmp5), NULL));
 				_tmp9 = NULL;
 				_tmp8 = NULL;
-				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp9 = vala_ccode_identifier_new ((_tmp8 = vala_data_type_get_upper_case_cname (VALA_DATA_TYPE (iface), "TYPE_"))))));
+				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp9 = vala_ccode_identifier_new ((_tmp8 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (iface), "TYPE_"))))));
 				(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
 				(_tmp8 = (g_free (_tmp8), NULL));
 				_tmp11 = NULL;
@@ -289,7 +290,6 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 		(base_type_it == NULL ? NULL : (base_type_it = (g_object_unref (base_type_it), NULL)));
 	}
 	return frag;
-	(frag == NULL ? NULL : (frag = (g_object_unref (frag), NULL)));
 }
 
 
@@ -339,17 +339,17 @@ static void vala_class_register_function_class_init (ValaClassRegisterFunctionCl
 	G_OBJECT_CLASS (klass)->get_property = vala_class_register_function_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_class_register_function_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_class_register_function_dispose;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_declaration = vala_class_register_function_real_get_type_declaration;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_struct_name = vala_class_register_function_real_get_type_struct_name;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_base_init_func_name = vala_class_register_function_real_get_base_init_func_name;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_class_init_func_name = vala_class_register_function_real_get_class_init_func_name;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_instance_struct_size = vala_class_register_function_real_get_instance_struct_size;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_instance_init_func_name = vala_class_register_function_real_get_instance_init_func_name;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_parent_type_name = vala_class_register_function_real_get_parent_type_name;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_flags = vala_class_register_function_real_get_type_flags;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_accessibility = vala_class_register_function_real_get_accessibility;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_declaration = vala_class_register_function_real_get_type_interface_init_declaration;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_statements = vala_class_register_function_real_get_type_interface_init_statements;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_declaration = vala_class_register_function_real_get_type_declaration;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_struct_name = vala_class_register_function_real_get_type_struct_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_base_init_func_name = vala_class_register_function_real_get_base_init_func_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_class_init_func_name = vala_class_register_function_real_get_class_init_func_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_instance_struct_size = vala_class_register_function_real_get_instance_struct_size;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_instance_init_func_name = vala_class_register_function_real_get_instance_init_func_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_parent_type_name = vala_class_register_function_real_get_parent_type_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_flags = vala_class_register_function_real_get_type_flags;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_accessibility = vala_class_register_function_real_get_accessibility;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_declaration = vala_class_register_function_real_get_type_interface_init_declaration;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_statements = vala_class_register_function_real_get_type_interface_init_statements;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_REGISTER_FUNCTION_CLASS_REFERENCE, g_param_spec_object ("class-reference", "class-reference", "class-reference", VALA_TYPE_CLASS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -370,7 +370,7 @@ GType vala_class_register_function_get_type (void) {
 	static GType vala_class_register_function_type_id = 0;
 	if (G_UNLIKELY (vala_class_register_function_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaClassRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_class_register_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaClassRegisterFunction), 0, (GInstanceInitFunc) vala_class_register_function_init };
-		vala_class_register_function_type_id = g_type_register_static (VALA_TYPE_TYPE_REGISTER_FUNCTION, "ValaClassRegisterFunction", &g_define_type_info, 0);
+		vala_class_register_function_type_id = g_type_register_static (VALA_TYPE_TYPEREGISTER_FUNCTION, "ValaClassRegisterFunction", &g_define_type_info, 0);
 	}
 	return vala_class_register_function_type_id;
 }
