@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,15 +20,16 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACLASSREGISTERFUNCTION_H__
-#define __VALACLASSREGISTERFUNCTION_H__
+#ifndef __GOBJECT_VALACLASSREGISTERFUNCTION_H__
+#define __GOBJECT_VALACLASSREGISTERFUNCTION_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valaclass.h>
-#include <vala/valadatatype.h>
+#include <vala/valatypesymbol.h>
 #include <stdlib.h>
 #include <string.h>
+#include <vala/valasymbol.h>
 #include <ccode/valaccodefragment.h>
 #include <gobject/valatyperegisterfunction.h>
 
@@ -50,11 +51,11 @@ typedef struct _ValaClassRegisterFunctionPrivate ValaClassRegisterFunctionPrivat
  * C function to register a class at runtime.
  */
 struct _ValaClassRegisterFunction {
-	ValaTypeRegisterFunction parent;
+	ValaTypeRegisterFunction parent_instance;
 	ValaClassRegisterFunctionPrivate * priv;
 };
 struct _ValaClassRegisterFunctionClass {
-	ValaTypeRegisterFunctionClass parent;
+	ValaTypeRegisterFunctionClass parent_class;
 };
 
 ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl);
