@@ -33,9 +33,9 @@ static char* vala_dbus_method_real_get_default_cname (ValaMethod* base);
 static gpointer vala_dbus_method_parent_class = NULL;
 
 
-ValaDBusMethod* vala_dbus_method_new (const char* name, ValaTypeReference* return_type, ValaSourceReference* source_reference) {
+ValaDBusMethod* vala_dbus_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
 	ValaDBusMethod * self;
-	g_return_val_if_fail (return_type == NULL || VALA_IS_TYPE_REFERENCE (return_type), NULL);
+	g_return_val_if_fail (return_type == NULL || VALA_IS_DATA_TYPE (return_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_DBUS_METHOD, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
