@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,13 +21,13 @@
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
 
-#ifndef __VALAINTERFACEREGISTERFUNCTION_H__
-#define __VALAINTERFACEREGISTERFUNCTION_H__
+#ifndef __GOBJECT_VALAINTERFACEREGISTERFUNCTION_H__
+#define __GOBJECT_VALAINTERFACEREGISTERFUNCTION_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valainterface.h>
-#include <vala/valadatatype.h>
+#include <vala/valatypesymbol.h>
 #include <stdlib.h>
 #include <string.h>
 #include <vala/valasymbol.h>
@@ -52,11 +52,11 @@ typedef struct _ValaInterfaceRegisterFunctionPrivate ValaInterfaceRegisterFuncti
  * C function to register an interface at runtime.
  */
 struct _ValaInterfaceRegisterFunction {
-	ValaTypeRegisterFunction parent;
+	ValaTypeRegisterFunction parent_instance;
 	ValaInterfaceRegisterFunctionPrivate * priv;
 };
 struct _ValaInterfaceRegisterFunctionClass {
-	ValaTypeRegisterFunctionClass parent;
+	ValaTypeRegisterFunctionClass parent_class;
 };
 
 ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterface* iface);
