@@ -1,12 +1,12 @@
 #!/bin/bash
 # testrunner.sh
 #
-# Copyright (C) 2006  Jürg Billeter
+# Copyright (C) 2006-2007  Jürg Billeter
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,33 +20,38 @@
 # Author:
 # 	Jürg Billeter <j@bitron.ch>
 
-builddir=$(dirname $0)
+builddir=$PWD
 topbuilddir=$builddir/..
-vapidir=$topbuilddir/vapi
+srcdir=`dirname $0`
+topsrcdir=$srcdir/..
+vapidir=$topsrcdir/vapi
+
+export G_DEBUG=fatal_warnings
 
 VALAC=$topbuilddir/compiler/valac
 CC="gcc -std=c99"
-CFLAGS="-O0 -g3"
-LDLIBS="-lm"
+CFLAGS="-O0 -g3 -I$topsrcdir -I$topbuilddir"
+LDLIBS="-lm ../gee/.libs/libgee.a"
 
 CODE=0
 
 for testcasesource in "$@"
 do
-	testcase=${testcasesource/.vala/}
-	if ! $VALAC --vapidir "$vapidir" $testcase.vala > $testcase.err 2>&1 
+	testsrc=${testcasesource/.vala/}
+	testbuild=`basename "$testsrc"`
+	if ! $VALAC --vapidir "$vapidir" --pkg gee-1.0 --basedir $topsrcdir -d $topbuilddir $testsrc.vala > $testbuild.err 2>&1
 	then
 		CODE=1
 		continue
 	fi
-	if ! $CC $CFLAGS $(pkg-config --cflags --libs gobject-2.0) $LDLIBS -o $testcase $testcase.c > $testcase.err 2>&1 
+	if ! $CC $CFLAGS $testbuild.c $(pkg-config --cflags --libs gobject-2.0) -o $testbuild $LDLIBS > $testbuild.err 2>&1
 	then
 		CODE=1
 		continue
 	fi
-	if ./$testcase | tee $testcase.err | cmp -s $testcase.out 
+	if ./$testbuild | tee $testbuild.err | cmp -s $testsrc.exp
 	then
-		rm $testcase.err
+		rm $testbuild.c $testbuild.h $testbuild $testbuild.err
 	else
 		CODE=1
 	fi
