@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,15 +21,17 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAARRAY_H__
-#define __VALAARRAY_H__
+#ifndef __VALA_VALAARRAY_H__
+#define __VALA_VALAARRAY_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <vala/valadatatype.h>
+#include <gee/collection.h>
+#include <vala/valatypesymbol.h>
 #include <vala/valacodenode.h>
+#include <vala/valaarraymovemethod.h>
 
 G_BEGIN_DECLS
 
@@ -47,24 +49,25 @@ typedef struct _ValaArrayPrivate ValaArrayPrivate;
  * Represents an array type i.e. everything with direct accessable elements.
  */
 struct _ValaArray {
-	ValaDataType parent;
+	ValaTypesymbol parent_instance;
 	ValaArrayPrivate * priv;
 };
 struct _ValaArrayClass {
-	ValaDataTypeClass parent;
+	ValaTypesymbolClass parent_class;
 };
 
-ValaArray* vala_array_new (ValaDataType* _element_type, gint _rank, ValaSourceReference* _source_reference);
+ValaArray* vala_array_new (ValaTypesymbol* _element_type, gint _rank, ValaSourceReference* _source_reference);
 ValaArray* vala_array_new_with_type_parameter (ValaTypeParameter* _element_type_parameter, gint _rank, ValaSourceReference* _source_reference);
 ValaArrayLengthField* vala_array_get_length_field (ValaArray* self);
 ValaArrayResizeMethod* vala_array_get_resize_method (ValaArray* self);
-ValaDataType* vala_array_get_element_type (ValaArray* self);
-void vala_array_set_element_type (ValaArray* self, ValaDataType* value);
+ValaArrayMoveMethod* vala_array_get_move_method (ValaArray* self);
+ValaTypesymbol* vala_array_get_element_type (ValaArray* self);
+void vala_array_set_element_type (ValaArray* self, ValaTypesymbol* value);
 ValaTypeParameter* vala_array_get_element_type_parameter (ValaArray* self);
 void vala_array_set_element_type_parameter (ValaArray* self, ValaTypeParameter* value);
 gint vala_array_get_rank (ValaArray* self);
 void vala_array_set_rank (ValaArray* self, gint value);
-GType vala_array_get_type ();
+GType vala_array_get_type (void);
 
 G_END_DECLS
 
