@@ -25,16 +25,16 @@
 #include <gee/arraylist.h>
 #include <gee/collection.h>
 #include <gee/readonlylist.h>
-#include <vala/valatypereference.h>
 #include <vala/valainitializerlist.h>
+#include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaArrayCreationExpressionPrivate {
-	ValaTypeReference* _element_type;
 	gint _rank;
 	GeeList* sizes;
 	ValaInitializerList* _initializer_list;
+	ValaDataType* _element_type;
 };
 #define VALA_ARRAY_CREATION_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ARRAY_CREATION_EXPRESSION, ValaArrayCreationExpressionPrivate))
 enum  {
@@ -45,6 +45,8 @@ enum  {
 };
 static void vala_array_creation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_array_creation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static gboolean vala_array_creation_expression_real_is_pure (ValaExpression* base);
+static void vala_array_creation_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_array_creation_expression_parent_class = NULL;
 static void vala_array_creation_expression_dispose (GObject * obj);
 
@@ -54,7 +56,7 @@ static void vala_array_creation_expression_dispose (GObject * obj);
  */
 void vala_array_creation_expression_append_size (ValaArrayCreationExpression* self, ValaExpression* size) {
 	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self));
-	g_return_if_fail (VALA_IS_EXPRESSION (size));
+	g_return_if_fail (size == NULL || VALA_IS_EXPRESSION (size));
 	gee_collection_add (GEE_COLLECTION (self->priv->sizes), size);
 }
 
@@ -64,23 +66,23 @@ void vala_array_creation_expression_append_size (ValaArrayCreationExpression* se
  */
 GeeList* vala_array_creation_expression_get_sizes (ValaArrayCreationExpression* self) {
 	g_return_val_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (g_object_ref, g_object_unref, self->priv->sizes));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, self->priv->sizes));
 }
 
 
-ValaArrayCreationExpression* vala_array_creation_expression_new (ValaTypeReference* element_type, gint rank, ValaInitializerList* initializer_list, ValaSourceReference* source_reference) {
+ValaArrayCreationExpression* vala_array_creation_expression_new (ValaDataType* element_type, gint rank, ValaInitializerList* initializer_list, ValaSourceReference* source_reference) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaArrayCreationExpression * self;
-	g_return_val_if_fail (element_type == NULL || VALA_IS_TYPE_REFERENCE (element_type), NULL);
+	g_return_val_if_fail (element_type == NULL || VALA_IS_DATA_TYPE (element_type), NULL);
 	g_return_val_if_fail (initializer_list == NULL || VALA_IS_INITIALIZER_LIST (initializer_list), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 3);
+	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
-	(__params_it->name = "element-type", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, element_type), __params_it++);
 	(__params_it->name = "rank", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, rank), __params_it++);
 	(__params_it->name = "initializer-list", g_value_init (&__params_it->value, VALA_TYPE_INITIALIZER_LIST), g_value_set_object (&__params_it->value, initializer_list), __params_it++);
 	self = g_object_newv (VALA_TYPE_ARRAY_CREATION_EXPRESSION, __params_it - __params, __params);
+	vala_array_creation_expression_set_element_type (self, element_type);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	while (__params_it > __params) {
 		--__params_it;
@@ -94,7 +96,7 @@ ValaArrayCreationExpression* vala_array_creation_expression_new (ValaTypeReferen
 static void vala_array_creation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaArrayCreationExpression * self;
 	self = VALA_ARRAY_CREATION_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	if (vala_array_creation_expression_get_element_type (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_array_creation_expression_get_element_type (self)), visitor);
 	}
@@ -122,24 +124,43 @@ static void vala_array_creation_expression_real_accept_children (ValaCodeNode* b
 static void vala_array_creation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaArrayCreationExpression * self;
 	self = VALA_ARRAY_CREATION_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_array_creation_expression (visitor, self);
 }
 
 
-ValaTypeReference* vala_array_creation_expression_get_element_type (ValaArrayCreationExpression* self) {
+static gboolean vala_array_creation_expression_real_is_pure (ValaExpression* base) {
+	ValaArrayCreationExpression * self;
+	self = VALA_ARRAY_CREATION_EXPRESSION (base);
+	return FALSE;
+}
+
+
+static void vala_array_creation_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
+	ValaArrayCreationExpression * self;
+	self = VALA_ARRAY_CREATION_EXPRESSION (base);
+	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	if (vala_array_creation_expression_get_element_type (self) == old_type) {
+		vala_array_creation_expression_set_element_type (self, new_type);
+	}
+}
+
+
+ValaDataType* vala_array_creation_expression_get_element_type (ValaArrayCreationExpression* self) {
 	g_return_val_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self), NULL);
 	return self->priv->_element_type;
 }
 
 
-void vala_array_creation_expression_set_element_type (ValaArrayCreationExpression* self, ValaTypeReference* value) {
-	ValaTypeReference* _tmp2;
-	ValaTypeReference* _tmp1;
+void vala_array_creation_expression_set_element_type (ValaArrayCreationExpression* self, ValaDataType* value) {
+	ValaDataType* _tmp2;
+	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_element_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL))), _tmp2);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_element_type), VALA_CODE_NODE (self));
 }
 
 
@@ -219,7 +240,9 @@ static void vala_array_creation_expression_class_init (ValaArrayCreationExpressi
 	G_OBJECT_CLASS (klass)->dispose = vala_array_creation_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_array_creation_expression_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_array_creation_expression_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_CREATION_EXPRESSION_ELEMENT_TYPE, g_param_spec_object ("element-type", "element-type", "element-type", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_array_creation_expression_real_is_pure;
+	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_array_creation_expression_real_replace_type;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_CREATION_EXPRESSION_ELEMENT_TYPE, g_param_spec_object ("element-type", "element-type", "element-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_CREATION_EXPRESSION_RANK, g_param_spec_int ("rank", "rank", "rank", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_CREATION_EXPRESSION_INITIALIZER_LIST, g_param_spec_object ("initializer-list", "initializer-list", "initializer-list", VALA_TYPE_INITIALIZER_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
@@ -227,16 +250,16 @@ static void vala_array_creation_expression_class_init (ValaArrayCreationExpressi
 
 static void vala_array_creation_expression_init (ValaArrayCreationExpression * self) {
 	self->priv = VALA_ARRAY_CREATION_EXPRESSION_GET_PRIVATE (self);
-	self->priv->sizes = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->sizes = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
 static void vala_array_creation_expression_dispose (GObject * obj) {
 	ValaArrayCreationExpression * self;
 	self = VALA_ARRAY_CREATION_EXPRESSION (obj);
-	(self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL)));
 	(self->priv->sizes == NULL ? NULL : (self->priv->sizes = (g_object_unref (self->priv->sizes), NULL)));
 	(self->priv->_initializer_list == NULL ? NULL : (self->priv->_initializer_list = (g_object_unref (self->priv->_initializer_list), NULL)));
+	(self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL)));
 	G_OBJECT_CLASS (vala_array_creation_expression_parent_class)->dispose (obj);
 }
 
