@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaarraylengthfield.h"
+#include <vala/valaarraylengthfield.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
 
@@ -35,8 +35,7 @@ static gpointer vala_array_length_field_parent_class = NULL;
  *
  * @return newly created field
  */
-ValaArrayLengthField* vala_array_length_field_new (ValaSourceReference* source_reference)
-{
+ValaArrayLengthField* vala_array_length_field_new (ValaSourceReference* source_reference) {
 	ValaArrayLengthField * self;
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ARRAY_LENGTH_FIELD, 0, NULL);
@@ -46,19 +45,16 @@ ValaArrayLengthField* vala_array_length_field_new (ValaSourceReference* source_r
 }
 
 
-static void vala_array_length_field_class_init (ValaArrayLengthFieldClass * klass)
-{
+static void vala_array_length_field_class_init (ValaArrayLengthFieldClass * klass) {
 	vala_array_length_field_parent_class = g_type_class_peek_parent (klass);
 }
 
 
-static void vala_array_length_field_init (ValaArrayLengthField * self)
-{
+static void vala_array_length_field_init (ValaArrayLengthField * self) {
 }
 
 
-GType vala_array_length_field_get_type (void)
-{
+GType vala_array_length_field_get_type (void) {
 	static GType vala_array_length_field_type_id = 0;
 	if (G_UNLIKELY (vala_array_length_field_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayLengthFieldClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_length_field_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayLengthField), 0, (GInstanceInitFunc) vala_array_length_field_init };
