@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,10 +20,9 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaarrayresizemethod.h"
+#include <vala/valaarrayresizemethod.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
-#include <vala/valaarrayresizemethod.h>
 
 enum  {
 	VALA_ARRAY_RESIZE_METHOD_DUMMY_PROPERTY
@@ -36,8 +35,7 @@ static gpointer vala_array_resize_method_parent_class = NULL;
  *
  * @return newly created method
  */
-ValaArrayResizeMethod* vala_array_resize_method_new (ValaSourceReference* source_reference)
-{
+ValaArrayResizeMethod* vala_array_resize_method_new (ValaSourceReference* source_reference) {
 	ValaArrayResizeMethod * self;
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ARRAY_RESIZE_METHOD, 0, NULL);
@@ -47,19 +45,16 @@ ValaArrayResizeMethod* vala_array_resize_method_new (ValaSourceReference* source
 }
 
 
-static void vala_array_resize_method_class_init (ValaArrayResizeMethodClass * klass)
-{
+static void vala_array_resize_method_class_init (ValaArrayResizeMethodClass * klass) {
 	vala_array_resize_method_parent_class = g_type_class_peek_parent (klass);
 }
 
 
-static void vala_array_resize_method_init (ValaArrayResizeMethod * self)
-{
+static void vala_array_resize_method_init (ValaArrayResizeMethod * self) {
 }
 
 
-GType vala_array_resize_method_get_type (void)
-{
+GType vala_array_resize_method_get_type (void) {
 	static GType vala_array_resize_method_type_id = 0;
 	if (G_UNLIKELY (vala_array_resize_method_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayResizeMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_resize_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayResizeMethod), 0, (GInstanceInitFunc) vala_array_resize_method_init };
