@@ -38,7 +38,8 @@ enum  {
 };
 static void vala_assignment_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_assignment_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static void vala_assignment_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
+static void vala_assignment_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
+static gboolean vala_assignment_real_is_pure (ValaExpression* base);
 static gpointer vala_assignment_parent_class = NULL;
 static void vala_assignment_dispose (GObject * obj);
 
@@ -56,8 +57,8 @@ ValaAssignment* vala_assignment_new (ValaExpression* left, ValaExpression* right
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaAssignment * self;
-	g_return_val_if_fail (VALA_IS_EXPRESSION (left), NULL);
-	g_return_val_if_fail (VALA_IS_EXPRESSION (right), NULL);
+	g_return_val_if_fail (left == NULL || VALA_IS_EXPRESSION (left), NULL);
+	g_return_val_if_fail (right == NULL || VALA_IS_EXPRESSION (right), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
@@ -78,7 +79,7 @@ ValaAssignment* vala_assignment_new (ValaExpression* left, ValaExpression* right
 static void vala_assignment_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaAssignment * self;
 	self = VALA_ASSIGNMENT (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_assignment (visitor, self);
 }
 
@@ -86,26 +87,33 @@ static void vala_assignment_real_accept (ValaCodeNode* base, ValaCodeVisitor* vi
 static void vala_assignment_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaAssignment * self;
 	self = VALA_ASSIGNMENT (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_assignment_get_left (self)), visitor);
 	vala_code_node_accept (VALA_CODE_NODE (vala_assignment_get_right (self)), visitor);
 }
 
 
-static void vala_assignment_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node) {
+static void vala_assignment_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaAssignment * self;
 	self = VALA_ASSIGNMENT (base);
-	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
-	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
-	if (VALA_CODE_NODE (vala_assignment_get_left (self)) == old_node) {
-		vala_assignment_set_left (self, VALA_EXPRESSION (new_node));
+	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	if (vala_assignment_get_left (self) == old_node) {
+		vala_assignment_set_left (self, new_node);
 	}
-	if (VALA_CODE_NODE (vala_assignment_get_right (self)) == old_node) {
-		vala_assignment_set_right (self, VALA_EXPRESSION (new_node));
+	if (vala_assignment_get_right (self) == old_node) {
+		vala_assignment_set_right (self, new_node);
 	}
 }
 
 
+static gboolean vala_assignment_real_is_pure (ValaExpression* base) {
+	ValaAssignment * self;
+	self = VALA_ASSIGNMENT (base);
+	return FALSE;
+}
+
+
 ValaExpression* vala_assignment_get_left (ValaAssignment* self) {
 	g_return_val_if_fail (VALA_IS_ASSIGNMENT (self), NULL);
 	return self->priv->_left;
@@ -113,10 +121,12 @@ ValaExpression* vala_assignment_get_left (ValaAssignment* self) {
 
 
 void vala_assignment_set_left (ValaAssignment* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_ASSIGNMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_left = (_tmp1 = g_object_ref (value), (self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL))), _tmp1);
+	self->priv->_left = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_left == NULL ? NULL : (self->priv->_left = (g_object_unref (self->priv->_left), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_left), VALA_CODE_NODE (self));
 }
 
@@ -140,10 +150,12 @@ ValaExpression* vala_assignment_get_right (ValaAssignment* self) {
 
 
 void vala_assignment_set_right (ValaAssignment* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_ASSIGNMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_right = (_tmp1 = g_object_ref (value), (self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL))), _tmp1);
+	self->priv->_right = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_right == NULL ? NULL : (self->priv->_right = (g_object_unref (self->priv->_right), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_right), VALA_CODE_NODE (self));
 }
 
@@ -196,7 +208,8 @@ static void vala_assignment_class_init (ValaAssignmentClass * klass) {
 	G_OBJECT_CLASS (klass)->dispose = vala_assignment_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_assignment_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_assignment_real_accept_children;
-	VALA_CODE_NODE_CLASS (klass)->replace = vala_assignment_real_replace;
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_assignment_real_replace_expression;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_assignment_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ASSIGNMENT_LEFT, g_param_spec_object ("left", "left", "left", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ASSIGNMENT_OPERATOR, g_param_spec_int ("operator", "operator", "operator", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ASSIGNMENT_RIGHT, g_param_spec_object ("right", "right", "right", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
