@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAATTRIBUTE_H__
-#define __VALAATTRIBUTE_H__
+#ifndef __VALA_VALAATTRIBUTE_H__
+#define __VALA_VALAATTRIBUTE_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -46,12 +46,12 @@ typedef struct _ValaAttributePrivate ValaAttributePrivate;
  * Represents an attribute specified in the source code.
  */
 struct _ValaAttribute {
-	ValaCodeNode parent;
+	ValaCodeNode parent_instance;
 	ValaAttributePrivate * priv;
 	GeeList* args;
 };
 struct _ValaAttributeClass {
-	ValaCodeNodeClass parent;
+	ValaCodeNodeClass parent_class;
 };
 
 ValaAttribute* vala_attribute_new (const char* name, ValaSourceReference* source_reference);
