@@ -1,6 +1,6 @@
 /* valaattributeprocessor.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -35,7 +35,8 @@ static void vala_attribute_processor_real_visit_enum (ValaCodeVisitor* base, Val
 static void vala_attribute_processor_real_visit_method (ValaCodeVisitor* base, ValaMethod* m);
 static void vala_attribute_processor_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m);
 static void vala_attribute_processor_real_visit_property (ValaCodeVisitor* base, ValaProperty* prop);
-static void vala_attribute_processor_real_visit_callback (ValaCodeVisitor* base, ValaCallback* cb);
+static void vala_attribute_processor_real_visit_delegate (ValaCodeVisitor* base, ValaDelegate* d);
+static void vala_attribute_processor_real_visit_constant (ValaCodeVisitor* base, ValaConstant* c);
 static void vala_attribute_processor_real_visit_field (ValaCodeVisitor* base, ValaField* f);
 static void vala_attribute_processor_real_visit_signal (ValaCodeVisitor* base, ValaSignal* sig);
 static gpointer vala_attribute_processor_parent_class = NULL;
@@ -48,7 +49,7 @@ static gpointer vala_attribute_processor_parent_class = NULL;
  */
 void vala_attribute_processor_process (ValaAttributeProcessor* self, ValaCodeContext* context) {
 	g_return_if_fail (VALA_IS_ATTRIBUTE_PROCESSOR (self));
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (context));
+	g_return_if_fail (context == NULL || VALA_IS_CODE_CONTEXT (context));
 	vala_code_context_accept (context, VALA_CODE_VISITOR (self));
 }
 
@@ -56,7 +57,7 @@ void vala_attribute_processor_process (ValaAttributeProcessor* self, ValaCodeCon
 static void vala_attribute_processor_real_visit_source_file (ValaCodeVisitor* base, ValaSourceFile* source_file) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (VALA_IS_SOURCE_FILE (source_file));
+	g_return_if_fail (source_file == NULL || VALA_IS_SOURCE_FILE (source_file));
 	vala_source_file_accept_children (source_file, VALA_CODE_VISITOR (self));
 }
 
@@ -64,7 +65,7 @@ static void vala_attribute_processor_real_visit_source_file (ValaCodeVisitor* ba
 static void vala_attribute_processor_real_visit_namespace (ValaCodeVisitor* base, ValaNamespace* ns) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (VALA_IS_NAMESPACE (ns));
+	g_return_if_fail (ns == NULL || VALA_IS_NAMESPACE (ns));
 	vala_namespace_process_attributes (ns);
 	{
 		GeeCollection* ns_collection;
@@ -88,7 +89,7 @@ static void vala_attribute_processor_real_visit_namespace (ValaCodeVisitor* base
 static void vala_attribute_processor_real_visit_class (ValaCodeVisitor* base, ValaClass* cl) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (VALA_IS_CLASS (cl));
+	g_return_if_fail (cl == NULL || VALA_IS_CLASS (cl));
 	vala_class_process_attributes (cl);
 	vala_code_node_accept_children (VALA_CODE_NODE (cl), VALA_CODE_VISITOR (self));
 }
@@ -97,7 +98,7 @@ static void vala_attribute_processor_real_visit_class (ValaCodeVisitor* base, Va
 static void vala_attribute_processor_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (VALA_IS_STRUCT (st));
+	g_return_if_fail (st == NULL || VALA_IS_STRUCT (st));
 	vala_struct_process_attributes (st);
 	vala_code_node_accept_children (VALA_CODE_NODE (st), VALA_CODE_VISITOR (self));
 }
@@ -106,7 +107,7 @@ static void vala_attribute_processor_real_visit_struct (ValaCodeVisitor* base, V
 static void vala_attribute_processor_real_visit_interface (ValaCodeVisitor* base, ValaInterface* iface) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (VALA_IS_INTERFACE (iface));
+	g_return_if_fail (iface == NULL || VALA_IS_INTERFACE (iface));
 	vala_interface_process_attributes (iface);
 	vala_code_node_accept_children (VALA_CODE_NODE (iface), VALA_CODE_VISITOR (self));
 }
@@ -115,7 +116,7 @@ static void vala_attribute_processor_real_visit_interface (ValaCodeVisitor* base
 static void vala_attribute_processor_real_visit_enum (ValaCodeVisitor* base, ValaEnum* en) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (VALA_IS_ENUM (en));
+	g_return_if_fail (en == NULL || VALA_IS_ENUM (en));
 	vala_enum_process_attributes (en);
 }
 
@@ -123,7 +124,7 @@ static void vala_attribute_processor_real_visit_enum (ValaCodeVisitor* base, Val
 static void vala_attribute_processor_real_visit_method (ValaCodeVisitor* base, ValaMethod* m) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (VALA_IS_METHOD (m));
+	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
 	vala_method_process_attributes (m);
 }
 
@@ -131,7 +132,7 @@ static void vala_attribute_processor_real_visit_method (ValaCodeVisitor* base, V
 static void vala_attribute_processor_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (VALA_IS_CREATION_METHOD (m));
+	g_return_if_fail (m == NULL || VALA_IS_CREATION_METHOD (m));
 	vala_method_process_attributes (VALA_METHOD (m));
 }
 
@@ -139,23 +140,31 @@ static void vala_attribute_processor_real_visit_creation_method (ValaCodeVisitor
 static void vala_attribute_processor_real_visit_property (ValaCodeVisitor* base, ValaProperty* prop) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (VALA_IS_PROPERTY (prop));
+	g_return_if_fail (prop == NULL || VALA_IS_PROPERTY (prop));
 	vala_property_process_attributes (prop);
 }
 
 
-static void vala_attribute_processor_real_visit_callback (ValaCodeVisitor* base, ValaCallback* cb) {
+static void vala_attribute_processor_real_visit_delegate (ValaCodeVisitor* base, ValaDelegate* d) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (VALA_IS_CALLBACK (cb));
-	vala_callback_process_attributes (cb);
+	g_return_if_fail (d == NULL || VALA_IS_DELEGATE (d));
+	vala_delegate_process_attributes (d);
+}
+
+
+static void vala_attribute_processor_real_visit_constant (ValaCodeVisitor* base, ValaConstant* c) {
+	ValaAttributeProcessor * self;
+	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	g_return_if_fail (c == NULL || VALA_IS_CONSTANT (c));
+	vala_constant_process_attributes (c);
 }
 
 
 static void vala_attribute_processor_real_visit_field (ValaCodeVisitor* base, ValaField* f) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (VALA_IS_FIELD (f));
+	g_return_if_fail (f == NULL || VALA_IS_FIELD (f));
 	vala_field_process_attributes (f);
 }
 
@@ -163,7 +172,7 @@ static void vala_attribute_processor_real_visit_field (ValaCodeVisitor* base, Va
 static void vala_attribute_processor_real_visit_signal (ValaCodeVisitor* base, ValaSignal* sig) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (VALA_IS_SIGNAL (sig));
+	g_return_if_fail (sig == NULL || VALA_IS_SIGNAL (sig));
 	vala_signal_process_attributes (sig);
 }
 
@@ -189,7 +198,8 @@ static void vala_attribute_processor_class_init (ValaAttributeProcessorClass * k
 	VALA_CODE_VISITOR_CLASS (klass)->visit_method = vala_attribute_processor_real_visit_method;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_creation_method = vala_attribute_processor_real_visit_creation_method;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_property = vala_attribute_processor_real_visit_property;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_callback = vala_attribute_processor_real_visit_callback;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_delegate = vala_attribute_processor_real_visit_delegate;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_constant = vala_attribute_processor_real_visit_constant;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_field = vala_attribute_processor_real_visit_field;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_signal = vala_attribute_processor_real_visit_signal;
 }
