@@ -46,11 +46,11 @@ typedef struct _ValaBaseAccessPrivate ValaBaseAccessPrivate;
  * Represents an access to base class members in the source code.
  */
 struct _ValaBaseAccess {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaBaseAccessPrivate * priv;
 };
 struct _ValaBaseAccessClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 
 ValaBaseAccess* vala_base_access_new (ValaSourceReference* source);
