@@ -1,11 +1,11 @@
 /* valabinaryexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,14 +20,12 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALABINARYEXPRESSION_H__
-#define __VALABINARYEXPRESSION_H__
-typedef struct _ValaBinaryExpressionPrivate ValaBinaryExpressionPrivate;
+#ifndef __VALA_VALABINARYEXPRESSION_H__
+#define __VALA_VALABINARYEXPRESSION_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valaexpression.h>
-#include <vala/valabinaryexpression.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -40,6 +38,7 @@ G_BEGIN_DECLS
 #define VALA_IS_BINARY_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_BINARY_EXPRESSION))
 #define VALA_BINARY_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_BINARY_EXPRESSION, ValaBinaryExpressionClass))
 
+typedef struct _ValaBinaryExpressionPrivate ValaBinaryExpressionPrivate;
 
 /**
  * Represents an expression with two operands in the source code.
@@ -47,11 +46,11 @@ G_BEGIN_DECLS
  * Supports +, -, *, /, %, <<, >>, <, >, <=, >=, ==, !=, &, |, ^, &&, ||.
  */
 struct _ValaBinaryExpression {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaBinaryExpressionPrivate * priv;
 };
 struct _ValaBinaryExpressionClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 typedef enum  {
 	VALA_BINARY_OPERATOR_PLUS,
@@ -71,7 +70,8 @@ typedef enum  {
 	VALA_BINARY_OPERATOR_BITWISE_OR,
 	VALA_BINARY_OPERATOR_BITWISE_XOR,
 	VALA_BINARY_OPERATOR_AND,
-	VALA_BINARY_OPERATOR_OR
+	VALA_BINARY_OPERATOR_OR,
+	VALA_BINARY_OPERATOR_IN
 } ValaBinaryOperator;
 
 ValaBinaryExpression* vala_binary_expression_new (ValaBinaryOperator op, ValaExpression* _left, ValaExpression* _right, ValaSourceReference* source);
@@ -81,7 +81,7 @@ ValaExpression* vala_binary_expression_get_left (ValaBinaryExpression* self);
 void vala_binary_expression_set_left (ValaBinaryExpression* self, ValaExpression* value);
 ValaExpression* vala_binary_expression_get_right (ValaBinaryExpression* self);
 void vala_binary_expression_set_right (ValaBinaryExpression* self, ValaExpression* value);
-GType vala_binary_expression_get_type ();
+GType vala_binary_expression_get_type (void);
 
 G_END_DECLS
 
