@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALABLOCK_H__
-#define __VALABLOCK_H__
+#ifndef __VALA_VALABLOCK_H__
+#define __VALA_VALABLOCK_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -46,11 +46,11 @@ typedef struct _ValaBlockPrivate ValaBlockPrivate;
  * Represents a source code block.
  */
 struct _ValaBlock {
-	ValaSymbol parent;
+	ValaSymbol parent_instance;
 	ValaBlockPrivate * priv;
 };
 struct _ValaBlockClass {
-	ValaSymbolClass parent;
+	ValaSymbolClass parent_class;
 };
 
 ValaBlock* vala_block_new (ValaSourceReference* source_reference);
