@@ -1,11 +1,11 @@
 /* valaclass.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,15 +20,15 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACLASS_H__
-#define __VALACLASS_H__
+#ifndef __VALA_VALACLASS_H__
+#define __VALA_VALACLASS_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
 #include <gee/collection.h>
-#include <vala/valadatatype.h>
+#include <vala/valatypesymbol.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -47,15 +47,15 @@ typedef struct _ValaClassPrivate ValaClassPrivate;
  * Represents a class declaration in the source code.
  */
 struct _ValaClass {
-	ValaDataType parent;
+	ValaTypesymbol parent_instance;
 	ValaClassPrivate * priv;
 };
 struct _ValaClassClass {
-	ValaDataTypeClass parent;
+	ValaTypesymbolClass parent_class;
 };
 
 ValaClass* vala_class_new (const char* name, ValaSourceReference* source_reference);
-void vala_class_add_base_type (ValaClass* self, ValaTypeReference* type);
+void vala_class_add_base_type (ValaClass* self, ValaDataType* type);
 GeeCollection* vala_class_get_base_types (ValaClass* self);
 void vala_class_add_type_parameter (ValaClass* self, ValaTypeParameter* p);
 GeeCollection* vala_class_get_type_parameters (ValaClass* self);
@@ -70,8 +70,15 @@ void vala_class_add_signal (ValaClass* self, ValaSignal* sig);
 GeeCollection* vala_class_get_signals (ValaClass* self);
 void vala_class_add_class (ValaClass* self, ValaClass* cl);
 void vala_class_add_struct (ValaClass* self, ValaStruct* st);
+char* vala_class_get_default_cname (ValaClass* self);
 void vala_class_set_cname (ValaClass* self, const char* cname);
 void vala_class_process_attributes (ValaClass* self);
+void vala_class_set_type_id (ValaClass* self, const char* type_id);
+void vala_class_set_ref_function (ValaClass* self, const char* name);
+void vala_class_set_unref_function (ValaClass* self, const char* name);
+void vala_class_set_dup_function (ValaClass* self, const char* name);
+char* vala_class_get_default_free_function (ValaClass* self);
+void vala_class_set_free_function (ValaClass* self, const char* name);
 ValaClass* vala_class_get_base_class (ValaClass* self);
 void vala_class_set_base_class (ValaClass* self, ValaClass* value);
 gboolean vala_class_get_is_abstract (ValaClass* self);
