@@ -1,6 +1,6 @@
 /* valacodenode.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -54,10 +54,8 @@ typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 typedef struct _ValaClass ValaClass;
 typedef struct _ValaClassClass ValaClassClass;
-typedef struct _ValaDataType ValaDataType;
-typedef struct _ValaDataTypeClass ValaDataTypeClass;
-typedef struct _ValaPointer ValaPointer;
-typedef struct _ValaPointerClass ValaPointerClass;
+typedef struct _ValaTypesymbol ValaTypesymbol;
+typedef struct _ValaTypesymbolClass ValaTypesymbolClass;
 typedef struct _ValaArray ValaArray;
 typedef struct _ValaArrayClass ValaArrayClass;
 typedef struct _ValaTypeParameter ValaTypeParameter;
@@ -68,10 +66,8 @@ typedef struct _ValaField ValaField;
 typedef struct _ValaFieldClass ValaFieldClass;
 typedef struct _ValaMember ValaMember;
 typedef struct _ValaMemberClass ValaMemberClass;
-typedef struct _ValaInvokable ValaInvokable;
-typedef struct _ValaInvokableIface ValaInvokableIface;
-typedef struct _ValaTypeReference ValaTypeReference;
-typedef struct _ValaTypeReferenceClass ValaTypeReferenceClass;
+typedef struct _ValaDataType ValaDataType;
+typedef struct _ValaDataTypeClass ValaDataTypeClass;
 typedef struct _ValaArrayResizeMethod ValaArrayResizeMethod;
 typedef struct _ValaArrayResizeMethodClass ValaArrayResizeMethodClass;
 typedef struct _ValaMethod ValaMethod;
@@ -92,8 +88,8 @@ typedef struct _ValaPropertyAccessor ValaPropertyAccessor;
 typedef struct _ValaPropertyAccessorClass ValaPropertyAccessorClass;
 typedef struct _ValaSignal ValaSignal;
 typedef struct _ValaSignalClass ValaSignalClass;
-typedef struct _ValaCallback ValaCallback;
-typedef struct _ValaCallbackClass ValaCallbackClass;
+typedef struct _ValaDelegate ValaDelegate;
+typedef struct _ValaDelegateClass ValaDelegateClass;
 typedef struct _ValaStruct ValaStruct;
 typedef struct _ValaStructClass ValaStructClass;
 typedef struct _ValaConstructor ValaConstructor;
@@ -231,21 +227,23 @@ typedef struct _ValaCodeNodePrivate ValaCodeNodePrivate;
  * compilation process.
  */
 struct _ValaCodeNode {
-	GObject parent;
+	GObject parent_instance;
 	ValaCodeNodePrivate * priv;
 	GList* attributes;
 };
 struct _ValaCodeNodeClass {
-	GObjectClass parent;
+	GObjectClass parent_class;
 	void (*accept) (ValaCodeNode* self, ValaCodeVisitor* visitor);
 	void (*accept_children) (ValaCodeNode* self, ValaCodeVisitor* visitor);
-	void (*replace) (ValaCodeNode* self, ValaCodeNode* old_node, ValaCodeNode* new_node);
+	void (*replace_type) (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
+	void (*replace_expression) (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
 	char* (*to_string) (ValaCodeNode* self);
 };
 
 void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 void vala_code_node_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor);
-void vala_code_node_replace (ValaCodeNode* self, ValaCodeNode* old_node, ValaCodeNode* new_node);
+void vala_code_node_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
+void vala_code_node_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
 ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* name);
 char* vala_code_node_to_string (ValaCodeNode* self);
 ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self);
