@@ -47,17 +47,18 @@ typedef struct _ValaConstantPrivate ValaConstantPrivate;
  * Represents a type member with a constant value.
  */
 struct _ValaConstant {
-	ValaMember parent;
+	ValaMember parent_instance;
 	ValaConstantPrivate * priv;
 };
 struct _ValaConstantClass {
-	ValaMemberClass parent;
+	ValaMemberClass parent_class;
 };
 
-ValaConstant* vala_constant_new (const char* name, ValaTypeReference* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference);
+ValaConstant* vala_constant_new (const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference);
 char* vala_constant_get_cname (ValaConstant* self);
-ValaTypeReference* vala_constant_get_type_reference (ValaConstant* self);
-void vala_constant_set_type_reference (ValaConstant* self, ValaTypeReference* value);
+void vala_constant_process_attributes (ValaConstant* self);
+ValaDataType* vala_constant_get_type_reference (ValaConstant* self);
+void vala_constant_set_type_reference (ValaConstant* self, ValaDataType* value);
 ValaExpression* vala_constant_get_initializer (ValaConstant* self);
 void vala_constant_set_initializer (ValaConstant* self, ValaExpression* value);
 GType vala_constant_get_type (void);
