@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,12 +20,12 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACONSTRUCTOR_H__
-#define __VALACONSTRUCTOR_H__
-typedef struct _ValaConstructorPrivate ValaConstructorPrivate;
+#ifndef __VALA_VALACONSTRUCTOR_H__
+#define __VALA_VALACONSTRUCTOR_H__
 
 #include <glib.h>
 #include <glib-object.h>
+#include <vala/valasymbol.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -38,24 +38,27 @@ G_BEGIN_DECLS
 #define VALA_IS_CONSTRUCTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CONSTRUCTOR))
 #define VALA_CONSTRUCTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CONSTRUCTOR, ValaConstructorClass))
 
+typedef struct _ValaConstructorPrivate ValaConstructorPrivate;
 
 /**
  * Represents a class or instance constructor.
  */
 struct _ValaConstructor {
-	ValaCodeNode parent;
+	ValaSymbol parent_instance;
 	ValaConstructorPrivate * priv;
 };
 struct _ValaConstructorClass {
-	ValaCodeNodeClass parent;
+	ValaSymbolClass parent_class;
 };
 
 ValaConstructor* vala_constructor_new (ValaSourceReference* source);
-ValaStatement* vala_constructor_get_body (ValaConstructor* self);
-void vala_constructor_set_body (ValaConstructor* self, ValaStatement* value);
+ValaBlock* vala_constructor_get_body (ValaConstructor* self);
+void vala_constructor_set_body (ValaConstructor* self, ValaBlock* value);
+ValaFormalParameter* vala_constructor_get_this_parameter (ValaConstructor* self);
+void vala_constructor_set_this_parameter (ValaConstructor* self, ValaFormalParameter* value);
 gboolean vala_constructor_get_instance (ValaConstructor* self);
 void vala_constructor_set_instance (ValaConstructor* self, gboolean value);
-GType vala_constructor_get_type ();
+GType vala_constructor_get_type (void);
 
 G_END_DECLS
 
