@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,10 +20,9 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valacontinuestatement.h"
+#include <vala/valacontinuestatement.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
-#include <vala/valacontinuestatement.h>
 
 enum  {
 	VALA_CONTINUE_STATEMENT_DUMMY_PROPERTY
@@ -39,8 +38,7 @@ static ValaStatementIface* vala_continue_statement_vala_statement_parent_iface =
  * @param source reference to source code
  * @return       newly created continue statement
  */
-ValaContinueStatement* vala_continue_statement_new (ValaSourceReference* source)
-{
+ValaContinueStatement* vala_continue_statement_new (ValaSourceReference* source) {
 	ValaContinueStatement * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_CONTINUE_STATEMENT, 0, NULL);
@@ -49,35 +47,30 @@ ValaContinueStatement* vala_continue_statement_new (ValaSourceReference* source)
 }
 
 
-static void vala_continue_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_continue_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaContinueStatement * self;
-	self = ((ValaContinueStatement*) base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = VALA_CONTINUE_STATEMENT (base);
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_continue_statement (visitor, self);
 }
 
 
-static void vala_continue_statement_class_init (ValaContinueStatementClass * klass)
-{
+static void vala_continue_statement_class_init (ValaContinueStatementClass * klass) {
 	vala_continue_statement_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_continue_statement_real_accept;
 }
 
 
-static void vala_continue_statement_vala_statement_interface_init (ValaStatementIface * iface)
-{
+static void vala_continue_statement_vala_statement_interface_init (ValaStatementIface * iface) {
 	vala_continue_statement_vala_statement_parent_iface = g_type_interface_peek_parent (iface);
 }
 
 
-static void vala_continue_statement_init (ValaContinueStatement * self)
-{
+static void vala_continue_statement_init (ValaContinueStatement * self) {
 }
 
 
-GType vala_continue_statement_get_type (void)
-{
+GType vala_continue_statement_get_type (void) {
 	static GType vala_continue_statement_type_id = 0;
 	if (G_UNLIKELY (vala_continue_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaContinueStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_continue_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaContinueStatement), 0, (GInstanceInitFunc) vala_continue_statement_init };
