@@ -44,11 +44,11 @@ typedef struct _ValaDeclarationStatementPrivate ValaDeclarationStatementPrivate;
  * Represents a local variable declaration statement in the source code.
  */
 struct _ValaDeclarationStatement {
-	ValaCodeNode parent;
+	ValaCodeNode parent_instance;
 	ValaDeclarationStatementPrivate * priv;
 };
 struct _ValaDeclarationStatementClass {
-	ValaCodeNodeClass parent;
+	ValaCodeNodeClass parent_class;
 };
 
 ValaDeclarationStatement* vala_declaration_statement_new (ValaLocalVariableDeclaration* decl, ValaSourceReference* source);
