@@ -59,7 +59,7 @@ ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference) {
 static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDestructor * self;
 	self = VALA_DESTRUCTOR (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_destructor (visitor, self);
 }
 
@@ -67,7 +67,7 @@ static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* vi
 static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDestructor * self;
 	self = VALA_DESTRUCTOR (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	if (vala_destructor_get_body (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_destructor_get_body (self)), visitor);
 	}
