@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALADOSTATEMENT_H__
-#define __VALADOSTATEMENT_H__
+#ifndef __VALA_VALADOSTATEMENT_H__
+#define __VALA_VALADOSTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -44,11 +44,11 @@ typedef struct _ValaDoStatementPrivate ValaDoStatementPrivate;
  * Represents a do iteration statement in the source code.
  */
 struct _ValaDoStatement {
-	ValaCodeNode parent;
+	ValaCodeNode parent_instance;
 	ValaDoStatementPrivate * priv;
 };
 struct _ValaDoStatementClass {
-	ValaCodeNodeClass parent;
+	ValaCodeNodeClass parent_class;
 };
 
 ValaDoStatement* vala_do_statement_new (ValaBlock* body, ValaExpression* condition, ValaSourceReference* source_reference);
