@@ -46,11 +46,11 @@ typedef struct _ValaElementAccessPrivate ValaElementAccessPrivate;
  * Represents an array access expression e.g. "a[1,2]".
  */
 struct _ValaElementAccess {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaElementAccessPrivate * priv;
 };
 struct _ValaElementAccessClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 
 void vala_element_access_append_index (ValaElementAccess* self, ValaExpression* index);
