@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,24 +20,25 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaenum.h"
+#include <vala/valaenum.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
-#include <vala/valasourcereference.h>
-#include <vala/valaenum.h>
-#include <vala/valasymbol.h>
 #include <vala/valaenumvalue.h>
-#include <vala/valascope.h>
 #include <vala/valamethod.h>
+#include <vala/valasourcereference.h>
+#include <vala/valasymbol.h>
+#include <vala/valascope.h>
 #include <vala/valacreationmethod.h>
 #include <vala/valareport.h>
 #include <vala/valaformalparameter.h>
-#include <vala/valatypereference.h>
+#include <vala/valavaluetype.h>
+#include <vala/valadatatype.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
 struct _ValaEnumPrivate {
+	gboolean _is_flags;
 	gboolean _error_domain;
 	GeeList* values;
 	GeeList* methods;
@@ -49,23 +50,24 @@ struct _ValaEnumPrivate {
 #define VALA_ENUM_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ENUM, ValaEnumPrivate))
 enum  {
 	VALA_ENUM_DUMMY_PROPERTY,
+	VALA_ENUM_IS_FLAGS,
 	VALA_ENUM_ERROR_DOMAIN
 };
 static void vala_enum_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static char* vala_enum_real_get_cname (ValaDataType* base, gboolean const_type);
+static char* vala_enum_real_get_cname (ValaTypesymbol* base, gboolean const_type);
 static char* vala_enum_real_get_lower_case_cprefix (ValaSymbol* base);
 static char* vala_enum_get_lower_case_csuffix (ValaEnum* self);
 static char* vala_enum_real_get_lower_case_cname (ValaSymbol* base, const char* infix);
-static char* vala_enum_real_get_upper_case_cname (ValaDataType* base, const char* infix);
-static gboolean vala_enum_real_is_reference_type (ValaDataType* base);
+static char* vala_enum_real_get_upper_case_cname (ValaTypesymbol* base, const char* infix);
+static gboolean vala_enum_real_is_reference_type (ValaTypesymbol* base);
 static void vala_enum_set_cname (ValaEnum* self, const char* cname);
 static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a);
-static char* vala_enum_real_get_type_id (ValaDataType* base);
-static char* vala_enum_real_get_marshaller_type_name (ValaDataType* base);
-static char* vala_enum_real_get_get_value_function (ValaDataType* base);
-static char* vala_enum_real_get_set_value_function (ValaDataType* base);
-static char* vala_enum_real_get_default_value (ValaDataType* base);
+static char* vala_enum_real_get_type_id (ValaTypesymbol* base);
+static char* vala_enum_real_get_marshaller_type_name (ValaTypesymbol* base);
+static char* vala_enum_real_get_get_value_function (ValaTypesymbol* base);
+static char* vala_enum_real_get_set_value_function (ValaTypesymbol* base);
+static char* vala_enum_real_get_default_value (ValaTypesymbol* base);
 static gpointer vala_enum_parent_class = NULL;
 static void vala_enum_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
@@ -78,10 +80,8 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
  * @param source_reference reference to source code
  * @return                 newly created enum
  */
-ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference)
-{
+ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference) {
 	ValaEnum * self;
-	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ENUM, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
@@ -95,12 +95,11 @@ ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference
  *
  * @param value an enum value
  */
-void vala_enum_add_value (ValaEnum* self, ValaEnumValue* value)
-{
+void vala_enum_add_value (ValaEnum* self, ValaEnumValue* value) {
 	g_return_if_fail (VALA_IS_ENUM (self));
-	g_return_if_fail (VALA_IS_ENUM_VALUE (value));
+	g_return_if_fail (value == NULL || VALA_IS_ENUM_VALUE (value));
 	gee_collection_add (GEE_COLLECTION (self->priv->values), value);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) value)), VALA_SYMBOL (value));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (value)), VALA_SYMBOL (value));
 }
 
 
@@ -109,28 +108,37 @@ void vala_enum_add_value (ValaEnum* self, ValaEnumValue* value)
  *
  * @param m a method
  */
-void vala_enum_add_method (ValaEnum* self, ValaMethod* m)
-{
+void vala_enum_add_method (ValaEnum* self, ValaMethod* m) {
 	g_return_if_fail (VALA_IS_ENUM (self));
-	g_return_if_fail (VALA_IS_METHOD (m));
+	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
 	if (VALA_IS_CREATION_METHOD (m)) {
-		vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) m)), "construction methods may only be declared within classes and structs");
+		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (m)), "construction methods may only be declared within classes and structs");
 		vala_code_node_set_error (VALA_CODE_NODE (m), TRUE);
 		return;
 	}
 	if (vala_method_get_instance (m)) {
 		ValaFormalParameter* _tmp1;
-		ValaTypeReference* _tmp0;
+		ValaValueType* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		vala_method_set_this_parameter (m, (_tmp1 = vala_formal_parameter_new ("this", (_tmp0 = vala_type_reference_new ()), NULL)));
+		vala_method_set_this_parameter (m, (_tmp1 = vala_formal_parameter_new ("this", VALA_DATA_TYPE ((_tmp0 = vala_value_type_new (VALA_TYPESYMBOL (self)))), NULL)));
 		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
-		vala_type_reference_set_data_type (vala_formal_parameter_get_type_reference (vala_method_get_this_parameter (m)), VALA_DATA_TYPE (self));
-		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) m)), vala_symbol_get_name (((ValaSymbol*) vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
+		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
 	}
 	gee_collection_add (GEE_COLLECTION (self->priv->methods), m);
-	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) m)), VALA_SYMBOL (m));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (m)), VALA_SYMBOL (m));
+}
+
+
+/**
+ * Returns a copy of the list of enum values.
+ *
+ * @return list of enum values
+ */
+GeeCollection* vala_enum_get_values (ValaEnum* self) {
+	g_return_val_if_fail (VALA_IS_ENUM (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_ENUM_VALUE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->values)));
 }
 
 
@@ -139,27 +147,24 @@ void vala_enum_add_method (ValaEnum* self, ValaMethod* m)
  *
  * @return list of methods
  */
-GeeCollection* vala_enum_get_methods (ValaEnum* self)
-{
+GeeCollection* vala_enum_get_methods (ValaEnum* self) {
 	g_return_val_if_fail (VALA_IS_ENUM (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->methods)));
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->methods)));
 }
 
 
-static void vala_enum_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_enum_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaEnum * self;
-	self = ((ValaEnum*) base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = VALA_ENUM (base);
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_enum (visitor, self);
 }
 
 
-static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaEnum * self;
-	self = ((ValaEnum*) base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = VALA_ENUM (base);
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* value_collection;
 		GeeIterator* value_it;
@@ -193,17 +198,16 @@ static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor*
 }
 
 
-static char* vala_enum_real_get_cname (ValaDataType* base, gboolean const_type)
-{
+static char* vala_enum_real_get_cname (ValaTypesymbol* base, gboolean const_type) {
 	ValaEnum * self;
 	const char* _tmp2;
-	self = ((ValaEnum*) base);
+	self = VALA_ENUM (base);
 	if (self->priv->cname == NULL) {
 		char* _tmp1;
 		char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		self->priv->cname = (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
+		self->priv->cname = (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
 		(_tmp0 = (g_free (_tmp0), NULL));
 	}
 	_tmp2 = NULL;
@@ -211,11 +215,10 @@ static char* vala_enum_real_get_cname (ValaDataType* base, gboolean const_type)
 }
 
 
-static char* vala_enum_real_get_lower_case_cprefix (ValaSymbol* base)
-{
+static char* vala_enum_real_get_lower_case_cprefix (ValaSymbol* base) {
 	ValaEnum * self;
 	const char* _tmp2;
-	self = ((ValaEnum*) base);
+	self = VALA_ENUM (base);
 	if (self->priv->lower_case_cprefix == NULL) {
 		char* _tmp1;
 		char* _tmp0;
@@ -229,64 +232,60 @@ static char* vala_enum_real_get_lower_case_cprefix (ValaSymbol* base)
 }
 
 
-static char* vala_enum_get_lower_case_csuffix (ValaEnum* self)
-{
+static char* vala_enum_get_lower_case_csuffix (ValaEnum* self) {
 	const char* _tmp1;
 	g_return_val_if_fail (VALA_IS_ENUM (self), NULL);
 	if (self->priv->lower_case_csuffix == NULL) {
 		char* _tmp0;
 		_tmp0 = NULL;
-		self->priv->lower_case_csuffix = (_tmp0 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), _tmp0);
+		self->priv->lower_case_csuffix = (_tmp0 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), _tmp0);
 	}
 	_tmp1 = NULL;
 	return (_tmp1 = self->priv->lower_case_csuffix, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 }
 
 
-static char* vala_enum_real_get_lower_case_cname (ValaSymbol* base, const char* infix)
-{
+static char* vala_enum_real_get_lower_case_cname (ValaSymbol* base, const char* infix) {
 	ValaEnum * self;
 	char* _tmp1;
 	char* _tmp0;
 	char* _tmp2;
-	self = ((ValaEnum*) base);
+	self = VALA_ENUM (base);
 	if (infix == NULL) {
 		infix = "";
 	}
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	_tmp2 = NULL;
-	return (_tmp2 = g_strdup_printf ("%s%s%s", (_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), infix, (_tmp1 = vala_enum_get_lower_case_csuffix (self))), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
+	return (_tmp2 = g_strdup_printf ("%s%s%s", (_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), infix, (_tmp1 = vala_enum_get_lower_case_csuffix (self))), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
 }
 
 
-static char* vala_enum_real_get_upper_case_cname (ValaDataType* base, const char* infix)
-{
+static char* vala_enum_real_get_upper_case_cname (ValaTypesymbol* base, const char* infix) {
 	ValaEnum * self;
 	char* _tmp0;
 	char* _tmp1;
-	self = ((ValaEnum*) base);
+	self = VALA_ENUM (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
 	return (_tmp1 = g_utf8_strup ((_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), NULL)), -1), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
-static gboolean vala_enum_real_is_reference_type (ValaDataType* base)
-{
+static gboolean vala_enum_real_is_reference_type (ValaTypesymbol* base) {
 	ValaEnum * self;
-	self = ((ValaEnum*) base);
+	self = VALA_ENUM (base);
 	return FALSE;
 }
 
 
-static void vala_enum_set_cname (ValaEnum* self, const char* cname)
-{
-	char* _tmp0;
+static void vala_enum_set_cname (ValaEnum* self, const char* cname) {
+	char* _tmp1;
+	const char* _tmp0;
 	g_return_if_fail (VALA_IS_ENUM (self));
-	g_return_if_fail (cname != NULL);
+	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->cname = (_tmp0 = g_strdup (cname), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
+	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
 }
 
 
@@ -296,8 +295,7 @@ static void vala_enum_set_cname (ValaEnum* self, const char* cname)
  *
  * @return the prefix to be used in C code
  */
-char* vala_enum_get_cprefix (ValaEnum* self)
-{
+char* vala_enum_get_cprefix (ValaEnum* self) {
 	const char* _tmp2;
 	g_return_val_if_fail (VALA_IS_ENUM (self), NULL);
 	if (self->priv->cprefix == NULL) {
@@ -305,7 +303,7 @@ char* vala_enum_get_cprefix (ValaEnum* self)
 		char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		self->priv->cprefix = (_tmp1 = g_strdup_printf ("%s_", (_tmp0 = vala_data_type_get_upper_case_cname (VALA_DATA_TYPE (self), NULL))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp1);
+		self->priv->cprefix = (_tmp1 = g_strdup_printf ("%s_", (_tmp0 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self), NULL))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp1);
 		(_tmp0 = (g_free (_tmp0), NULL));
 	}
 	_tmp2 = NULL;
@@ -319,20 +317,19 @@ char* vala_enum_get_cprefix (ValaEnum* self)
  *
  * @param cprefix the prefix to be used in C code
  */
-void vala_enum_set_cprefix (ValaEnum* self, const char* cprefix)
-{
-	char* _tmp0;
+void vala_enum_set_cprefix (ValaEnum* self, const char* cprefix) {
+	char* _tmp1;
+	const char* _tmp0;
 	g_return_if_fail (VALA_IS_ENUM (self));
-	g_return_if_fail (cprefix != NULL);
+	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->cprefix = (_tmp0 = g_strdup (cprefix), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp0);
+	self->priv->cprefix = (_tmp1 = (_tmp0 = cprefix, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp1);
 }
 
 
-static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a)
-{
+static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_ENUM (self));
-	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -365,7 +362,7 @@ static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a)
 				_tmp3 = NULL;
 				filename = (_tmp3 = *filename_it, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
 				{
-					vala_data_type_add_cheader_filename (VALA_DATA_TYPE (self), filename);
+					vala_typesymbol_add_cheader_filename (VALA_TYPESYMBOL (self), filename);
 					(filename = (g_free (filename), NULL));
 				}
 			}
@@ -379,13 +376,12 @@ static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a)
 /**
  * Process all associated attributes.
  */
-void vala_enum_process_attributes (ValaEnum* self)
-{
+void vala_enum_process_attributes (ValaEnum* self) {
 	g_return_if_fail (VALA_IS_ENUM (self));
 	{
 		GList* a_collection;
 		GList* a_it;
-		a_collection = ((ValaCodeNode*) self)->attributes;
+		a_collection = VALA_CODE_NODE (self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
@@ -395,8 +391,12 @@ void vala_enum_process_attributes (ValaEnum* self)
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_enum_process_ccode_attribute (self, a);
 				} else {
-					if (g_utf8_collate (vala_attribute_get_name (a), "ErrorDomain") == 0) {
-						vala_enum_set_error_domain (self, TRUE);
+					if (g_utf8_collate (vala_attribute_get_name (a), "Flags") == 0) {
+						vala_enum_set_is_flags (self, TRUE);
+					} else {
+						if (g_utf8_collate (vala_attribute_get_name (a), "ErrorDomain") == 0) {
+							vala_enum_set_error_domain (self, TRUE);
+						}
 					}
 				}
 				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
@@ -406,69 +406,76 @@ void vala_enum_process_attributes (ValaEnum* self)
 }
 
 
-static char* vala_enum_real_get_type_id (ValaDataType* base)
-{
+static char* vala_enum_real_get_type_id (ValaTypesymbol* base) {
 	ValaEnum * self;
-	self = ((ValaEnum*) base);
+	self = VALA_ENUM (base);
 	return g_strdup ("G_TYPE_INT");
 }
 
 
 /* FIXME: use GType-registered enums*/
-static char* vala_enum_real_get_marshaller_type_name (ValaDataType* base)
-{
+static char* vala_enum_real_get_marshaller_type_name (ValaTypesymbol* base) {
 	ValaEnum * self;
-	self = ((ValaEnum*) base);
+	self = VALA_ENUM (base);
 	return g_strdup ("INT");
 }
 
 
 /* FIXME: use GType-registered enums*/
-static char* vala_enum_real_get_get_value_function (ValaDataType* base)
-{
+static char* vala_enum_real_get_get_value_function (ValaTypesymbol* base) {
 	ValaEnum * self;
-	self = ((ValaEnum*) base);
+	self = VALA_ENUM (base);
 	return g_strdup ("g_value_get_int");
 }
 
 
 /* FIXME: use GType-registered enums*/
-static char* vala_enum_real_get_set_value_function (ValaDataType* base)
-{
+static char* vala_enum_real_get_set_value_function (ValaTypesymbol* base) {
 	ValaEnum * self;
-	self = ((ValaEnum*) base);
+	self = VALA_ENUM (base);
 	return g_strdup ("g_value_set_int");
 }
 
 
 /* FIXME: use GType-registered enums*/
-static char* vala_enum_real_get_default_value (ValaDataType* base)
-{
+static char* vala_enum_real_get_default_value (ValaTypesymbol* base) {
 	ValaEnum * self;
-	self = ((ValaEnum*) base);
+	self = VALA_ENUM (base);
 	return g_strdup ("0");
 }
 
 
-gboolean vala_enum_get_error_domain (ValaEnum* self)
-{
+gboolean vala_enum_get_is_flags (ValaEnum* self) {
+	g_return_val_if_fail (VALA_IS_ENUM (self), FALSE);
+	return self->priv->_is_flags;
+}
+
+
+void vala_enum_set_is_flags (ValaEnum* self, gboolean value) {
+	g_return_if_fail (VALA_IS_ENUM (self));
+	self->priv->_is_flags = value;
+}
+
+
+gboolean vala_enum_get_error_domain (ValaEnum* self) {
 	g_return_val_if_fail (VALA_IS_ENUM (self), FALSE);
 	return self->priv->_error_domain;
 }
 
 
-void vala_enum_set_error_domain (ValaEnum* self, gboolean value)
-{
+void vala_enum_set_error_domain (ValaEnum* self, gboolean value) {
 	g_return_if_fail (VALA_IS_ENUM (self));
 	self->priv->_error_domain = value;
 }
 
 
-static void vala_enum_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_enum_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaEnum * self;
 	self = VALA_ENUM (object);
 	switch (property_id) {
+		case VALA_ENUM_IS_FLAGS:
+		g_value_set_boolean (value, vala_enum_get_is_flags (self));
+		break;
 		case VALA_ENUM_ERROR_DOMAIN:
 		g_value_set_boolean (value, vala_enum_get_error_domain (self));
 		break;
@@ -479,11 +486,13 @@ static void vala_enum_get_property (GObject * object, guint property_id, GValue
 }
 
 
-static void vala_enum_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_enum_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaEnum * self;
 	self = VALA_ENUM (object);
 	switch (property_id) {
+		case VALA_ENUM_IS_FLAGS:
+		vala_enum_set_is_flags (self, g_value_get_boolean (value));
+		break;
 		case VALA_ENUM_ERROR_DOMAIN:
 		vala_enum_set_error_domain (self, g_value_get_boolean (value));
 		break;
@@ -494,8 +503,7 @@ static void vala_enum_set_property (GObject * object, guint property_id, const G
 }
 
 
-static void vala_enum_class_init (ValaEnumClass * klass)
-{
+static void vala_enum_class_init (ValaEnumClass * klass) {
 	vala_enum_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaEnumPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_enum_get_property;
@@ -503,33 +511,30 @@ static void vala_enum_class_init (ValaEnumClass * klass)
 	G_OBJECT_CLASS (klass)->dispose = vala_enum_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_enum_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_enum_real_accept_children;
-	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_enum_real_get_cname;
+	VALA_TYPESYMBOL_CLASS (klass)->get_cname = vala_enum_real_get_cname;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cprefix = vala_enum_real_get_lower_case_cprefix;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cname = vala_enum_real_get_lower_case_cname;
-	VALA_DATA_TYPE_CLASS (klass)->get_upper_case_cname = vala_enum_real_get_upper_case_cname;
-	VALA_DATA_TYPE_CLASS (klass)->is_reference_type = vala_enum_real_is_reference_type;
-	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_enum_real_get_type_id;
-	VALA_DATA_TYPE_CLASS (klass)->get_marshaller_type_name = vala_enum_real_get_marshaller_type_name;
-	VALA_DATA_TYPE_CLASS (klass)->get_get_value_function = vala_enum_real_get_get_value_function;
-	VALA_DATA_TYPE_CLASS (klass)->get_set_value_function = vala_enum_real_get_set_value_function;
-	VALA_DATA_TYPE_CLASS (klass)->get_default_value = vala_enum_real_get_default_value;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ENUM_ERROR_DOMAIN, g_param_spec_boolean ("error-domain", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_TYPESYMBOL_CLASS (klass)->get_upper_case_cname = vala_enum_real_get_upper_case_cname;
+	VALA_TYPESYMBOL_CLASS (klass)->is_reference_type = vala_enum_real_is_reference_type;
+	VALA_TYPESYMBOL_CLASS (klass)->get_type_id = vala_enum_real_get_type_id;
+	VALA_TYPESYMBOL_CLASS (klass)->get_marshaller_type_name = vala_enum_real_get_marshaller_type_name;
+	VALA_TYPESYMBOL_CLASS (klass)->get_get_value_function = vala_enum_real_get_get_value_function;
+	VALA_TYPESYMBOL_CLASS (klass)->get_set_value_function = vala_enum_real_get_set_value_function;
+	VALA_TYPESYMBOL_CLASS (klass)->get_default_value = vala_enum_real_get_default_value;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ENUM_IS_FLAGS, g_param_spec_boolean ("is-flags", "is-flags", "is-flags", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ENUM_ERROR_DOMAIN, g_param_spec_boolean ("error-domain", "error-domain", "error-domain", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_enum_init (ValaEnum * self)
-{
+static void vala_enum_init (ValaEnum * self) {
 	self->priv = VALA_ENUM_GET_PRIVATE (self);
-	self->priv->values = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
-	self->priv->methods = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->values = GEE_LIST (gee_array_list_new (VALA_TYPE_ENUM_VALUE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
-static void vala_enum_dispose (GObject * obj)
-{
+static void vala_enum_dispose (GObject * obj) {
 	ValaEnum * self;
-	ValaEnumClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_ENUM (obj);
 	(self->priv->values == NULL ? NULL : (self->priv->values = (g_object_unref (self->priv->values), NULL)));
 	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_object_unref (self->priv->methods), NULL)));
@@ -537,25 +542,21 @@ static void vala_enum_dispose (GObject * obj)
 	(self->priv->cprefix = (g_free (self->priv->cprefix), NULL));
 	(self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL));
 	(self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL));
-	klass = VALA_ENUM_CLASS (g_type_class_peek (VALA_TYPE_ENUM));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_enum_parent_class)->dispose (obj);
 }
 
 
-GType vala_enum_get_type (void)
-{
+GType vala_enum_get_type (void) {
 	static GType vala_enum_type_id = 0;
 	if (G_UNLIKELY (vala_enum_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaEnumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_enum_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaEnum), 0, (GInstanceInitFunc) vala_enum_init };
-		vala_enum_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaEnum", &g_define_type_info, 0);
+		vala_enum_type_id = g_type_register_static (VALA_TYPE_TYPESYMBOL, "ValaEnum", &g_define_type_info, 0);
 	}
 	return vala_enum_type_id;
 }
 
 
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func)
-{
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if (array != NULL && destroy_func != NULL) {
 		int i;
 		if (array_length >= 0)
