@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,14 +20,15 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAENUM_H__
-#define __VALAENUM_H__
+#ifndef __VALA_VALAENUM_H__
+#define __VALA_VALAENUM_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <vala/valadatatype.h>
+#include <gee/collection.h>
+#include <vala/valatypesymbol.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -46,23 +47,26 @@ typedef struct _ValaEnumPrivate ValaEnumPrivate;
  * Represents an enum declaration in the source code.
  */
 struct _ValaEnum {
-	ValaDataType parent;
+	ValaTypesymbol parent_instance;
 	ValaEnumPrivate * priv;
 };
 struct _ValaEnumClass {
-	ValaDataTypeClass parent;
+	ValaTypesymbolClass parent_class;
 };
 
 ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference);
 void vala_enum_add_value (ValaEnum* self, ValaEnumValue* value);
 void vala_enum_add_method (ValaEnum* self, ValaMethod* m);
-GList* vala_enum_get_methods (ValaEnum* self);
+GeeCollection* vala_enum_get_values (ValaEnum* self);
+GeeCollection* vala_enum_get_methods (ValaEnum* self);
 char* vala_enum_get_cprefix (ValaEnum* self);
 void vala_enum_set_cprefix (ValaEnum* self, const char* cprefix);
 void vala_enum_process_attributes (ValaEnum* self);
+gboolean vala_enum_get_is_flags (ValaEnum* self);
+void vala_enum_set_is_flags (ValaEnum* self, gboolean value);
 gboolean vala_enum_get_error_domain (ValaEnum* self);
 void vala_enum_set_error_domain (ValaEnum* self, gboolean value);
-GType vala_enum_get_type ();
+GType vala_enum_get_type (void);
 
 G_END_DECLS
 
