@@ -47,7 +47,6 @@ static void vala_enum_value_dispose (GObject * obj);
  */
 ValaEnumValue* vala_enum_value_new (const char* name) {
 	ValaEnumValue * self;
-	g_return_val_if_fail (name != NULL, NULL);
 	self = g_object_newv (VALA_TYPE_ENUM_VALUE, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
@@ -63,7 +62,6 @@ ValaEnumValue* vala_enum_value_new (const char* name) {
  */
 ValaEnumValue* vala_enum_value_new_with_value (const char* name, ValaExpression* value) {
 	ValaEnumValue * self;
-	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (value == NULL || VALA_IS_EXPRESSION (value), NULL);
 	self = g_object_newv (VALA_TYPE_ENUM_VALUE, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
@@ -75,7 +73,7 @@ ValaEnumValue* vala_enum_value_new_with_value (const char* name, ValaExpression*
 static void vala_enum_value_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaEnumValue * self;
 	self = VALA_ENUM_VALUE (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_enum_value (visitor, self);
 }
 
