@@ -44,18 +44,20 @@ typedef struct _ValaExpressionPrivate ValaExpressionPrivate;
  * Base class for all code nodes that might be used as an expression.
  */
 struct _ValaExpression {
-	ValaCodeNode parent;
+	ValaCodeNode parent_instance;
 	ValaExpressionPrivate * priv;
 	GeeArrayList* temp_vars;
 };
 struct _ValaExpressionClass {
-	ValaCodeNodeClass parent;
+	ValaCodeNodeClass parent_class;
+	gboolean (*is_pure) (ValaExpression* self);
 };
 
-ValaTypeReference* vala_expression_get_static_type (ValaExpression* self);
-void vala_expression_set_static_type (ValaExpression* self, ValaTypeReference* value);
-ValaTypeReference* vala_expression_get_expected_type (ValaExpression* self);
-void vala_expression_set_expected_type (ValaExpression* self, ValaTypeReference* value);
+gboolean vala_expression_is_pure (ValaExpression* self);
+ValaDataType* vala_expression_get_static_type (ValaExpression* self);
+void vala_expression_set_static_type (ValaExpression* self, ValaDataType* value);
+ValaDataType* vala_expression_get_expected_type (ValaExpression* self);
+void vala_expression_set_expected_type (ValaExpression* self, ValaDataType* value);
 ValaSymbol* vala_expression_get_symbol_reference (ValaExpression* self);
 void vala_expression_set_symbol_reference (ValaExpression* self, ValaSymbol* value);
 gboolean vala_expression_get_ref_leaked (ValaExpression* self);
