@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,23 +20,22 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valafield.h"
-#include <vala/valatypereference.h>
-#include <vala/valaexpression.h>
-#include <vala/valasourcereference.h>
 #include <vala/valafield.h>
+#include <vala/valaexpression.h>
+#include <vala/valadatatype.h>
+#include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
-#include <vala/valacallback.h>
 
 struct _ValaFieldPrivate {
-	ValaTypeReference* _type_reference;
 	ValaExpression* _initializer;
+	gboolean _is_volatile;
 	gboolean _no_array_length;
 	char* cname;
 	gboolean _instance;
 	gboolean lock_used;
+	ValaDataType* _data_type;
 };
 #define VALA_FIELD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FIELD, ValaFieldPrivate))
 enum  {
@@ -44,19 +43,17 @@ enum  {
 	VALA_FIELD_TYPE_REFERENCE,
 	VALA_FIELD_INITIALIZER,
 	VALA_FIELD_INSTANCE,
+	VALA_FIELD_IS_VOLATILE,
 	VALA_FIELD_NO_ARRAY_LENGTH
 };
 static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_field_set_cname (ValaField* self, const char* cname);
 static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute* a);
-static GeeCollection* vala_field_real_get_parameters (ValaInvokable* base);
-static ValaTypeReference* vala_field_real_get_return_type (ValaInvokable* base);
-static gboolean vala_field_real_is_invokable (ValaInvokable* base);
 static gboolean vala_field_real_get_lock_used (ValaLockable* base);
 static void vala_field_real_set_lock_used (ValaLockable* base, gboolean used);
+static void vala_field_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_field_parent_class = NULL;
-static ValaInvokableIface* vala_field_vala_invokable_parent_iface = NULL;
 static ValaLockableIface* vala_field_vala_lockable_parent_iface = NULL;
 static void vala_field_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
@@ -71,11 +68,9 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
  * @param source reference to source code
  * @return       newly created field
  */
-ValaField* vala_field_new (const char* name, ValaTypeReference* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference)
-{
+ValaField* vala_field_new (const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference) {
 	ValaField * self;
-	g_return_val_if_fail (name != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type_reference), NULL);
+	g_return_val_if_fail (type_reference == NULL || VALA_IS_DATA_TYPE (type_reference), NULL);
 	g_return_val_if_fail (initializer == NULL || VALA_IS_EXPRESSION (initializer), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_FIELD, 0, NULL);
@@ -87,21 +82,19 @@ ValaField* vala_field_new (const char* name, ValaTypeReference* type_reference,
 }
 
 
-static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaField * self;
-	self = ((ValaField*) base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = VALA_FIELD (base);
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, VALA_MEMBER (self));
 	vala_code_visitor_visit_field (visitor, self);
 }
 
 
-static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaField * self;
-	self = ((ValaField*) base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = VALA_FIELD (base);
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_field_get_type_reference (self)), visitor);
 	if (vala_field_get_initializer (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_field_get_initializer (self)), visitor);
@@ -114,8 +107,7 @@ static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor
  *
  * @return the name to be used in C code
  */
-char* vala_field_get_cname (ValaField* self)
-{
+char* vala_field_get_cname (ValaField* self) {
 	const char* _tmp1;
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
 	if (self->priv->cname == NULL) {
@@ -128,13 +120,13 @@ char* vala_field_get_cname (ValaField* self)
 }
 
 
-static void vala_field_set_cname (ValaField* self, const char* cname)
-{
-	char* _tmp0;
+static void vala_field_set_cname (ValaField* self, const char* cname) {
+	char* _tmp1;
+	const char* _tmp0;
 	g_return_if_fail (VALA_IS_FIELD (self));
-	g_return_if_fail (cname != NULL);
+	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->cname = (_tmp0 = g_strdup (cname), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
+	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
 }
 
 
@@ -143,27 +135,25 @@ static void vala_field_set_cname (ValaField* self, const char* cname)
  *
  * @return the name to be used in C code by default
  */
-char* vala_field_get_default_cname (ValaField* self)
-{
+char* vala_field_get_default_cname (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
 	if (!vala_field_get_instance (self)) {
 		char* _tmp0;
 		char* _tmp1;
 		_tmp0 = NULL;
 		_tmp1 = NULL;
-		return (_tmp1 = g_strconcat ((_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self)), NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+		return (_tmp1 = g_strconcat ((_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self)), NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 	} else {
 		const char* _tmp3;
 		_tmp3 = NULL;
-		return (_tmp3 = vala_symbol_get_name (((ValaSymbol*) self)), (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
+		return (_tmp3 = vala_symbol_get_name (VALA_SYMBOL (self)), (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
 	}
 }
 
 
-static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute* a)
-{
+static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_FIELD (self));
-	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -199,13 +189,12 @@ static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute*
 /**
  * Process all associated attributes.
  */
-void vala_field_process_attributes (ValaField* self)
-{
+void vala_field_process_attributes (ValaField* self) {
 	g_return_if_fail (VALA_IS_FIELD (self));
 	{
 		GList* a_collection;
 		GList* a_it;
-		a_collection = ((ValaCodeNode*) self)->attributes;
+		a_collection = VALA_CODE_NODE (self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
@@ -226,93 +215,55 @@ void vala_field_process_attributes (ValaField* self)
 }
 
 
-static GeeCollection* vala_field_real_get_parameters (ValaInvokable* base)
-{
+static gboolean vala_field_real_get_lock_used (ValaLockable* base) {
 	ValaField * self;
-	ValaCallback* _tmp1;
-	ValaCallback* cb;
-	GeeCollection* _tmp2;
-	self = ((ValaField*) base);
-	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
-		return GEE_COLLECTION (NULL);
-	}
-	_tmp1 = NULL;
-	cb = (_tmp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_field_get_type_reference (self))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
-	_tmp2 = NULL;
-	return (_tmp2 = vala_callback_get_parameters (cb), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), _tmp2);
-	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
-}
-
-
-static ValaTypeReference* vala_field_real_get_return_type (ValaInvokable* base)
-{
-	ValaField * self;
-	ValaCallback* _tmp1;
-	ValaCallback* cb;
-	ValaTypeReference* _tmp2;
-	ValaTypeReference* _tmp3;
-	self = ((ValaField*) base);
-	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
-		return VALA_TYPE_REFERENCE (NULL);
-	}
-	_tmp1 = NULL;
-	cb = (_tmp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_field_get_type_reference (self))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
-	_tmp2 = NULL;
-	_tmp3 = NULL;
-	return (_tmp3 = (_tmp2 = vala_callback_get_return_type (cb), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), _tmp3);
-	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
-}
-
-
-static gboolean vala_field_real_is_invokable (ValaInvokable* base)
-{
-	ValaField * self;
-	self = ((ValaField*) base);
-	return (VALA_IS_CALLBACK (vala_type_reference_get_data_type (vala_field_get_type_reference (self))));
-}
-
-
-static gboolean vala_field_real_get_lock_used (ValaLockable* base)
-{
-	ValaField * self;
-	self = ((ValaField*) base);
+	self = VALA_FIELD (base);
 	return self->priv->lock_used;
 }
 
 
-static void vala_field_real_set_lock_used (ValaLockable* base, gboolean used)
-{
+static void vala_field_real_set_lock_used (ValaLockable* base, gboolean used) {
 	ValaField * self;
-	self = ((ValaField*) base);
+	self = VALA_FIELD (base);
 	self->priv->lock_used = used;
 }
 
 
-ValaTypeReference* vala_field_get_type_reference (ValaField* self)
-{
+static void vala_field_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
+	ValaField * self;
+	self = VALA_FIELD (base);
+	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	if (vala_field_get_type_reference (self) == old_type) {
+		vala_field_set_type_reference (self, new_type);
+	}
+}
+
+
+ValaDataType* vala_field_get_type_reference (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
-	return self->priv->_type_reference;
+	return self->priv->_data_type;
 }
 
 
-void vala_field_set_type_reference (ValaField* self, ValaTypeReference* value)
-{
-	ValaTypeReference* _tmp1;
+void vala_field_set_type_reference (ValaField* self, ValaDataType* value) {
+	ValaDataType* _tmp2;
+	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_FIELD (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_type_reference = (_tmp1 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp1);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
 }
 
 
-ValaExpression* vala_field_get_initializer (ValaField* self)
-{
+ValaExpression* vala_field_get_initializer (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
 	return self->priv->_initializer;
 }
 
 
-void vala_field_set_initializer (ValaField* self, ValaExpression* value)
-{
+void vala_field_set_initializer (ValaField* self, ValaExpression* value) {
 	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_FIELD (self));
@@ -322,36 +273,43 @@ void vala_field_set_initializer (ValaField* self, ValaExpression* value)
 }
 
 
-gboolean vala_field_get_instance (ValaField* self)
-{
+gboolean vala_field_get_instance (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), FALSE);
 	return self->priv->_instance;
 }
 
 
-void vala_field_set_instance (ValaField* self, gboolean value)
-{
+void vala_field_set_instance (ValaField* self, gboolean value) {
 	g_return_if_fail (VALA_IS_FIELD (self));
 	self->priv->_instance = value;
 }
 
 
-gboolean vala_field_get_no_array_length (ValaField* self)
-{
+gboolean vala_field_get_is_volatile (ValaField* self) {
+	g_return_val_if_fail (VALA_IS_FIELD (self), FALSE);
+	return self->priv->_is_volatile;
+}
+
+
+void vala_field_set_is_volatile (ValaField* self, gboolean value) {
+	g_return_if_fail (VALA_IS_FIELD (self));
+	self->priv->_is_volatile = value;
+}
+
+
+gboolean vala_field_get_no_array_length (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), FALSE);
 	return self->priv->_no_array_length;
 }
 
 
-void vala_field_set_no_array_length (ValaField* self, gboolean value)
-{
+void vala_field_set_no_array_length (ValaField* self, gboolean value) {
 	g_return_if_fail (VALA_IS_FIELD (self));
 	self->priv->_no_array_length = value;
 }
 
 
-static void vala_field_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_field_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaField * self;
 	self = VALA_FIELD (object);
 	switch (property_id) {
@@ -364,6 +322,9 @@ static void vala_field_get_property (GObject * object, guint property_id, GValue
 		case VALA_FIELD_INSTANCE:
 		g_value_set_boolean (value, vala_field_get_instance (self));
 		break;
+		case VALA_FIELD_IS_VOLATILE:
+		g_value_set_boolean (value, vala_field_get_is_volatile (self));
+		break;
 		case VALA_FIELD_NO_ARRAY_LENGTH:
 		g_value_set_boolean (value, vala_field_get_no_array_length (self));
 		break;
@@ -374,8 +335,7 @@ static void vala_field_get_property (GObject * object, guint property_id, GValue
 }
 
 
-static void vala_field_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_field_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaField * self;
 	self = VALA_FIELD (object);
 	switch (property_id) {
@@ -388,6 +348,9 @@ static void vala_field_set_property (GObject * object, guint property_id, const
 		case VALA_FIELD_INSTANCE:
 		vala_field_set_instance (self, g_value_get_boolean (value));
 		break;
+		case VALA_FIELD_IS_VOLATILE:
+		vala_field_set_is_volatile (self, g_value_get_boolean (value));
+		break;
 		case VALA_FIELD_NO_ARRAY_LENGTH:
 		vala_field_set_no_array_length (self, g_value_get_boolean (value));
 		break;
@@ -398,8 +361,7 @@ static void vala_field_set_property (GObject * object, guint property_id, const
 }
 
 
-static void vala_field_class_init (ValaFieldClass * klass)
-{
+static void vala_field_class_init (ValaFieldClass * klass) {
 	vala_field_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaFieldPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_field_get_property;
@@ -407,70 +369,52 @@ static void vala_field_class_init (ValaFieldClass * klass)
 	G_OBJECT_CLASS (klass)->dispose = vala_field_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_field_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_field_real_accept_children;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_TYPE_REFERENCE, g_param_spec_object ("type-reference", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INITIALIZER, g_param_spec_object ("initializer", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INSTANCE, g_param_spec_boolean ("instance", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_field_real_replace_type;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INITIALIZER, g_param_spec_object ("initializer", "initializer", "initializer", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_IS_VOLATILE, g_param_spec_boolean ("is-volatile", "is-volatile", "is-volatile", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_field_vala_invokable_interface_init (ValaInvokableIface * iface)
-{
-	vala_field_vala_invokable_parent_iface = g_type_interface_peek_parent (iface);
-	iface->get_parameters = vala_field_real_get_parameters;
-	iface->get_return_type = vala_field_real_get_return_type;
-	iface->is_invokable = vala_field_real_is_invokable;
-}
-
-
-static void vala_field_vala_lockable_interface_init (ValaLockableIface * iface)
-{
+static void vala_field_vala_lockable_interface_init (ValaLockableIface * iface) {
 	vala_field_vala_lockable_parent_iface = g_type_interface_peek_parent (iface);
 	iface->get_lock_used = vala_field_real_get_lock_used;
 	iface->set_lock_used = vala_field_real_set_lock_used;
 }
 
 
-static void vala_field_init (ValaField * self)
-{
+static void vala_field_init (ValaField * self) {
 	self->priv = VALA_FIELD_GET_PRIVATE (self);
 	self->priv->_instance = TRUE;
 	self->priv->lock_used = FALSE;
 }
 
 
-static void vala_field_dispose (GObject * obj)
-{
+static void vala_field_dispose (GObject * obj) {
 	ValaField * self;
-	ValaFieldClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_FIELD (obj);
-	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
 	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
 	(self->priv->cname = (g_free (self->priv->cname), NULL));
-	klass = VALA_FIELD_CLASS (g_type_class_peek (VALA_TYPE_FIELD));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
+	G_OBJECT_CLASS (vala_field_parent_class)->dispose (obj);
 }
 
 
-GType vala_field_get_type (void)
-{
+GType vala_field_get_type (void) {
 	static GType vala_field_type_id = 0;
 	if (G_UNLIKELY (vala_field_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaFieldClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_field_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaField), 0, (GInstanceInitFunc) vala_field_init };
-		static const GInterfaceInfo vala_invokable_info = { (GInterfaceInitFunc) vala_field_vala_invokable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo vala_lockable_info = { (GInterfaceInitFunc) vala_field_vala_lockable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_field_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaField", &g_define_type_info, 0);
-		g_type_add_interface_static (vala_field_type_id, VALA_TYPE_INVOKABLE, &vala_invokable_info);
 		g_type_add_interface_static (vala_field_type_id, VALA_TYPE_LOCKABLE, &vala_lockable_info);
 	}
 	return vala_field_type_id;
 }
 
 
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func)
-{
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if (array != NULL && destroy_func != NULL) {
 		int i;
 		if (array_length >= 0)
