@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAFOREACHSTATEMENT_H__
-#define __VALAFOREACHSTATEMENT_H__
+#ifndef __VALA_VALAFOREACHSTATEMENT_H__
+#define __VALA_VALAFOREACHSTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -47,16 +47,16 @@ typedef struct _ValaForeachStatementPrivate ValaForeachStatementPrivate;
  * over the elements of a collection.
  */
 struct _ValaForeachStatement {
-	ValaBlock parent;
+	ValaBlock parent_instance;
 	ValaForeachStatementPrivate * priv;
 };
 struct _ValaForeachStatementClass {
-	ValaBlockClass parent;
+	ValaBlockClass parent_class;
 };
 
-ValaForeachStatement* vala_foreach_statement_new (ValaTypeReference* type_reference, const char* variable_name, ValaExpression* collection, ValaBlock* body, ValaSourceReference* source_reference);
-ValaTypeReference* vala_foreach_statement_get_type_reference (ValaForeachStatement* self);
-void vala_foreach_statement_set_type_reference (ValaForeachStatement* self, ValaTypeReference* value);
+ValaForeachStatement* vala_foreach_statement_new (ValaDataType* type_reference, const char* variable_name, ValaExpression* collection, ValaBlock* body, ValaSourceReference* source_reference);
+ValaDataType* vala_foreach_statement_get_type_reference (ValaForeachStatement* self);
+void vala_foreach_statement_set_type_reference (ValaForeachStatement* self, ValaDataType* value);
 char* vala_foreach_statement_get_variable_name (ValaForeachStatement* self);
 void vala_foreach_statement_set_variable_name (ValaForeachStatement* self, const char* value);
 ValaExpression* vala_foreach_statement_get_collection (ValaForeachStatement* self);
