@@ -22,18 +22,17 @@
  */
 
 #include <vala/valaformalparameter.h>
-#include <vala/valatypereference.h>
 #include <vala/valaexpression.h>
+#include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
-#include <vala/valacallback.h>
 
 struct _ValaFormalParameterPrivate {
-	ValaTypeReference* _type_reference;
 	gboolean _ellipsis;
 	ValaExpression* _default_expression;
 	gboolean _no_array_length;
 	gboolean _construct_parameter;
+	ValaDataType* _data_type;
 };
 #define VALA_FORMAL_PARAMETER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FORMAL_PARAMETER, ValaFormalParameterPrivate))
 enum  {
@@ -46,12 +45,9 @@ enum  {
 };
 static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static GeeCollection* vala_formal_parameter_real_get_parameters (ValaInvokable* base);
-static ValaTypeReference* vala_formal_parameter_real_get_return_type (ValaInvokable* base);
-static gboolean vala_formal_parameter_real_is_invokable (ValaInvokable* base);
+static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static GObject * vala_formal_parameter_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_formal_parameter_parent_class = NULL;
-static ValaInvokableIface* vala_formal_parameter_vala_invokable_parent_iface = NULL;
 static void vala_formal_parameter_dispose (GObject * obj);
 
 
@@ -63,10 +59,9 @@ static void vala_formal_parameter_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created formal parameter
  */
-ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaTypeReference* type, ValaSourceReference* source) {
+ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaDataType* type, ValaSourceReference* source) {
 	ValaFormalParameter * self;
-	g_return_val_if_fail (_name != NULL, NULL);
-	g_return_val_if_fail (type == NULL || VALA_IS_TYPE_REFERENCE (type), NULL);
+	g_return_val_if_fail (type == NULL || VALA_IS_DATA_TYPE (type), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_FORMAL_PARAMETER, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), _name);
@@ -93,7 +88,7 @@ ValaFormalParameter* vala_formal_parameter_new_with_ellipsis (ValaSourceReferenc
 static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_formal_parameter (visitor, self);
 }
 
@@ -101,7 +96,7 @@ static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisit
 static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	if (!vala_formal_parameter_get_ellipsis (self)) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_formal_parameter_get_type_reference (self)), visitor);
 		if (vala_formal_parameter_get_default_expression (self) != NULL) {
@@ -111,62 +106,31 @@ static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, Vala
 }
 
 
-static GeeCollection* vala_formal_parameter_real_get_parameters (ValaInvokable* base) {
+static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaFormalParameter * self;
-	ValaCallback* _tmp1;
-	ValaCallback* cb;
-	GeeCollection* _tmp2;
 	self = VALA_FORMAL_PARAMETER (base);
-	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
-		return NULL;
+	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	if (vala_formal_parameter_get_type_reference (self) == old_type) {
+		vala_formal_parameter_set_type_reference (self, new_type);
 	}
-	_tmp1 = NULL;
-	cb = (_tmp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
-	_tmp2 = NULL;
-	return (_tmp2 = vala_callback_get_parameters (cb), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), _tmp2);
-	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
 }
 
 
-static ValaTypeReference* vala_formal_parameter_real_get_return_type (ValaInvokable* base) {
-	ValaFormalParameter * self;
-	ValaCallback* _tmp1;
-	ValaCallback* cb;
-	ValaTypeReference* _tmp2;
-	ValaTypeReference* _tmp3;
-	self = VALA_FORMAL_PARAMETER (base);
-	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
-		return NULL;
-	}
-	_tmp1 = NULL;
-	cb = (_tmp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
-	_tmp2 = NULL;
-	_tmp3 = NULL;
-	return (_tmp3 = (_tmp2 = vala_callback_get_return_type (cb), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), _tmp3);
-	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
-}
-
-
-static gboolean vala_formal_parameter_real_is_invokable (ValaInvokable* base) {
-	ValaFormalParameter * self;
-	self = VALA_FORMAL_PARAMETER (base);
-	return (VALA_IS_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))));
-}
-
-
-ValaTypeReference* vala_formal_parameter_get_type_reference (ValaFormalParameter* self) {
+ValaDataType* vala_formal_parameter_get_type_reference (ValaFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
-	return self->priv->_type_reference;
+	return self->priv->_data_type;
 }
 
 
-void vala_formal_parameter_set_type_reference (ValaFormalParameter* self, ValaTypeReference* value) {
-	ValaTypeReference* _tmp2;
-	ValaTypeReference* _tmp1;
+void vala_formal_parameter_set_type_reference (ValaFormalParameter* self, ValaDataType* value) {
+	ValaDataType* _tmp2;
+	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_type_reference = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp2);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
 }
 
 
@@ -299,7 +263,8 @@ static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass)
 	G_OBJECT_CLASS (klass)->dispose = vala_formal_parameter_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_formal_parameter_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_formal_parameter_real_accept_children;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_formal_parameter_real_replace_type;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_ELLIPSIS, g_param_spec_boolean ("ellipsis", "ellipsis", "ellipsis", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION, g_param_spec_object ("default-expression", "default-expression", "default-expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -307,14 +272,6 @@ static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass)
 }
 
 
-static void vala_formal_parameter_vala_invokable_interface_init (ValaInvokableIface * iface) {
-	vala_formal_parameter_vala_invokable_parent_iface = g_type_interface_peek_parent (iface);
-	iface->get_parameters = vala_formal_parameter_real_get_parameters;
-	iface->get_return_type = vala_formal_parameter_real_get_return_type;
-	iface->is_invokable = vala_formal_parameter_real_is_invokable;
-}
-
-
 static void vala_formal_parameter_init (ValaFormalParameter * self) {
 	self->priv = VALA_FORMAL_PARAMETER_GET_PRIVATE (self);
 }
@@ -323,8 +280,8 @@ static void vala_formal_parameter_init (ValaFormalParameter * self) {
 static void vala_formal_parameter_dispose (GObject * obj) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (obj);
-	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
 	(self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL)));
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
 	G_OBJECT_CLASS (vala_formal_parameter_parent_class)->dispose (obj);
 }
 
@@ -333,9 +290,7 @@ GType vala_formal_parameter_get_type (void) {
 	static GType vala_formal_parameter_type_id = 0;
 	if (G_UNLIKELY (vala_formal_parameter_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaFormalParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_formal_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaFormalParameter), 0, (GInstanceInitFunc) vala_formal_parameter_init };
-		static const GInterfaceInfo vala_invokable_info = { (GInterfaceInitFunc) vala_formal_parameter_vala_invokable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_formal_parameter_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaFormalParameter", &g_define_type_info, 0);
-		g_type_add_interface_static (vala_formal_parameter_type_id, VALA_TYPE_INVOKABLE, &vala_invokable_info);
 	}
 	return vala_formal_parameter_type_id;
 }
