@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,16 +21,14 @@
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
 
-#ifndef __VALAFORMALPARAMETER_H__
-#define __VALAFORMALPARAMETER_H__
+#ifndef __VALA_VALAFORMALPARAMETER_H__
+#define __VALA_VALAFORMALPARAMETER_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gee/collection.h>
 #include <vala/valasymbol.h>
-#include <vala/valainvokable.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -49,17 +47,17 @@ typedef struct _ValaFormalParameterPrivate ValaFormalParameterPrivate;
  * Represents a formal parameter in method and callback signatures.
  */
 struct _ValaFormalParameter {
-	ValaSymbol parent;
+	ValaSymbol parent_instance;
 	ValaFormalParameterPrivate * priv;
 };
 struct _ValaFormalParameterClass {
-	ValaSymbolClass parent;
+	ValaSymbolClass parent_class;
 };
 
-ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaTypeReference* type, ValaSourceReference* source);
+ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaDataType* type, ValaSourceReference* source);
 ValaFormalParameter* vala_formal_parameter_new_with_ellipsis (ValaSourceReference* source);
-ValaTypeReference* vala_formal_parameter_get_type_reference (ValaFormalParameter* self);
-void vala_formal_parameter_set_type_reference (ValaFormalParameter* self, ValaTypeReference* value);
+ValaDataType* vala_formal_parameter_get_type_reference (ValaFormalParameter* self);
+void vala_formal_parameter_set_type_reference (ValaFormalParameter* self, ValaDataType* value);
 gboolean vala_formal_parameter_get_ellipsis (ValaFormalParameter* self);
 void vala_formal_parameter_set_ellipsis (ValaFormalParameter* self, gboolean value);
 ValaExpression* vala_formal_parameter_get_default_expression (ValaFormalParameter* self);
