@@ -38,6 +38,7 @@ enum  {
 };
 static void vala_initializer_list_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_initializer_list_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static gboolean vala_initializer_list_real_is_pure (ValaExpression* base);
 static gpointer vala_initializer_list_parent_class = NULL;
 static void vala_initializer_list_dispose (GObject * obj);
 
@@ -49,7 +50,7 @@ static void vala_initializer_list_dispose (GObject * obj);
  */
 void vala_initializer_list_append (ValaInitializerList* self, ValaExpression* expr) {
 	g_return_if_fail (VALA_IS_INITIALIZER_LIST (self));
-	g_return_if_fail (VALA_IS_EXPRESSION (expr));
+	g_return_if_fail (expr == NULL || VALA_IS_EXPRESSION (expr));
 	gee_collection_add (GEE_COLLECTION (self->priv->initializers), expr);
 }
 
@@ -61,7 +62,7 @@ void vala_initializer_list_append (ValaInitializerList* self, ValaExpression* ex
  */
 GeeCollection* vala_initializer_list_get_initializers (ValaInitializerList* self) {
 	g_return_val_if_fail (VALA_IS_INITIALIZER_LIST (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->initializers)));
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->initializers)));
 }
 
 
@@ -83,7 +84,7 @@ ValaInitializerList* vala_initializer_list_new (ValaSourceReference* source_refe
 static void vala_initializer_list_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaInitializerList * self;
 	self = VALA_INITIALIZER_LIST (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* expr_collection;
 		GeeIterator* expr_it;
@@ -105,11 +106,36 @@ static void vala_initializer_list_real_accept_children (ValaCodeNode* base, Vala
 static void vala_initializer_list_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaInitializerList * self;
 	self = VALA_INITIALIZER_LIST (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_initializer_list (visitor, self);
 }
 
 
+static gboolean vala_initializer_list_real_is_pure (ValaExpression* base) {
+	ValaInitializerList * self;
+	self = VALA_INITIALIZER_LIST (base);
+	{
+		GeeList* initializer_collection;
+		GeeIterator* initializer_it;
+		initializer_collection = self->priv->initializers;
+		initializer_it = gee_iterable_iterator (GEE_ITERABLE (initializer_collection));
+		while (gee_iterator_next (initializer_it)) {
+			ValaExpression* initializer;
+			initializer = gee_iterator_get (initializer_it);
+			{
+				if (!vala_expression_is_pure (initializer)) {
+					gboolean _tmp0;
+					return (_tmp0 = FALSE, (initializer == NULL ? NULL : (initializer = (g_object_unref (initializer), NULL))), (initializer_it == NULL ? NULL : (initializer_it = (g_object_unref (initializer_it), NULL))), _tmp0);
+				}
+				(initializer == NULL ? NULL : (initializer = (g_object_unref (initializer), NULL)));
+			}
+		}
+		(initializer_it == NULL ? NULL : (initializer_it = (g_object_unref (initializer_it), NULL)));
+	}
+	return TRUE;
+}
+
+
 gint vala_initializer_list_get_size (ValaInitializerList* self) {
 	g_return_val_if_fail (VALA_IS_INITIALIZER_LIST (self), 0);
 	return gee_collection_get_size (GEE_COLLECTION (self->priv->initializers));
@@ -137,13 +163,14 @@ static void vala_initializer_list_class_init (ValaInitializerListClass * klass)
 	G_OBJECT_CLASS (klass)->dispose = vala_initializer_list_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_initializer_list_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_initializer_list_real_accept;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_initializer_list_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INITIALIZER_LIST_SIZE, g_param_spec_int ("size", "size", "size", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
 
 static void vala_initializer_list_init (ValaInitializerList * self) {
 	self->priv = VALA_INITIALIZER_LIST_GET_PRIVATE (self);
-	self->priv->initializers = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->initializers = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
