@@ -1,11 +1,11 @@
 /* valainstancecast.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,14 +20,14 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAINSTANCECAST_H__
-#define __VALAINSTANCECAST_H__
+#ifndef __VALA_VALAINSTANCECAST_H__
+#define __VALA_VALAINSTANCECAST_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <ccode/valaccodefunctioncall.h>
 #include <ccode/valaccodeexpression.h>
-#include <vala/valadatatype.h>
+#include <vala/valatypesymbol.h>
 
 G_BEGIN_DECLS
 
@@ -47,16 +47,16 @@ typedef struct _ValaInstanceCastPrivate ValaInstanceCastPrivate;
  * Represents a runtime checked object instance cast expression in the C code.
  */
 struct _ValaInstanceCast {
-	ValaCCodeFunctionCall parent;
+	ValaCCodeFunctionCall parent_instance;
 	ValaInstanceCastPrivate * priv;
 };
 struct _ValaInstanceCastClass {
-	ValaCCodeFunctionCallClass parent;
+	ValaCCodeFunctionCallClass parent_class;
 };
 
-ValaInstanceCast* vala_instance_cast_new (ValaCCodeExpression* expr, ValaDataType* type);
-ValaDataType* vala_instance_cast_get_type_reference (ValaInstanceCast* self);
-void vala_instance_cast_set_type_reference (ValaInstanceCast* self, ValaDataType* value);
+ValaInstanceCast* vala_instance_cast_new (ValaCCodeExpression* expr, ValaTypesymbol* type);
+ValaTypesymbol* vala_instance_cast_get_type_reference (ValaInstanceCast* self);
+void vala_instance_cast_set_type_reference (ValaInstanceCast* self, ValaTypesymbol* value);
 ValaCCodeExpression* vala_instance_cast_get_inner (ValaInstanceCast* self);
 void vala_instance_cast_set_inner (ValaInstanceCast* self, ValaCCodeExpression* value);
 GType vala_instance_cast_get_type (void);
