@@ -1,6 +1,6 @@
 /* valainterface.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,7 +28,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <gee/collection.h>
-#include <vala/valadatatype.h>
+#include <vala/valatypesymbol.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -47,18 +47,18 @@ typedef struct _ValaInterfacePrivate ValaInterfacePrivate;
  * Represents a class declaration in the source code.
  */
 struct _ValaInterface {
-	ValaDataType parent;
+	ValaTypesymbol parent_instance;
 	ValaInterfacePrivate * priv;
 };
 struct _ValaInterfaceClass {
-	ValaDataTypeClass parent;
+	ValaTypesymbolClass parent_class;
 };
 
 ValaInterface* vala_interface_new (const char* name, ValaSourceReference* source_reference);
 void vala_interface_add_type_parameter (ValaInterface* self, ValaTypeParameter* p);
 GeeCollection* vala_interface_get_type_parameters (ValaInterface* self);
-void vala_interface_add_prerequisite (ValaInterface* self, ValaTypeReference* type);
-void vala_interface_prepend_prerequisite (ValaInterface* self, ValaTypeReference* type);
+void vala_interface_add_prerequisite (ValaInterface* self, ValaDataType* type);
+void vala_interface_prepend_prerequisite (ValaInterface* self, ValaDataType* type);
 GeeCollection* vala_interface_get_prerequisites (ValaInterface* self);
 void vala_interface_add_method (ValaInterface* self, ValaMethod* m);
 GeeCollection* vala_interface_get_methods (ValaInterface* self);
