@@ -1,6 +1,6 @@
 /* valainvocationexpression.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,17 +28,20 @@
 #include <vala/valacodevisitor.h>
 
 struct _ValaInvocationExpressionPrivate {
+	ValaCCodeExpression* _delegate_target;
 	GeeList* argument_list;
 	GeeList* array_sizes;
 };
 #define VALA_INVOCATION_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INVOCATION_EXPRESSION, ValaInvocationExpressionPrivate))
 enum  {
 	VALA_INVOCATION_EXPRESSION_DUMMY_PROPERTY,
-	VALA_INVOCATION_EXPRESSION_CALL
+	VALA_INVOCATION_EXPRESSION_CALL,
+	VALA_INVOCATION_EXPRESSION_DELEGATE_TARGET
 };
 static void vala_invocation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_invocation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static void vala_invocation_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
+static void vala_invocation_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
+static gboolean vala_invocation_expression_real_is_pure (ValaExpression* base);
 static gpointer vala_invocation_expression_parent_class = NULL;
 static void vala_invocation_expression_dispose (GObject * obj);
 
@@ -54,7 +57,7 @@ ValaInvocationExpression* vala_invocation_expression_new (ValaExpression* call,
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaInvocationExpression * self;
-	g_return_val_if_fail (VALA_IS_EXPRESSION (call), NULL);
+	g_return_val_if_fail (call == NULL || VALA_IS_EXPRESSION (call), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -77,7 +80,7 @@ ValaInvocationExpression* vala_invocation_expression_new (ValaExpression* call,
  */
 void vala_invocation_expression_add_argument (ValaInvocationExpression* self, ValaExpression* arg) {
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
-	g_return_if_fail (VALA_IS_EXPRESSION (arg));
+	g_return_if_fail (arg == NULL || VALA_IS_EXPRESSION (arg));
 	gee_collection_add (GEE_COLLECTION (self->priv->argument_list), arg);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (arg), VALA_CODE_NODE (self));
 }
@@ -99,7 +102,7 @@ GeeCollection* vala_invocation_expression_get_argument_list (ValaInvocationExpre
  */
 void vala_invocation_expression_append_array_size (ValaInvocationExpression* self, ValaCCodeExpression* size) {
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
-	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (size));
+	g_return_if_fail (size == NULL || VALA_IS_CCODE_EXPRESSION (size));
 	gee_collection_add (GEE_COLLECTION (self->priv->array_sizes), size);
 }
 
@@ -117,7 +120,7 @@ GeeList* vala_invocation_expression_get_array_sizes (ValaInvocationExpression* s
 static void vala_invocation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaInvocationExpression * self;
 	self = VALA_INVOCATION_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_invocation_expression (visitor, self);
 }
 
@@ -125,7 +128,7 @@ static void vala_invocation_expression_real_accept (ValaCodeNode* base, ValaCode
 static void vala_invocation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaInvocationExpression * self;
 	self = VALA_INVOCATION_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_invocation_expression_get_call (self)), visitor);
 	{
 		GeeList* expr_collection;
@@ -145,23 +148,30 @@ static void vala_invocation_expression_real_accept_children (ValaCodeNode* base,
 }
 
 
-static void vala_invocation_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node) {
+static void vala_invocation_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaInvocationExpression * self;
 	gint index;
 	self = VALA_INVOCATION_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
-	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
-	if (VALA_CODE_NODE (vala_invocation_expression_get_call (self)) == old_node) {
-		vala_invocation_expression_set_call (self, VALA_EXPRESSION (new_node));
+	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	if (vala_invocation_expression_get_call (self) == old_node) {
+		vala_invocation_expression_set_call (self, new_node);
 	}
 	index = gee_list_index_of (self->priv->argument_list, old_node);
-	if (index >= 0 && vala_code_node_get_parent_node (new_node) == NULL) {
-		gee_list_set (((GeeList*) self->priv->argument_list), index, VALA_EXPRESSION (new_node));
-		vala_code_node_set_parent_node (new_node, VALA_CODE_NODE (self));
+	if (index >= 0 && vala_code_node_get_parent_node (VALA_CODE_NODE (new_node)) == NULL) {
+		gee_list_set (((GeeList*) self->priv->argument_list), index, new_node);
+		vala_code_node_set_parent_node (VALA_CODE_NODE (new_node), VALA_CODE_NODE (self));
 	}
 }
 
 
+static gboolean vala_invocation_expression_real_is_pure (ValaExpression* base) {
+	ValaInvocationExpression * self;
+	self = VALA_INVOCATION_EXPRESSION (base);
+	return FALSE;
+}
+
+
 ValaExpression* vala_invocation_expression_get_call (ValaInvocationExpression* self) {
 	g_return_val_if_fail (VALA_IS_INVOCATION_EXPRESSION (self), NULL);
 	return self->_call;
@@ -169,14 +179,32 @@ ValaExpression* vala_invocation_expression_get_call (ValaInvocationExpression* s
 
 
 void vala_invocation_expression_set_call (ValaInvocationExpression* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->_call = (_tmp1 = g_object_ref (value), (self->_call == NULL ? NULL : (self->_call = (g_object_unref (self->_call), NULL))), _tmp1);
+	self->_call = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->_call == NULL ? NULL : (self->_call = (g_object_unref (self->_call), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->_call), VALA_CODE_NODE (self));
 }
 
 
+ValaCCodeExpression* vala_invocation_expression_get_delegate_target (ValaInvocationExpression* self) {
+	g_return_val_if_fail (VALA_IS_INVOCATION_EXPRESSION (self), NULL);
+	return self->priv->_delegate_target;
+}
+
+
+void vala_invocation_expression_set_delegate_target (ValaInvocationExpression* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
+	ValaCCodeExpression* _tmp1;
+	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_delegate_target = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_delegate_target == NULL ? NULL : (self->priv->_delegate_target = (g_object_unref (self->priv->_delegate_target), NULL))), _tmp2);
+}
+
+
 static void vala_invocation_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaInvocationExpression * self;
 	self = VALA_INVOCATION_EXPRESSION (object);
@@ -184,6 +212,9 @@ static void vala_invocation_expression_get_property (GObject * object, guint pro
 		case VALA_INVOCATION_EXPRESSION_CALL:
 		g_value_set_object (value, vala_invocation_expression_get_call (self));
 		break;
+		case VALA_INVOCATION_EXPRESSION_DELEGATE_TARGET:
+		g_value_set_object (value, vala_invocation_expression_get_delegate_target (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -198,6 +229,9 @@ static void vala_invocation_expression_set_property (GObject * object, guint pro
 		case VALA_INVOCATION_EXPRESSION_CALL:
 		vala_invocation_expression_set_call (self, g_value_get_object (value));
 		break;
+		case VALA_INVOCATION_EXPRESSION_DELEGATE_TARGET:
+		vala_invocation_expression_set_delegate_target (self, g_value_get_object (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -213,8 +247,10 @@ static void vala_invocation_expression_class_init (ValaInvocationExpressionClass
 	G_OBJECT_CLASS (klass)->dispose = vala_invocation_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_invocation_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_invocation_expression_real_accept_children;
-	VALA_CODE_NODE_CLASS (klass)->replace = vala_invocation_expression_real_replace;
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_invocation_expression_real_replace_expression;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_invocation_expression_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INVOCATION_EXPRESSION_CALL, g_param_spec_object ("call", "call", "call", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INVOCATION_EXPRESSION_DELEGATE_TARGET, g_param_spec_object ("delegate-target", "delegate-target", "delegate-target", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -228,6 +264,7 @@ static void vala_invocation_expression_init (ValaInvocationExpression * self) {
 static void vala_invocation_expression_dispose (GObject * obj) {
 	ValaInvocationExpression * self;
 	self = VALA_INVOCATION_EXPRESSION (obj);
+	(self->priv->_delegate_target == NULL ? NULL : (self->priv->_delegate_target = (g_object_unref (self->priv->_delegate_target), NULL)));
 	(self->_call == NULL ? NULL : (self->_call = (g_object_unref (self->_call), NULL)));
 	(self->priv->argument_list == NULL ? NULL : (self->priv->argument_list = (g_object_unref (self->priv->argument_list), NULL)));
 	(self->priv->array_sizes == NULL ? NULL : (self->priv->array_sizes = (g_object_unref (self->priv->array_sizes), NULL)));
