@@ -35,6 +35,8 @@ enum  {
 };
 static void vala_literal_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_literal_expression_real_to_string (ValaCodeNode* base);
+static gboolean vala_literal_expression_real_is_pure (ValaExpression* base);
+static void vala_literal_expression_set_literal (ValaLiteralExpression* self, ValaLiteral* value);
 static gpointer vala_literal_expression_parent_class = NULL;
 static void vala_literal_expression_dispose (GObject * obj);
 
@@ -50,7 +52,7 @@ ValaLiteralExpression* vala_literal_expression_new (ValaLiteral* _literal, ValaS
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaLiteralExpression * self;
-	g_return_val_if_fail (VALA_IS_LITERAL (_literal), NULL);
+	g_return_val_if_fail (_literal == NULL || VALA_IS_LITERAL (_literal), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -69,7 +71,7 @@ ValaLiteralExpression* vala_literal_expression_new (ValaLiteral* _literal, ValaS
 static void vala_literal_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaLiteralExpression * self;
 	self = VALA_LITERAL_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_literal_expression_get_literal (self)), visitor);
 	vala_code_visitor_visit_literal_expression (visitor, self);
 }
@@ -82,13 +84,20 @@ static char* vala_literal_expression_real_to_string (ValaCodeNode* base) {
 }
 
 
+static gboolean vala_literal_expression_real_is_pure (ValaExpression* base) {
+	ValaLiteralExpression * self;
+	self = VALA_LITERAL_EXPRESSION (base);
+	return TRUE;
+}
+
+
 ValaLiteral* vala_literal_expression_get_literal (ValaLiteralExpression* self) {
 	g_return_val_if_fail (VALA_IS_LITERAL_EXPRESSION (self), NULL);
 	return self->priv->_literal;
 }
 
 
-void vala_literal_expression_set_literal (ValaLiteralExpression* self, ValaLiteral* value) {
+static void vala_literal_expression_set_literal (ValaLiteralExpression* self, ValaLiteral* value) {
 	ValaLiteral* _tmp2;
 	ValaLiteral* _tmp1;
 	g_return_if_fail (VALA_IS_LITERAL_EXPRESSION (self));
@@ -134,6 +143,7 @@ static void vala_literal_expression_class_init (ValaLiteralExpressionClass * kla
 	G_OBJECT_CLASS (klass)->dispose = vala_literal_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_literal_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_literal_expression_real_to_string;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_literal_expression_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_LITERAL_EXPRESSION_LITERAL, g_param_spec_object ("literal", "literal", "literal", VALA_TYPE_LITERAL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
