@@ -67,7 +67,7 @@ ValaLockStatement* vala_lock_statement_new (ValaExpression* resource, ValaBlock*
 static void vala_lock_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaLockStatement * self;
 	self = VALA_LOCK_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_lock_statement_get_resource (self)), visitor);
 	vala_code_node_accept (VALA_CODE_NODE (vala_lock_statement_get_body (self)), visitor);
 	vala_code_visitor_visit_lock_statement (visitor, self);
@@ -81,10 +81,12 @@ ValaExpression* vala_lock_statement_get_resource (ValaLockStatement* self) {
 
 
 void vala_lock_statement_set_resource (ValaLockStatement* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_LOCK_STATEMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_resource = (_tmp1 = g_object_ref (value), (self->priv->_resource == NULL ? NULL : (self->priv->_resource = (g_object_unref (self->priv->_resource), NULL))), _tmp1);
+	self->priv->_resource = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_resource == NULL ? NULL : (self->priv->_resource = (g_object_unref (self->priv->_resource), NULL))), _tmp2);
 }
 
 
@@ -95,10 +97,12 @@ ValaBlock* vala_lock_statement_get_body (ValaLockStatement* self) {
 
 
 void vala_lock_statement_set_body (ValaLockStatement* self, ValaBlock* value) {
+	ValaBlock* _tmp2;
 	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_LOCK_STATEMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_body = (_tmp1 = g_object_ref (value), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp1);
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
 }
 
 
