@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,12 +20,11 @@
  * 	Raffaele Sandrini <rasa@gmx.ch>
  */
 
-#include "valamember.h"
+#include <vala/valamember.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
 #include <vala/valacodevisitor.h>
-#include <vala/valamember.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasourcefile.h>
 
@@ -42,24 +41,22 @@ static gpointer vala_member_parent_class = NULL;
 static void vala_member_dispose (GObject * obj);
 
 
-static void vala_member_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_member_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMember * self;
-	self = ((ValaMember*) base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = VALA_MEMBER (base);
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, self);
 }
 
 
-static GeeCollection* vala_member_real_get_cheader_filenames (ValaSymbol* base)
-{
+static GeeCollection* vala_member_real_get_cheader_filenames (ValaSymbol* base) {
 	ValaMember * self;
-	self = ((ValaMember*) base);
-	if (gee_collection_get_size (((GeeCollection*) self->priv->cheader_filenames)) == 0) {
+	self = VALA_MEMBER (base);
+	if (gee_collection_get_size (GEE_COLLECTION (self->priv->cheader_filenames)) == 0) {
 		{
 			GeeCollection* filename_collection;
 			GeeIterator* filename_it;
-			filename_collection = vala_symbol_get_cheader_filenames (vala_symbol_get_parent_symbol (((ValaSymbol*) self)));
+			filename_collection = vala_symbol_get_cheader_filenames (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)));
 			filename_it = gee_iterable_iterator (GEE_ITERABLE (filename_collection));
 			while (gee_iterator_next (filename_it)) {
 				char* filename;
@@ -73,15 +70,15 @@ static GeeCollection* vala_member_real_get_cheader_filenames (ValaSymbol* base)
 			(filename_collection == NULL ? NULL : (filename_collection = (g_object_unref (filename_collection), NULL)));
 			(filename_it == NULL ? NULL : (filename_it = (g_object_unref (filename_it), NULL)));
 		}
-		if (gee_collection_get_size (((GeeCollection*) self->priv->cheader_filenames)) == 0 && vala_code_node_get_source_reference (((ValaCodeNode*) self)) != NULL && !vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))) {
+		if (gee_collection_get_size (GEE_COLLECTION (self->priv->cheader_filenames)) == 0 && vala_code_node_get_source_reference (VALA_CODE_NODE (self)) != NULL && !vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))) {
 			char* _tmp0;
 			/* don't add default include directives for VAPI files*/
 			_tmp0 = NULL;
-			gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), (_tmp0 = vala_source_file_get_cinclude_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))));
+			gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), (_tmp0 = vala_source_file_get_cinclude_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))));
 			(_tmp0 = (g_free (_tmp0), NULL));
 		}
 	}
-	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, GEE_COLLECTION (self->priv->cheader_filenames)));
+	return GEE_COLLECTION (gee_read_only_collection_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, GEE_COLLECTION (self->priv->cheader_filenames)));
 }
 
 
@@ -91,16 +88,23 @@ static GeeCollection* vala_member_real_get_cheader_filenames (ValaSymbol* base)
  *
  * @param filename a C header filename
  */
-void vala_member_add_cheader_filename (ValaMember* self, const char* filename)
-{
+void vala_member_add_cheader_filename (ValaMember* self, const char* filename) {
 	g_return_if_fail (VALA_IS_MEMBER (self));
-	g_return_if_fail (filename != NULL);
 	gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), filename);
 }
 
 
-static void vala_member_class_init (ValaMemberClass * klass)
-{
+/**
+ * Represents a general class member.
+ */
+ValaMember* vala_member_new (void) {
+	ValaMember * self;
+	self = g_object_newv (VALA_TYPE_MEMBER, 0, NULL);
+	return self;
+}
+
+
+static void vala_member_class_init (ValaMemberClass * klass) {
 	vala_member_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaMemberPrivate));
 	G_OBJECT_CLASS (klass)->dispose = vala_member_dispose;
@@ -109,28 +113,21 @@ static void vala_member_class_init (ValaMemberClass * klass)
 }
 
 
-static void vala_member_init (ValaMember * self)
-{
+static void vala_member_init (ValaMember * self) {
 	self->priv = VALA_MEMBER_GET_PRIVATE (self);
-	self->priv->cheader_filenames = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_direct_equal));
+	self->priv->cheader_filenames = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_direct_equal));
 }
 
 
-static void vala_member_dispose (GObject * obj)
-{
+static void vala_member_dispose (GObject * obj) {
 	ValaMember * self;
-	ValaMemberClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_MEMBER (obj);
 	(self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (g_object_unref (self->priv->cheader_filenames), NULL)));
-	klass = VALA_MEMBER_CLASS (g_type_class_peek (VALA_TYPE_MEMBER));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_member_parent_class)->dispose (obj);
 }
 
 
-GType vala_member_get_type (void)
-{
+GType vala_member_get_type (void) {
 	static GType vala_member_type_id = 0;
 	if (G_UNLIKELY (vala_member_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaMemberClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_member_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMember), 0, (GInstanceInitFunc) vala_member_init };
