@@ -47,11 +47,11 @@ typedef struct _ValaMemberPrivate ValaMemberPrivate;
  * Represents a general class member.
  */
 struct _ValaMember {
-	ValaSymbol parent;
+	ValaSymbol parent_instance;
 	ValaMemberPrivate * priv;
 };
 struct _ValaMemberClass {
-	ValaSymbolClass parent;
+	ValaSymbolClass parent_class;
 };
 
 void vala_member_add_cheader_filename (ValaMember* self, const char* filename);
