@@ -1,6 +1,6 @@
 /* valamethod.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,9 +27,11 @@
 #include <gee/readonlycollection.h>
 #include <gee/iterable.h>
 #include <gee/iterator.h>
-#include <vala/valatypereference.h>
 #include <vala/valablock.h>
 #include <vala/valaformalparameter.h>
+#include <vala/valavariabledeclarator.h>
+#include <vala/valadatatype.h>
+#include <vala/valaexpression.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
 #include <vala/valascope.h>
@@ -37,16 +39,17 @@
 #include <vala/valaattribute.h>
 
 struct _ValaMethodPrivate {
-	ValaTypeReference* _return_type;
 	ValaBlock* _body;
 	gboolean _is_abstract;
 	gboolean _is_virtual;
 	gboolean _overrides;
+	gboolean _is_inline;
 	gboolean _returns_modified_pointer;
 	gboolean _instance_last;
 	ValaMethod* _base_method;
 	ValaMethod* _base_interface_method;
 	ValaFormalParameter* _this_parameter;
+	ValaVariableDeclarator* _result_var;
 	gboolean _printf_format;
 	gboolean _instance;
 	GeeList* parameters;
@@ -55,6 +58,9 @@ struct _ValaMethodPrivate {
 	char* _sentinel;
 	gboolean _no_array_length;
 	GeeList* error_domains;
+	GeeList* preconditions;
+	GeeList* postconditions;
+	ValaDataType* _return_type;
 };
 #define VALA_METHOD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_METHOD, ValaMethodPrivate))
 enum  {
@@ -67,23 +73,22 @@ enum  {
 	VALA_METHOD_IS_ABSTRACT,
 	VALA_METHOD_IS_VIRTUAL,
 	VALA_METHOD_OVERRIDES,
+	VALA_METHOD_IS_INLINE,
 	VALA_METHOD_RETURNS_MODIFIED_POINTER,
 	VALA_METHOD_INSTANCE_LAST,
 	VALA_METHOD_BASE_METHOD,
 	VALA_METHOD_BASE_INTERFACE_METHOD,
 	VALA_METHOD_THIS_PARAMETER,
+	VALA_METHOD_RESULT_VAR,
 	VALA_METHOD_NO_ARRAY_LENGTH,
 	VALA_METHOD_PRINTF_FORMAT
 };
-static GeeCollection* vala_method_real_get_parameters (ValaInvokable* base);
-static ValaTypeReference* vala_method_real_get_return_type (ValaInvokable* base);
-static gboolean vala_method_real_is_invokable (ValaInvokable* base);
 static void vala_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_method_real_get_default_cname (ValaMethod* self);
 static void vala_method_process_ccode_attribute (ValaMethod* self, ValaAttribute* a);
+static void vala_method_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_method_parent_class = NULL;
-static ValaInvokableIface* vala_method_vala_invokable_parent_iface = NULL;
 static void vala_method_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
@@ -96,9 +101,9 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
  * @param source      reference to source code
  * @return            newly created method
  */
-ValaMethod* vala_method_new (const char* name, ValaTypeReference* return_type, ValaSourceReference* source_reference) {
+ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
 	ValaMethod * self;
-	g_return_val_if_fail (return_type == NULL || VALA_IS_TYPE_REFERENCE (return_type), NULL);
+	g_return_val_if_fail (return_type == NULL || VALA_IS_DATA_TYPE (return_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_METHOD, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
@@ -115,7 +120,7 @@ ValaMethod* vala_method_new (const char* name, ValaTypeReference* return_type, V
  */
 void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param) {
 	g_return_if_fail (VALA_IS_METHOD (self));
-	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (param));
+	g_return_if_fail (param == NULL || VALA_IS_FORMAL_PARAMETER (param));
 	if (vala_method_get_no_array_length (self)) {
 		vala_formal_parameter_set_no_array_length (param, TRUE);
 	}
@@ -126,33 +131,16 @@ void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param) {
 }
 
 
-static GeeCollection* vala_method_real_get_parameters (ValaInvokable* base) {
-	ValaMethod * self;
-	self = VALA_METHOD (base);
-	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->parameters)));
-}
-
-
-static ValaTypeReference* vala_method_real_get_return_type (ValaInvokable* base) {
-	ValaMethod * self;
-	ValaTypeReference* _tmp0;
-	self = VALA_METHOD (base);
-	_tmp0 = NULL;
-	return (_tmp0 = vala_method_get_return_type (self), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
-}
-
-
-static gboolean vala_method_real_is_invokable (ValaInvokable* base) {
-	ValaMethod * self;
-	self = VALA_METHOD (base);
-	return TRUE;
+GeeCollection* vala_method_get_parameters (ValaMethod* self) {
+	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->parameters)));
 }
 
 
 static void vala_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMethod * self;
 	self = VALA_METHOD (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_method (visitor, self);
 }
 
@@ -160,7 +148,7 @@ static void vala_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visito
 static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMethod * self;
 	self = VALA_METHOD (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	if (vala_method_get_return_type (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_method_get_return_type (self)), visitor);
 	}
@@ -185,7 +173,7 @@ static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 		error_domain_collection = self->priv->error_domains;
 		error_domain_it = gee_iterable_iterator (GEE_ITERABLE (error_domain_collection));
 		while (gee_iterator_next (error_domain_it)) {
-			ValaTypeReference* error_domain;
+			ValaDataType* error_domain;
 			error_domain = gee_iterator_get (error_domain_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (error_domain), visitor);
@@ -194,6 +182,39 @@ static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 		}
 		(error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL)));
 	}
+	if (vala_method_get_result_var (self) != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (vala_variable_declarator_get_type_reference (vala_method_get_result_var (self))), visitor);
+	}
+	{
+		GeeList* precondition_collection;
+		GeeIterator* precondition_it;
+		precondition_collection = self->priv->preconditions;
+		precondition_it = gee_iterable_iterator (GEE_ITERABLE (precondition_collection));
+		while (gee_iterator_next (precondition_it)) {
+			ValaExpression* precondition;
+			precondition = gee_iterator_get (precondition_it);
+			{
+				vala_code_node_accept (VALA_CODE_NODE (precondition), visitor);
+				(precondition == NULL ? NULL : (precondition = (g_object_unref (precondition), NULL)));
+			}
+		}
+		(precondition_it == NULL ? NULL : (precondition_it = (g_object_unref (precondition_it), NULL)));
+	}
+	{
+		GeeList* postcondition_collection;
+		GeeIterator* postcondition_it;
+		postcondition_collection = self->priv->postconditions;
+		postcondition_it = gee_iterable_iterator (GEE_ITERABLE (postcondition_collection));
+		while (gee_iterator_next (postcondition_it)) {
+			ValaExpression* postcondition;
+			postcondition = gee_iterator_get (postcondition_it);
+			{
+				vala_code_node_accept (VALA_CODE_NODE (postcondition), visitor);
+				(postcondition == NULL ? NULL : (postcondition = (g_object_unref (postcondition), NULL)));
+			}
+		}
+		(postcondition_it == NULL ? NULL : (postcondition_it = (g_object_unref (postcondition_it), NULL)));
+	}
 	if (vala_method_get_body (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_method_get_body (self)), visitor);
 	}
@@ -243,7 +264,9 @@ static char* vala_method_real_get_default_cname (ValaMethod* self) {
 
 
 char* vala_method_get_default_cname (ValaMethod* self) {
-	return VALA_METHOD_GET_CLASS (self)->get_default_cname (self);
+	char* result;
+	result = VALA_METHOD_GET_CLASS (self)->get_default_cname (self);
+	return result;
 }
 
 
@@ -354,7 +377,7 @@ void vala_method_process_attributes (ValaMethod* self) {
 							vala_method_set_instance_last (self, TRUE);
 						} else {
 							if (g_utf8_collate (vala_attribute_get_name (a), "FloatingReference") == 0) {
-								vala_type_reference_set_floating_reference (vala_method_get_return_type (self), TRUE);
+								vala_data_type_set_floating_reference (vala_method_get_return_type (self), TRUE);
 							} else {
 								if (g_utf8_collate (vala_attribute_get_name (a), "NoArrayLength") == 0) {
 									vala_method_set_no_array_length (self, TRUE);
@@ -394,13 +417,13 @@ gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2) {
 	GeeIterator* method_error_domains_it;
 	gboolean _tmp14;
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
-	g_return_val_if_fail (VALA_IS_METHOD (m2), FALSE);
-	if (!vala_type_reference_equals (vala_method_get_return_type (m2), vala_method_get_return_type (self))) {
+	g_return_val_if_fail (m2 == NULL || VALA_IS_METHOD (m2), FALSE);
+	if (!vala_data_type_equals (vala_method_get_return_type (m2), vala_method_get_return_type (self))) {
 		return FALSE;
 	}
 	_tmp1 = NULL;
 	_tmp2 = NULL;
-	method_params_it = (_tmp2 = gee_iterable_iterator (GEE_ITERABLE ((_tmp1 = vala_invokable_get_parameters (VALA_INVOKABLE (m2))))), (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2);
+	method_params_it = (_tmp2 = gee_iterable_iterator (GEE_ITERABLE ((_tmp1 = vala_method_get_parameters (m2)))), (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2);
 	{
 		GeeList* param_collection;
 		GeeIterator* param_it;
@@ -418,7 +441,7 @@ gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2) {
 					return (_tmp3 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp3);
 				}
 				_tmp4 = NULL;
-				if ((_tmp5 = !vala_type_reference_equals (vala_formal_parameter_get_type_reference ((_tmp4 = gee_iterator_get (method_params_it))), vala_formal_parameter_get_type_reference (param)), (_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL))), _tmp5)) {
+				if ((_tmp5 = !vala_data_type_equals (vala_formal_parameter_get_type_reference ((_tmp4 = gee_iterator_get (method_params_it))), vala_formal_parameter_get_type_reference (param)), (_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL))), _tmp5)) {
 					gboolean _tmp6;
 					return (_tmp6 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp6);
 				}
@@ -441,10 +464,10 @@ gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2) {
 		error_domain_collection = self->priv->error_domains;
 		error_domain_it = gee_iterable_iterator (GEE_ITERABLE (error_domain_collection));
 		while (gee_iterator_next (error_domain_it)) {
-			ValaTypeReference* error_domain;
+			ValaDataType* error_domain;
 			error_domain = gee_iterator_get (error_domain_it);
 			{
-				ValaTypeReference* _tmp11;
+				ValaDataType* _tmp11;
 				gboolean _tmp12;
 				/* method may not have less error domains */
 				if (!gee_iterator_next (method_error_domains_it)) {
@@ -452,7 +475,7 @@ gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2) {
 					return (_tmp10 = FALSE, (error_domain == NULL ? NULL : (error_domain = (g_object_unref (error_domain), NULL))), (error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), (method_error_domains_it == NULL ? NULL : (method_error_domains_it = (g_object_unref (method_error_domains_it), NULL))), _tmp10);
 				}
 				_tmp11 = NULL;
-				if ((_tmp12 = !vala_type_reference_equals ((_tmp11 = gee_iterator_get (method_error_domains_it)), error_domain), (_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL))), _tmp12)) {
+				if ((_tmp12 = !vala_data_type_equals ((_tmp11 = gee_iterator_get (method_error_domains_it)), error_domain), (_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL))), _tmp12)) {
 					gboolean _tmp13;
 					return (_tmp13 = FALSE, (error_domain == NULL ? NULL : (error_domain = (g_object_unref (error_domain), NULL))), (error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), (method_error_domains_it == NULL ? NULL : (method_error_domains_it = (g_object_unref (method_error_domains_it), NULL))), _tmp13);
 				}
@@ -462,8 +485,6 @@ gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2) {
 		(error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL)));
 	}
 	return (_tmp14 = TRUE, (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), (method_error_domains_it == NULL ? NULL : (method_error_domains_it = (g_object_unref (method_error_domains_it), NULL))), _tmp14);
-	(method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL)));
-	(method_error_domains_it == NULL ? NULL : (method_error_domains_it = (g_object_unref (method_error_domains_it), NULL)));
 }
 
 
@@ -472,10 +493,11 @@ gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2) {
  *
  * @param error_domain an error domain
  */
-void vala_method_add_error_domain (ValaMethod* self, ValaTypeReference* error_domain) {
+void vala_method_add_error_domain (ValaMethod* self, ValaDataType* error_domain) {
 	g_return_if_fail (VALA_IS_METHOD (self));
-	g_return_if_fail (VALA_IS_TYPE_REFERENCE (error_domain));
+	g_return_if_fail (error_domain == NULL || VALA_IS_DATA_TYPE (error_domain));
 	gee_collection_add (GEE_COLLECTION (self->priv->error_domains), error_domain);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (error_domain), VALA_CODE_NODE (self));
 }
 
 
@@ -486,23 +508,97 @@ void vala_method_add_error_domain (ValaMethod* self, ValaTypeReference* error_do
  */
 GeeCollection* vala_method_get_error_domains (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->error_domains)));
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->error_domains)));
 }
 
 
-ValaTypeReference* vala_method_get_return_type (ValaMethod* self) {
+/**
+ * Adds a precondition to this method.
+ *
+ * @param precondition a boolean precondition expression
+ */
+void vala_method_add_precondition (ValaMethod* self, ValaExpression* precondition) {
+	g_return_if_fail (VALA_IS_METHOD (self));
+	g_return_if_fail (precondition == NULL || VALA_IS_EXPRESSION (precondition));
+	gee_collection_add (GEE_COLLECTION (self->priv->preconditions), precondition);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (precondition), VALA_CODE_NODE (self));
+}
+
+
+/**
+ * Returns a copy of the list of preconditions of this method.
+ *
+ * @return list of preconditions
+ */
+GeeCollection* vala_method_get_preconditions (ValaMethod* self) {
+	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->preconditions)));
+}
+
+
+/**
+ * Adds a postcondition to this method.
+ *
+ * @param postcondition a boolean postcondition expression
+ */
+void vala_method_add_postcondition (ValaMethod* self, ValaExpression* postcondition) {
+	g_return_if_fail (VALA_IS_METHOD (self));
+	g_return_if_fail (postcondition == NULL || VALA_IS_EXPRESSION (postcondition));
+	gee_collection_add (GEE_COLLECTION (self->priv->postconditions), postcondition);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (postcondition), VALA_CODE_NODE (self));
+}
+
+
+/**
+ * Returns a copy of the list of postconditions of this method.
+ *
+ * @return list of postconditions
+ */
+GeeCollection* vala_method_get_postconditions (ValaMethod* self) {
+	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->postconditions)));
+}
+
+
+static void vala_method_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
+	ValaMethod * self;
+	self = VALA_METHOD (base);
+	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	if (vala_method_get_return_type (self) == old_type) {
+		vala_method_set_return_type (self, new_type);
+		return;
+	}
+	{
+		gint i;
+		i = 0;
+		for (i = 0; i < gee_collection_get_size (GEE_COLLECTION (self->priv->error_domains)); i++) {
+			ValaDataType* _tmp0;
+			gboolean _tmp1;
+			_tmp0 = NULL;
+			if ((_tmp1 = (_tmp0 = gee_list_get (((GeeList*) self->priv->error_domains), i)) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+				gee_list_set (((GeeList*) self->priv->error_domains), i, new_type);
+				return;
+			}
+		}
+	}
+}
+
+
+ValaDataType* vala_method_get_return_type (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	return self->priv->_return_type;
 }
 
 
-void vala_method_set_return_type (ValaMethod* self, ValaTypeReference* value) {
-	ValaTypeReference* _tmp2;
-	ValaTypeReference* _tmp1;
+void vala_method_set_return_type (ValaMethod* self, ValaDataType* value) {
+	ValaDataType* _tmp2;
+	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_METHOD (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_return_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), _tmp2);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_return_type), VALA_CODE_NODE (self));
 }
 
 
@@ -548,10 +644,12 @@ char* vala_method_get_vfunc_name (ValaMethod* self) {
 
 
 void vala_method_set_vfunc_name (ValaMethod* self, const char* value) {
-	char* _tmp3;
+	char* _tmp4;
+	const char* _tmp3;
 	g_return_if_fail (VALA_IS_METHOD (self));
+	_tmp4 = NULL;
 	_tmp3 = NULL;
-	self->priv->_vfunc_name = (_tmp3 = g_strdup (value), (self->priv->_vfunc_name = (g_free (self->priv->_vfunc_name), NULL)), _tmp3);
+	self->priv->_vfunc_name = (_tmp4 = (_tmp3 = value, (_tmp3 == NULL ? NULL : g_strdup (_tmp3))), (self->priv->_vfunc_name = (g_free (self->priv->_vfunc_name), NULL)), _tmp4);
 }
 
 
@@ -565,10 +663,12 @@ char* vala_method_get_sentinel (ValaMethod* self) {
 
 
 void vala_method_set_sentinel (ValaMethod* self, const char* value) {
-	char* _tmp2;
+	char* _tmp3;
+	const char* _tmp2;
 	g_return_if_fail (VALA_IS_METHOD (self));
+	_tmp3 = NULL;
 	_tmp2 = NULL;
-	self->priv->_sentinel = (_tmp2 = g_strdup (value), (self->priv->_sentinel = (g_free (self->priv->_sentinel), NULL)), _tmp2);
+	self->priv->_sentinel = (_tmp3 = (_tmp2 = value, (_tmp2 == NULL ? NULL : g_strdup (_tmp2))), (self->priv->_sentinel = (g_free (self->priv->_sentinel), NULL)), _tmp3);
 }
 
 
@@ -608,6 +708,18 @@ void vala_method_set_overrides (ValaMethod* self, gboolean value) {
 }
 
 
+gboolean vala_method_get_is_inline (ValaMethod* self) {
+	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
+	return self->priv->_is_inline;
+}
+
+
+void vala_method_set_is_inline (ValaMethod* self, gboolean value) {
+	g_return_if_fail (VALA_IS_METHOD (self));
+	self->priv->_is_inline = value;
+}
+
+
 gboolean vala_method_get_returns_modified_pointer (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
 	return self->priv->_returns_modified_pointer;
@@ -676,6 +788,22 @@ void vala_method_set_this_parameter (ValaMethod* self, ValaFormalParameter* valu
 }
 
 
+ValaVariableDeclarator* vala_method_get_result_var (ValaMethod* self) {
+	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
+	return self->priv->_result_var;
+}
+
+
+void vala_method_set_result_var (ValaMethod* self, ValaVariableDeclarator* value) {
+	ValaVariableDeclarator* _tmp2;
+	ValaVariableDeclarator* _tmp1;
+	g_return_if_fail (VALA_IS_METHOD (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_result_var = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_result_var == NULL ? NULL : (self->priv->_result_var = (g_object_unref (self->priv->_result_var), NULL))), _tmp2);
+}
+
+
 gboolean vala_method_get_no_array_length (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
 	return self->priv->_no_array_length;
@@ -743,6 +871,9 @@ static void vala_method_get_property (GObject * object, guint property_id, GValu
 		case VALA_METHOD_OVERRIDES:
 		g_value_set_boolean (value, vala_method_get_overrides (self));
 		break;
+		case VALA_METHOD_IS_INLINE:
+		g_value_set_boolean (value, vala_method_get_is_inline (self));
+		break;
 		case VALA_METHOD_RETURNS_MODIFIED_POINTER:
 		g_value_set_boolean (value, vala_method_get_returns_modified_pointer (self));
 		break;
@@ -758,6 +889,9 @@ static void vala_method_get_property (GObject * object, guint property_id, GValu
 		case VALA_METHOD_THIS_PARAMETER:
 		g_value_set_object (value, vala_method_get_this_parameter (self));
 		break;
+		case VALA_METHOD_RESULT_VAR:
+		g_value_set_object (value, vala_method_get_result_var (self));
+		break;
 		case VALA_METHOD_NO_ARRAY_LENGTH:
 		g_value_set_boolean (value, vala_method_get_no_array_length (self));
 		break;
@@ -799,6 +933,9 @@ static void vala_method_set_property (GObject * object, guint property_id, const
 		case VALA_METHOD_OVERRIDES:
 		vala_method_set_overrides (self, g_value_get_boolean (value));
 		break;
+		case VALA_METHOD_IS_INLINE:
+		vala_method_set_is_inline (self, g_value_get_boolean (value));
+		break;
 		case VALA_METHOD_RETURNS_MODIFIED_POINTER:
 		vala_method_set_returns_modified_pointer (self, g_value_get_boolean (value));
 		break;
@@ -814,6 +951,9 @@ static void vala_method_set_property (GObject * object, guint property_id, const
 		case VALA_METHOD_THIS_PARAMETER:
 		vala_method_set_this_parameter (self, g_value_get_object (value));
 		break;
+		case VALA_METHOD_RESULT_VAR:
+		vala_method_set_result_var (self, g_value_get_object (value));
+		break;
 		case VALA_METHOD_NO_ARRAY_LENGTH:
 		vala_method_set_no_array_length (self, g_value_get_boolean (value));
 		break;
@@ -836,7 +976,8 @@ static void vala_method_class_init (ValaMethodClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_method_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_method_real_accept_children;
 	VALA_METHOD_CLASS (klass)->get_default_cname = vala_method_real_get_default_cname;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RETURN_TYPE, g_param_spec_object ("return-type", "return-type", "return-type", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_method_real_replace_type;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RETURN_TYPE, g_param_spec_object ("return-type", "return-type", "return-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_VFUNC_NAME, g_param_spec_string ("vfunc-name", "vfunc-name", "vfunc-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -844,44 +985,43 @@ static void vala_method_class_init (ValaMethodClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_IS_ABSTRACT, g_param_spec_boolean ("is-abstract", "is-abstract", "is-abstract", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_IS_VIRTUAL, g_param_spec_boolean ("is-virtual", "is-virtual", "is-virtual", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_OVERRIDES, g_param_spec_boolean ("overrides", "overrides", "overrides", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_IS_INLINE, g_param_spec_boolean ("is-inline", "is-inline", "is-inline", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RETURNS_MODIFIED_POINTER, g_param_spec_boolean ("returns-modified-pointer", "returns-modified-pointer", "returns-modified-pointer", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_INSTANCE_LAST, g_param_spec_boolean ("instance-last", "instance-last", "instance-last", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BASE_METHOD, g_param_spec_object ("base-method", "base-method", "base-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BASE_INTERFACE_METHOD, g_param_spec_object ("base-interface-method", "base-interface-method", "base-interface-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_THIS_PARAMETER, g_param_spec_object ("this-parameter", "this-parameter", "this-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RESULT_VAR, g_param_spec_object ("result-var", "result-var", "result-var", VALA_TYPE_VARIABLE_DECLARATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_PRINTF_FORMAT, g_param_spec_boolean ("printf-format", "printf-format", "printf-format", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_method_vala_invokable_interface_init (ValaInvokableIface * iface) {
-	vala_method_vala_invokable_parent_iface = g_type_interface_peek_parent (iface);
-	iface->get_parameters = vala_method_real_get_parameters;
-	iface->get_return_type = vala_method_real_get_return_type;
-	iface->is_invokable = vala_method_real_is_invokable;
-}
-
-
 static void vala_method_init (ValaMethod * self) {
 	self->priv = VALA_METHOD_GET_PRIVATE (self);
 	self->priv->_instance = TRUE;
-	self->priv->parameters = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
-	self->priv->error_domains = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->error_domains = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->preconditions = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->postconditions = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
 static void vala_method_dispose (GObject * obj) {
 	ValaMethod * self;
 	self = VALA_METHOD (obj);
-	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	(self->priv->_base_interface_method == NULL ? NULL : (self->priv->_base_interface_method = (g_object_unref (self->priv->_base_interface_method), NULL)));
 	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL)));
+	(self->priv->_result_var == NULL ? NULL : (self->priv->_result_var = (g_object_unref (self->priv->_result_var), NULL)));
 	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
 	(self->priv->cname = (g_free (self->priv->cname), NULL));
 	(self->priv->_vfunc_name = (g_free (self->priv->_vfunc_name), NULL));
 	(self->priv->_sentinel = (g_free (self->priv->_sentinel), NULL));
 	(self->priv->error_domains == NULL ? NULL : (self->priv->error_domains = (g_object_unref (self->priv->error_domains), NULL)));
+	(self->priv->preconditions == NULL ? NULL : (self->priv->preconditions = (g_object_unref (self->priv->preconditions), NULL)));
+	(self->priv->postconditions == NULL ? NULL : (self->priv->postconditions = (g_object_unref (self->priv->postconditions), NULL)));
+	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
 	G_OBJECT_CLASS (vala_method_parent_class)->dispose (obj);
 }
 
@@ -890,9 +1030,7 @@ GType vala_method_get_type (void) {
 	static GType vala_method_type_id = 0;
 	if (G_UNLIKELY (vala_method_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMethod), 0, (GInstanceInitFunc) vala_method_init };
-		static const GInterfaceInfo vala_invokable_info = { (GInterfaceInitFunc) vala_method_vala_invokable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_method_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaMethod", &g_define_type_info, 0);
-		g_type_add_interface_static (vala_method_type_id, VALA_TYPE_INVOKABLE, &vala_invokable_info);
 	}
 	return vala_method_type_id;
 }
