@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,10 +20,9 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valanamedargument.h"
+#include <vala/valanamedargument.h>
 #include <vala/valaexpression.h>
 #include <vala/valasourcereference.h>
-#include <vala/valanamedargument.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaNamedArgumentPrivate {
@@ -49,13 +48,11 @@ static void vala_named_argument_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created named argument
  */
-ValaNamedArgument* vala_named_argument_new (const char* _name, ValaExpression* arg, ValaSourceReference* source)
-{
+ValaNamedArgument* vala_named_argument_new (const char* _name, ValaExpression* arg, ValaSourceReference* source) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaNamedArgument * self;
-	g_return_val_if_fail (_name != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_EXPRESSION (arg), NULL);
+	g_return_val_if_fail (arg == NULL || VALA_IS_EXPRESSION (arg), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
@@ -72,50 +69,48 @@ ValaNamedArgument* vala_named_argument_new (const char* _name, ValaExpression* a
 }
 
 
-static void vala_named_argument_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_named_argument_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaNamedArgument * self;
-	self = ((ValaNamedArgument*) base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = VALA_NAMED_ARGUMENT (base);
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_named_argument_get_argument (self)), visitor);
 	vala_code_visitor_visit_named_argument (visitor, self);
 }
 
 
-char* vala_named_argument_get_name (ValaNamedArgument* self)
-{
+char* vala_named_argument_get_name (ValaNamedArgument* self) {
 	g_return_val_if_fail (VALA_IS_NAMED_ARGUMENT (self), NULL);
 	return self->priv->_name;
 }
 
 
-void vala_named_argument_set_name (ValaNamedArgument* self, const char* value)
-{
-	char* __temp1;
+void vala_named_argument_set_name (ValaNamedArgument* self, const char* value) {
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_NAMED_ARGUMENT (self));
-	__temp1 = NULL;
-	self->priv->_name = (__temp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp1);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
 }
 
 
-ValaExpression* vala_named_argument_get_argument (ValaNamedArgument* self)
-{
+ValaExpression* vala_named_argument_get_argument (ValaNamedArgument* self) {
 	g_return_val_if_fail (VALA_IS_NAMED_ARGUMENT (self), NULL);
 	return self->priv->_argument;
 }
 
 
-void vala_named_argument_set_argument (ValaNamedArgument* self, ValaExpression* value)
-{
-	ValaExpression* __temp3;
+void vala_named_argument_set_argument (ValaNamedArgument* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_NAMED_ARGUMENT (self));
-	__temp3 = NULL;
-	self->priv->_argument = (__temp3 = g_object_ref (value), (self->priv->_argument == NULL ? NULL : (self->priv->_argument = (g_object_unref (self->priv->_argument), NULL))), __temp3);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_argument = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_argument == NULL ? NULL : (self->priv->_argument = (g_object_unref (self->priv->_argument), NULL))), _tmp2);
 }
 
 
-static void vala_named_argument_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_named_argument_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaNamedArgument * self;
 	self = VALA_NAMED_ARGUMENT (object);
 	switch (property_id) {
@@ -125,12 +120,14 @@ static void vala_named_argument_get_property (GObject * object, guint property_i
 		case VALA_NAMED_ARGUMENT_ARGUMENT:
 		g_value_set_object (value, vala_named_argument_get_argument (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_named_argument_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_named_argument_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaNamedArgument * self;
 	self = VALA_NAMED_ARGUMENT (object);
 	switch (property_id) {
@@ -140,45 +137,40 @@ static void vala_named_argument_set_property (GObject * object, guint property_i
 		case VALA_NAMED_ARGUMENT_ARGUMENT:
 		vala_named_argument_set_argument (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_named_argument_class_init (ValaNamedArgumentClass * klass)
-{
+static void vala_named_argument_class_init (ValaNamedArgumentClass * klass) {
 	vala_named_argument_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaNamedArgumentPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_named_argument_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_named_argument_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_named_argument_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_named_argument_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_NAMED_ARGUMENT_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_NAMED_ARGUMENT_ARGUMENT, g_param_spec_object ("argument", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_NAMED_ARGUMENT_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_NAMED_ARGUMENT_ARGUMENT, g_param_spec_object ("argument", "argument", "argument", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_named_argument_init (ValaNamedArgument * self)
-{
+static void vala_named_argument_init (ValaNamedArgument * self) {
 	self->priv = VALA_NAMED_ARGUMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_named_argument_dispose (GObject * obj)
-{
+static void vala_named_argument_dispose (GObject * obj) {
 	ValaNamedArgument * self;
-	ValaNamedArgumentClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_NAMED_ARGUMENT (obj);
 	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->priv->_argument == NULL ? NULL : (self->priv->_argument = (g_object_unref (self->priv->_argument), NULL)));
-	klass = VALA_NAMED_ARGUMENT_CLASS (g_type_class_peek (VALA_TYPE_NAMED_ARGUMENT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_named_argument_parent_class)->dispose (obj);
 }
 
 
-GType vala_named_argument_get_type (void)
-{
+GType vala_named_argument_get_type (void) {
 	static GType vala_named_argument_type_id = 0;
 	if (G_UNLIKELY (vala_named_argument_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaNamedArgumentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_named_argument_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNamedArgument), 0, (GInstanceInitFunc) vala_named_argument_init };
