@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALANAMEDARGUMENT_H__
-#define __VALANAMEDARGUMENT_H__
+#ifndef __VALA_VALANAMEDARGUMENT_H__
+#define __VALA_VALANAMEDARGUMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -46,11 +46,11 @@ typedef struct _ValaNamedArgumentPrivate ValaNamedArgumentPrivate;
  * when creating objects and attributes where no parameter list exists.
  */
 struct _ValaNamedArgument {
-	ValaCodeNode parent;
+	ValaCodeNode parent_instance;
 	ValaNamedArgumentPrivate * priv;
 };
 struct _ValaNamedArgumentClass {
-	ValaCodeNodeClass parent;
+	ValaCodeNodeClass parent_class;
 };
 
 ValaNamedArgument* vala_named_argument_new (const char* _name, ValaExpression* arg, ValaSourceReference* source);
