@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALANAMESPACEREFERENCE_H__
-#define __VALANAMESPACEREFERENCE_H__
+#ifndef __VALA_VALANAMESPACEREFERENCE_H__
+#define __VALA_VALANAMESPACEREFERENCE_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -45,11 +45,11 @@ typedef struct _ValaNamespaceReferencePrivate ValaNamespaceReferencePrivate;
  * A reference to a namespace symbol.
  */
 struct _ValaNamespaceReference {
-	ValaCodeNode parent;
+	ValaCodeNode parent_instance;
 	ValaNamespaceReferencePrivate * priv;
 };
 struct _ValaNamespaceReferenceClass {
-	ValaCodeNodeClass parent;
+	ValaCodeNodeClass parent_class;
 };
 
 ValaNamespaceReference* vala_namespace_reference_new (const char* name, ValaSourceReference* source_reference);
