@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,13 +19,10 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
-#include "valanullliteral.h"
+#include <vala/valanullliteral.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
-#include <vala/valanullliteral.h>
 
 enum  {
 	VALA_NULL_LITERAL_DUMMY_PROPERTY
@@ -41,52 +38,42 @@ static gpointer vala_null_literal_parent_class = NULL;
  * @param source reference to source code
  * @return       newly created null literal
  */
-ValaNullLiteral* vala_null_literal_new (ValaSourceReference* source)
-{
-	GParameter * __params;
-	GParameter * __params_it;
+ValaNullLiteral* vala_null_literal_new (ValaSourceReference* source) {
 	ValaNullLiteral * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_NULL_LITERAL, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_NULL_LITERAL, 0, NULL);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
-static void vala_null_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_null_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaNullLiteral * self;
 	self = VALA_NULL_LITERAL (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_null_literal (visitor, self);
 }
 
 
-static char* vala_null_literal_real_to_string (ValaCodeNode* base)
-{
+static char* vala_null_literal_real_to_string (ValaCodeNode* base) {
 	ValaNullLiteral * self;
 	self = VALA_NULL_LITERAL (base);
 	return g_strdup ("null");
 }
 
 
-static void vala_null_literal_class_init (ValaNullLiteralClass * klass)
-{
+static void vala_null_literal_class_init (ValaNullLiteralClass * klass) {
 	vala_null_literal_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_null_literal_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_null_literal_real_to_string;
 }
 
 
-static void vala_null_literal_init (ValaNullLiteral * self)
-{
+static void vala_null_literal_init (ValaNullLiteral * self) {
 }
 
 
-GType vala_null_literal_get_type ()
-{
+GType vala_null_literal_get_type (void) {
 	static GType vala_null_literal_type_id = 0;
 	if (G_UNLIKELY (vala_null_literal_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaNullLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_null_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNullLiteral), 0, (GInstanceInitFunc) vala_null_literal_init };
