@@ -24,19 +24,19 @@
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
-#include <vala/valatypereference.h>
 #include <vala/valamethod.h>
 #include <vala/valamemberaccess.h>
-#include <vala/valasourcereference.h>
 #include <vala/valamemberinitializer.h>
+#include <vala/valadatatype.h>
+#include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaObjectCreationExpressionPrivate {
-	ValaTypeReference* _type_reference;
 	ValaMethod* _constructor;
 	ValaMemberAccess* _member_name;
 	GeeList* argument_list;
 	GeeList* object_initializer;
+	ValaDataType* _data_type;
 };
 #define VALA_OBJECT_CREATION_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_OBJECT_CREATION_EXPRESSION, ValaObjectCreationExpressionPrivate))
 enum  {
@@ -47,7 +47,9 @@ enum  {
 };
 static void vala_object_creation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_object_creation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static void vala_object_creation_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
+static void vala_object_creation_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
+static gboolean vala_object_creation_expression_real_is_pure (ValaExpression* base);
+static void vala_object_creation_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_object_creation_expression_parent_class = NULL;
 static void vala_object_creation_expression_dispose (GObject * obj);
 
@@ -61,7 +63,7 @@ static void vala_object_creation_expression_dispose (GObject * obj);
  */
 ValaObjectCreationExpression* vala_object_creation_expression_new (ValaMemberAccess* member_name, ValaSourceReference* source_reference) {
 	ValaObjectCreationExpression * self;
-	g_return_val_if_fail (VALA_IS_MEMBER_ACCESS (member_name), NULL);
+	g_return_val_if_fail (member_name == NULL || VALA_IS_MEMBER_ACCESS (member_name), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_OBJECT_CREATION_EXPRESSION, 0, NULL);
 	vala_object_creation_expression_set_member_name (self, member_name);
@@ -77,7 +79,7 @@ ValaObjectCreationExpression* vala_object_creation_expression_new (ValaMemberAcc
  */
 void vala_object_creation_expression_add_argument (ValaObjectCreationExpression* self, ValaExpression* arg) {
 	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self));
-	g_return_if_fail (VALA_IS_EXPRESSION (arg));
+	g_return_if_fail (arg == NULL || VALA_IS_EXPRESSION (arg));
 	gee_collection_add (GEE_COLLECTION (self->priv->argument_list), arg);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (arg), VALA_CODE_NODE (self));
 }
@@ -90,7 +92,7 @@ void vala_object_creation_expression_add_argument (ValaObjectCreationExpression*
  */
 GeeCollection* vala_object_creation_expression_get_argument_list (ValaObjectCreationExpression* self) {
 	g_return_val_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->argument_list)));
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->argument_list)));
 }
 
 
@@ -101,7 +103,7 @@ GeeCollection* vala_object_creation_expression_get_argument_list (ValaObjectCrea
  */
 void vala_object_creation_expression_add_member_initializer (ValaObjectCreationExpression* self, ValaMemberInitializer* init) {
 	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self));
-	g_return_if_fail (VALA_IS_MEMBER_INITIALIZER (init));
+	g_return_if_fail (init == NULL || VALA_IS_MEMBER_INITIALIZER (init));
 	gee_collection_add (GEE_COLLECTION (self->priv->object_initializer), init);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (init), VALA_CODE_NODE (self));
 }
@@ -114,14 +116,14 @@ void vala_object_creation_expression_add_member_initializer (ValaObjectCreationE
  */
 GeeCollection* vala_object_creation_expression_get_object_initializer (ValaObjectCreationExpression* self) {
 	g_return_val_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->object_initializer)));
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_MEMBER_INITIALIZER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->object_initializer)));
 }
 
 
 static void vala_object_creation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaObjectCreationExpression * self;
 	self = VALA_OBJECT_CREATION_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_object_creation_expression (visitor, self);
 }
 
@@ -129,7 +131,7 @@ static void vala_object_creation_expression_real_accept (ValaCodeNode* base, Val
 static void vala_object_creation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaObjectCreationExpression * self;
 	self = VALA_OBJECT_CREATION_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	if (vala_object_creation_expression_get_type_reference (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_object_creation_expression_get_type_reference (self)), visitor);
 	}
@@ -169,33 +171,52 @@ static void vala_object_creation_expression_real_accept_children (ValaCodeNode*
 }
 
 
-static void vala_object_creation_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node) {
+static void vala_object_creation_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaObjectCreationExpression * self;
 	gint index;
 	self = VALA_OBJECT_CREATION_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
-	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
+	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
 	index = gee_list_index_of (self->priv->argument_list, old_node);
-	if (index >= 0 && vala_code_node_get_parent_node (new_node) == NULL) {
-		gee_list_set (((GeeList*) self->priv->argument_list), index, VALA_EXPRESSION (new_node));
-		vala_code_node_set_parent_node (new_node, VALA_CODE_NODE (self));
+	if (index >= 0 && vala_code_node_get_parent_node (VALA_CODE_NODE (new_node)) == NULL) {
+		gee_list_set (((GeeList*) self->priv->argument_list), index, new_node);
+		vala_code_node_set_parent_node (VALA_CODE_NODE (new_node), VALA_CODE_NODE (self));
 	}
 }
 
 
-ValaTypeReference* vala_object_creation_expression_get_type_reference (ValaObjectCreationExpression* self) {
-	g_return_val_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self), NULL);
-	return self->priv->_type_reference;
+static gboolean vala_object_creation_expression_real_is_pure (ValaExpression* base) {
+	ValaObjectCreationExpression * self;
+	self = VALA_OBJECT_CREATION_EXPRESSION (base);
+	return FALSE;
 }
 
 
-void vala_object_creation_expression_set_type_reference (ValaObjectCreationExpression* self, ValaTypeReference* value) {
-	ValaTypeReference* _tmp2;
-	ValaTypeReference* _tmp1;
+static void vala_object_creation_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
+	ValaObjectCreationExpression * self;
+	self = VALA_OBJECT_CREATION_EXPRESSION (base);
+	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	if (vala_object_creation_expression_get_type_reference (self) == old_type) {
+		vala_object_creation_expression_set_type_reference (self, new_type);
+	}
+}
+
+
+ValaDataType* vala_object_creation_expression_get_type_reference (ValaObjectCreationExpression* self) {
+	g_return_val_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self), NULL);
+	return self->priv->_data_type;
+}
+
+
+void vala_object_creation_expression_set_type_reference (ValaObjectCreationExpression* self, ValaDataType* value) {
+	ValaDataType* _tmp2;
+	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_type_reference = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp2);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
 }
 
 
@@ -279,8 +300,10 @@ static void vala_object_creation_expression_class_init (ValaObjectCreationExpres
 	G_OBJECT_CLASS (klass)->dispose = vala_object_creation_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_object_creation_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_object_creation_expression_real_accept_children;
-	VALA_CODE_NODE_CLASS (klass)->replace = vala_object_creation_expression_real_replace;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_OBJECT_CREATION_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_object_creation_expression_real_replace_expression;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_object_creation_expression_real_is_pure;
+	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_object_creation_expression_real_replace_type;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_OBJECT_CREATION_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_OBJECT_CREATION_EXPRESSION_CONSTRUCTOR, g_param_spec_object ("constructor", "constructor", "constructor", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_OBJECT_CREATION_EXPRESSION_MEMBER_NAME, g_param_spec_object ("member-name", "member-name", "member-name", VALA_TYPE_MEMBER_ACCESS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -288,19 +311,19 @@ static void vala_object_creation_expression_class_init (ValaObjectCreationExpres
 
 static void vala_object_creation_expression_init (ValaObjectCreationExpression * self) {
 	self->priv = VALA_OBJECT_CREATION_EXPRESSION_GET_PRIVATE (self);
-	self->priv->argument_list = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
-	self->priv->object_initializer = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->argument_list = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->object_initializer = GEE_LIST (gee_array_list_new (VALA_TYPE_MEMBER_INITIALIZER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
 static void vala_object_creation_expression_dispose (GObject * obj) {
 	ValaObjectCreationExpression * self;
 	self = VALA_OBJECT_CREATION_EXPRESSION (obj);
-	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
 	(self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (g_object_unref (self->priv->_constructor), NULL)));
 	(self->priv->_member_name == NULL ? NULL : (self->priv->_member_name = (g_object_unref (self->priv->_member_name), NULL)));
 	(self->priv->argument_list == NULL ? NULL : (self->priv->argument_list = (g_object_unref (self->priv->argument_list), NULL)));
 	(self->priv->object_initializer == NULL ? NULL : (self->priv->object_initializer = (g_object_unref (self->priv->object_initializer), NULL)));
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
 	G_OBJECT_CLASS (vala_object_creation_expression_parent_class)->dispose (obj);
 }
 
