@@ -1,6 +1,6 @@
 /* valaparenthesizedexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -33,7 +33,8 @@ enum  {
 	VALA_PARENTHESIZED_EXPRESSION_INNER
 };
 static void vala_parenthesized_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static void vala_parenthesized_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
+static void vala_parenthesized_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
+static gboolean vala_parenthesized_expression_real_is_pure (ValaExpression* base);
 static gpointer vala_parenthesized_expression_parent_class = NULL;
 static void vala_parenthesized_expression_dispose (GObject * obj);
 
@@ -49,7 +50,7 @@ ValaParenthesizedExpression* vala_parenthesized_expression_new (ValaExpression*
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaParenthesizedExpression * self;
-	g_return_val_if_fail (VALA_IS_EXPRESSION (_inner), NULL);
+	g_return_val_if_fail (_inner == NULL || VALA_IS_EXPRESSION (_inner), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -68,23 +69,30 @@ ValaParenthesizedExpression* vala_parenthesized_expression_new (ValaExpression*
 static void vala_parenthesized_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaParenthesizedExpression * self;
 	self = VALA_PARENTHESIZED_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_parenthesized_expression_get_inner (self)), visitor);
 	vala_code_visitor_visit_parenthesized_expression (visitor, self);
 }
 
 
-static void vala_parenthesized_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node) {
+static void vala_parenthesized_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaParenthesizedExpression * self;
 	self = VALA_PARENTHESIZED_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
-	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
-	if (VALA_CODE_NODE (vala_parenthesized_expression_get_inner (self)) == old_node) {
-		vala_parenthesized_expression_set_inner (self, VALA_EXPRESSION (new_node));
+	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	if (vala_parenthesized_expression_get_inner (self) == old_node) {
+		vala_parenthesized_expression_set_inner (self, new_node);
 	}
 }
 
 
+static gboolean vala_parenthesized_expression_real_is_pure (ValaExpression* base) {
+	ValaParenthesizedExpression * self;
+	self = VALA_PARENTHESIZED_EXPRESSION (base);
+	return vala_expression_is_pure (vala_parenthesized_expression_get_inner (self));
+}
+
+
 ValaExpression* vala_parenthesized_expression_get_inner (ValaParenthesizedExpression* self) {
 	g_return_val_if_fail (VALA_IS_PARENTHESIZED_EXPRESSION (self), NULL);
 	return self->priv->_inner;
@@ -92,10 +100,12 @@ ValaExpression* vala_parenthesized_expression_get_inner (ValaParenthesizedExpres
 
 
 void vala_parenthesized_expression_set_inner (ValaParenthesizedExpression* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_PARENTHESIZED_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
 }
 
@@ -135,7 +145,8 @@ static void vala_parenthesized_expression_class_init (ValaParenthesizedExpressio
 	G_OBJECT_CLASS (klass)->set_property = vala_parenthesized_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_parenthesized_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_parenthesized_expression_real_accept;
-	VALA_CODE_NODE_CLASS (klass)->replace = vala_parenthesized_expression_real_replace;
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_parenthesized_expression_real_replace_expression;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_parenthesized_expression_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PARENTHESIZED_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
