@@ -49,11 +49,11 @@ typedef struct _ValaParserPrivate ValaParserPrivate;
  * Code visitor parsing all Vala source files.
  */
 struct _ValaParser {
-	ValaCodeVisitor parent;
+	ValaCodeVisitor parent_instance;
 	ValaParserPrivate * priv;
 };
 struct _ValaParserClass {
-	ValaCodeVisitorClass parent;
+	ValaCodeVisitorClass parent_class;
 };
 
 void vala_parser_parse (ValaParser* self, ValaCodeContext* context);
