@@ -1,6 +1,6 @@
 /* valapostfixexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -35,6 +35,7 @@ enum  {
 	VALA_POSTFIX_EXPRESSION_INCREMENT
 };
 static void vala_postfix_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static gboolean vala_postfix_expression_real_is_pure (ValaExpression* base);
 static gpointer vala_postfix_expression_parent_class = NULL;
 static void vala_postfix_expression_dispose (GObject * obj);
 
@@ -51,7 +52,7 @@ ValaPostfixExpression* vala_postfix_expression_new (ValaExpression* _inner, gboo
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaPostfixExpression * self;
-	g_return_val_if_fail (VALA_IS_EXPRESSION (_inner), NULL);
+	g_return_val_if_fail (_inner == NULL || VALA_IS_EXPRESSION (_inner), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -71,12 +72,19 @@ ValaPostfixExpression* vala_postfix_expression_new (ValaExpression* _inner, gboo
 static void vala_postfix_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaPostfixExpression * self;
 	self = VALA_POSTFIX_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_postfix_expression_get_inner (self)), visitor);
 	vala_code_visitor_visit_postfix_expression (visitor, self);
 }
 
 
+static gboolean vala_postfix_expression_real_is_pure (ValaExpression* base) {
+	ValaPostfixExpression * self;
+	self = VALA_POSTFIX_EXPRESSION (base);
+	return FALSE;
+}
+
+
 ValaExpression* vala_postfix_expression_get_inner (ValaPostfixExpression* self) {
 	g_return_val_if_fail (VALA_IS_POSTFIX_EXPRESSION (self), NULL);
 	return self->priv->_inner;
@@ -84,10 +92,12 @@ ValaExpression* vala_postfix_expression_get_inner (ValaPostfixExpression* self)
 
 
 void vala_postfix_expression_set_inner (ValaPostfixExpression* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_POSTFIX_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 }
 
 
@@ -144,6 +154,7 @@ static void vala_postfix_expression_class_init (ValaPostfixExpressionClass * kla
 	G_OBJECT_CLASS (klass)->set_property = vala_postfix_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_postfix_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_postfix_expression_real_accept;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_postfix_expression_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_POSTFIX_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_POSTFIX_EXPRESSION_INCREMENT, g_param_spec_boolean ("increment", "increment", "increment", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
