@@ -1,6 +1,6 @@
 /* valapostfixexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -44,11 +44,11 @@ typedef struct _ValaPostfixExpressionPrivate ValaPostfixExpressionPrivate;
  * Represents a postfix increment or decrement expression.
  */
 struct _ValaPostfixExpression {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaPostfixExpressionPrivate * priv;
 };
 struct _ValaPostfixExpressionClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 
 ValaPostfixExpression* vala_postfix_expression_new (ValaExpression* _inner, gboolean inc, ValaSourceReference* source);
