@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,12 +20,11 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valapropertyaccessor.h"
+#include <vala/valapropertyaccessor.h>
 #include <vala/valaproperty.h>
 #include <vala/valablock.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valasourcereference.h>
-#include <vala/valapropertyaccessor.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaPropertyAccessorPrivate {
@@ -62,8 +61,7 @@ static void vala_property_accessor_dispose (GObject * obj);
  * @param source       reference to source code
  * @return             newly created property accessor
  */
-ValaPropertyAccessor* vala_property_accessor_new (gboolean readable, gboolean writable, gboolean construction, ValaBlock* body, ValaSourceReference* source_reference)
-{
+ValaPropertyAccessor* vala_property_accessor_new (gboolean readable, gboolean writable, gboolean construction, ValaBlock* body, ValaSourceReference* source_reference) {
 	ValaPropertyAccessor * self;
 	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
@@ -77,91 +75,79 @@ ValaPropertyAccessor* vala_property_accessor_new (gboolean readable, gboolean wr
 }
 
 
-static void vala_property_accessor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_property_accessor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaPropertyAccessor * self;
-	self = ((ValaPropertyAccessor*) base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = VALA_PROPERTY_ACCESSOR (base);
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_property_accessor (visitor, self);
 }
 
 
-static void vala_property_accessor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_property_accessor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaPropertyAccessor * self;
-	self = ((ValaPropertyAccessor*) base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = VALA_PROPERTY_ACCESSOR (base);
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	if (vala_property_accessor_get_body (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_property_accessor_get_body (self)), visitor);
 	}
 }
 
 
-ValaProperty* vala_property_accessor_get_prop (ValaPropertyAccessor* self)
-{
+ValaProperty* vala_property_accessor_get_prop (ValaPropertyAccessor* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
 	return self->priv->_prop;
 }
 
 
-void vala_property_accessor_set_prop (ValaPropertyAccessor* self, ValaProperty* value)
-{
+void vala_property_accessor_set_prop (ValaPropertyAccessor* self, ValaProperty* value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_prop = value;
 }
 
 
-gboolean vala_property_accessor_get_readable (ValaPropertyAccessor* self)
-{
+gboolean vala_property_accessor_get_readable (ValaPropertyAccessor* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), FALSE);
 	return self->priv->_readable;
 }
 
 
-void vala_property_accessor_set_readable (ValaPropertyAccessor* self, gboolean value)
-{
+void vala_property_accessor_set_readable (ValaPropertyAccessor* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_readable = value;
 }
 
 
-gboolean vala_property_accessor_get_writable (ValaPropertyAccessor* self)
-{
+gboolean vala_property_accessor_get_writable (ValaPropertyAccessor* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), FALSE);
 	return self->priv->_writable;
 }
 
 
-void vala_property_accessor_set_writable (ValaPropertyAccessor* self, gboolean value)
-{
+void vala_property_accessor_set_writable (ValaPropertyAccessor* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_writable = value;
 }
 
 
-gboolean vala_property_accessor_get_construction (ValaPropertyAccessor* self)
-{
+gboolean vala_property_accessor_get_construction (ValaPropertyAccessor* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), FALSE);
 	return self->priv->_construction;
 }
 
 
-void vala_property_accessor_set_construction (ValaPropertyAccessor* self, gboolean value)
-{
+void vala_property_accessor_set_construction (ValaPropertyAccessor* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
 	self->priv->_construction = value;
 }
 
 
-ValaBlock* vala_property_accessor_get_body (ValaPropertyAccessor* self)
-{
+ValaBlock* vala_property_accessor_get_body (ValaPropertyAccessor* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
 	return self->priv->_body;
 }
 
 
-void vala_property_accessor_set_body (ValaPropertyAccessor* self, ValaBlock* value)
-{
+void vala_property_accessor_set_body (ValaPropertyAccessor* self, ValaBlock* value) {
 	ValaBlock* _tmp2;
 	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
@@ -171,15 +157,13 @@ void vala_property_accessor_set_body (ValaPropertyAccessor* self, ValaBlock* val
 }
 
 
-ValaFormalParameter* vala_property_accessor_get_value_parameter (ValaPropertyAccessor* self)
-{
+ValaFormalParameter* vala_property_accessor_get_value_parameter (ValaPropertyAccessor* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
 	return self->priv->_value_parameter;
 }
 
 
-void vala_property_accessor_set_value_parameter (ValaPropertyAccessor* self, ValaFormalParameter* value)
-{
+void vala_property_accessor_set_value_parameter (ValaPropertyAccessor* self, ValaFormalParameter* value) {
 	ValaFormalParameter* _tmp2;
 	ValaFormalParameter* _tmp1;
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
@@ -189,8 +173,7 @@ void vala_property_accessor_set_value_parameter (ValaPropertyAccessor* self, Val
 }
 
 
-static void vala_property_accessor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_property_accessor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaPropertyAccessor * self;
 	self = VALA_PROPERTY_ACCESSOR (object);
 	switch (property_id) {
@@ -219,8 +202,7 @@ static void vala_property_accessor_get_property (GObject * object, guint propert
 }
 
 
-static void vala_property_accessor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_property_accessor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaPropertyAccessor * self;
 	self = VALA_PROPERTY_ACCESSOR (object);
 	switch (property_id) {
@@ -249,8 +231,7 @@ static void vala_property_accessor_set_property (GObject * object, guint propert
 }
 
 
-static void vala_property_accessor_class_init (ValaPropertyAccessorClass * klass)
-{
+static void vala_property_accessor_class_init (ValaPropertyAccessorClass * klass) {
 	vala_property_accessor_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaPropertyAccessorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_property_accessor_get_property;
@@ -258,37 +239,30 @@ static void vala_property_accessor_class_init (ValaPropertyAccessorClass * klass
 	G_OBJECT_CLASS (klass)->dispose = vala_property_accessor_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_property_accessor_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_property_accessor_real_accept_children;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_PROP, g_param_spec_object ("prop", "foo", "bar", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_READABLE, g_param_spec_boolean ("readable", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_WRITABLE, g_param_spec_boolean ("writable", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_CONSTRUCTION, g_param_spec_boolean ("construction", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER, g_param_spec_object ("value-parameter", "foo", "bar", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_PROP, g_param_spec_object ("prop", "prop", "prop", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_READABLE, g_param_spec_boolean ("readable", "readable", "readable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_WRITABLE, g_param_spec_boolean ("writable", "writable", "writable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_CONSTRUCTION, g_param_spec_boolean ("construction", "construction", "construction", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER, g_param_spec_object ("value-parameter", "value-parameter", "value-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_property_accessor_init (ValaPropertyAccessor * self)
-{
+static void vala_property_accessor_init (ValaPropertyAccessor * self) {
 	self->priv = VALA_PROPERTY_ACCESSOR_GET_PRIVATE (self);
 }
 
 
-static void vala_property_accessor_dispose (GObject * obj)
-{
+static void vala_property_accessor_dispose (GObject * obj) {
 	ValaPropertyAccessor * self;
-	ValaPropertyAccessorClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_PROPERTY_ACCESSOR (obj);
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	(self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (g_object_unref (self->priv->_value_parameter), NULL)));
-	klass = VALA_PROPERTY_ACCESSOR_CLASS (g_type_class_peek (VALA_TYPE_PROPERTY_ACCESSOR));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_property_accessor_parent_class)->dispose (obj);
 }
 
 
-GType vala_property_accessor_get_type (void)
-{
+GType vala_property_accessor_get_type (void) {
 	static GType vala_property_accessor_type_id = 0;
 	if (G_UNLIKELY (vala_property_accessor_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaPropertyAccessorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_property_accessor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaPropertyAccessor), 0, (GInstanceInitFunc) vala_property_accessor_init };
