@@ -33,7 +33,8 @@ enum  {
 	VALA_REFERENCE_TRANSFER_EXPRESSION_INNER
 };
 static void vala_reference_transfer_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static void vala_reference_transfer_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
+static void vala_reference_transfer_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
+static gboolean vala_reference_transfer_expression_real_is_pure (ValaExpression* base);
 static gpointer vala_reference_transfer_expression_parent_class = NULL;
 static void vala_reference_transfer_expression_dispose (GObject * obj);
 
@@ -48,7 +49,7 @@ ValaReferenceTransferExpression* vala_reference_transfer_expression_new (ValaExp
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaReferenceTransferExpression * self;
-	g_return_val_if_fail (VALA_IS_EXPRESSION (inner), NULL);
+	g_return_val_if_fail (inner == NULL || VALA_IS_EXPRESSION (inner), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -67,23 +68,30 @@ ValaReferenceTransferExpression* vala_reference_transfer_expression_new (ValaExp
 static void vala_reference_transfer_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaReferenceTransferExpression * self;
 	self = VALA_REFERENCE_TRANSFER_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_reference_transfer_expression_get_inner (self)), visitor);
 	vala_code_visitor_visit_reference_transfer_expression (visitor, self);
 }
 
 
-static void vala_reference_transfer_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node) {
+static void vala_reference_transfer_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaReferenceTransferExpression * self;
 	self = VALA_REFERENCE_TRANSFER_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
-	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
-	if (VALA_CODE_NODE (vala_reference_transfer_expression_get_inner (self)) == old_node) {
-		vala_reference_transfer_expression_set_inner (self, VALA_EXPRESSION (new_node));
+	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	if (vala_reference_transfer_expression_get_inner (self) == old_node) {
+		vala_reference_transfer_expression_set_inner (self, new_node);
 	}
 }
 
 
+static gboolean vala_reference_transfer_expression_real_is_pure (ValaExpression* base) {
+	ValaReferenceTransferExpression * self;
+	self = VALA_REFERENCE_TRANSFER_EXPRESSION (base);
+	return FALSE;
+}
+
+
 ValaExpression* vala_reference_transfer_expression_get_inner (ValaReferenceTransferExpression* self) {
 	g_return_val_if_fail (VALA_IS_REFERENCE_TRANSFER_EXPRESSION (self), NULL);
 	return self->priv->_inner;
@@ -91,10 +99,12 @@ ValaExpression* vala_reference_transfer_expression_get_inner (ValaReferenceTrans
 
 
 void vala_reference_transfer_expression_set_inner (ValaReferenceTransferExpression* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_REFERENCE_TRANSFER_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
 }
 
@@ -134,7 +144,8 @@ static void vala_reference_transfer_expression_class_init (ValaReferenceTransfer
 	G_OBJECT_CLASS (klass)->set_property = vala_reference_transfer_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_reference_transfer_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_reference_transfer_expression_real_accept;
-	VALA_CODE_NODE_CLASS (klass)->replace = vala_reference_transfer_expression_real_replace;
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_reference_transfer_expression_real_replace_expression;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_reference_transfer_expression_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_REFERENCE_TRANSFER_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
