@@ -1,6 +1,6 @@
 /* valareport.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -51,7 +51,6 @@ gint vala_report_get_errors (void) {
  */
 void vala_report_warning (ValaSourceReference* source, const char* message) {
 	g_return_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source));
-	g_return_if_fail (message != NULL);
 	vala_report_warnings++;
 	if (source == NULL) {
 		fprintf (stderr, "warning: %s\n", message);
@@ -72,7 +71,6 @@ void vala_report_warning (ValaSourceReference* source, const char* message) {
  */
 void vala_report_error (ValaSourceReference* source, const char* message) {
 	g_return_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source));
-	g_return_if_fail (message != NULL);
 	vala_report_errors++;
 	if (source == NULL) {
 		fprintf (stderr, "error: %s\n", message);
@@ -85,20 +83,5 @@ void vala_report_error (ValaSourceReference* source, const char* message) {
 }
 
 
-/**
- * Static class to centralize reporting warnings and errors.
- */
-ValaReport* vala_report_new (void) {
-	ValaReport* self;
-	self = g_slice_new0 (ValaReport);
-	return self;
-}
-
-
-void vala_report_free (ValaReport* self) {
-	g_slice_free (ValaReport, self);
-}
-
-
 
 
