@@ -35,7 +35,7 @@ enum  {
 };
 static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_return_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static void vala_return_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
+static void vala_return_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_return_statement_parent_class = NULL;
 static ValaStatementIface* vala_return_statement_vala_statement_parent_iface = NULL;
 static void vala_return_statement_dispose (GObject * obj);
@@ -62,7 +62,7 @@ ValaReturnStatement* vala_return_statement_new (ValaExpression* return_expressio
 static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaReturnStatement * self;
 	self = VALA_RETURN_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_return_statement (visitor, self);
 }
 
@@ -70,7 +70,7 @@ static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisit
 static void vala_return_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaReturnStatement * self;
 	self = VALA_RETURN_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	if (vala_return_statement_get_return_expression (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_return_statement_get_return_expression (self)), visitor);
 		vala_code_visitor_visit_end_full_expression (visitor, vala_return_statement_get_return_expression (self));
@@ -78,13 +78,13 @@ static void vala_return_statement_real_accept_children (ValaCodeNode* base, Vala
 }
 
 
-static void vala_return_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node) {
+static void vala_return_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaReturnStatement * self;
 	self = VALA_RETURN_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
-	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
-	if (VALA_CODE_NODE (vala_return_statement_get_return_expression (self)) == old_node) {
-		vala_return_statement_set_return_expression (self, VALA_EXPRESSION (new_node));
+	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	if (vala_return_statement_get_return_expression (self) == old_node) {
+		vala_return_statement_set_return_expression (self, new_node);
 	}
 }
 
@@ -144,7 +144,7 @@ static void vala_return_statement_class_init (ValaReturnStatementClass * klass)
 	G_OBJECT_CLASS (klass)->dispose = vala_return_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_return_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_return_statement_real_accept_children;
-	VALA_CODE_NODE_CLASS (klass)->replace = vala_return_statement_real_replace;
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_return_statement_real_replace_expression;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_RETURN_STATEMENT_RETURN_EXPRESSION, g_param_spec_object ("return-expression", "return-expression", "return-expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
