@@ -1,6 +1,6 @@
 /* valasignal.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,23 +24,27 @@
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
-#include <vala/valatypereference.h>
-#include <vala/valacallback.h>
+#include <vala/valaformalparameter.h>
+#include <vala/valadelegate.h>
+#include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
-#include <vala/valaformalparameter.h>
 #include <vala/valascope.h>
-#include <vala/valadatatype.h>
+#include <vala/valareferencetype.h>
+#include <vala/valaclass.h>
+#include <vala/valaclasstype.h>
+#include <vala/valainterfacetype.h>
+#include <vala/valainterface.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
 struct _ValaSignalPrivate {
-	ValaTypeReference* _return_type;
 	gboolean _has_emitter;
 	GeeList* parameters;
-	ValaCallback* generated_callback;
+	ValaDelegate* generated_delegate;
 	char* cname;
 	gboolean lock_used;
+	ValaDataType* _return_type;
 };
 #define VALA_SIGNAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SIGNAL, ValaSignalPrivate))
 enum  {
@@ -48,15 +52,12 @@ enum  {
 	VALA_SIGNAL_RETURN_TYPE,
 	VALA_SIGNAL_HAS_EMITTER
 };
-static GeeCollection* vala_signal_real_get_parameters (ValaInvokable* base);
-static ValaTypeReference* vala_signal_real_get_return_type (ValaInvokable* base);
-static gboolean vala_signal_real_is_invokable (ValaInvokable* base);
 static void vala_signal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_signal_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gboolean vala_signal_real_get_lock_used (ValaLockable* base);
 static void vala_signal_real_set_lock_used (ValaLockable* base, gboolean used);
+static void vala_signal_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_signal_parent_class = NULL;
-static ValaInvokableIface* vala_signal_vala_invokable_parent_iface = NULL;
 static ValaLockableIface* vala_signal_vala_lockable_parent_iface = NULL;
 static void vala_signal_dispose (GObject * obj);
 
@@ -69,10 +70,9 @@ static void vala_signal_dispose (GObject * obj);
  * @param source      reference to source code
  * @return            newly created signal
  */
-ValaSignal* vala_signal_new (const char* name, ValaTypeReference* return_type, ValaSourceReference* source_reference) {
+ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
 	ValaSignal * self;
-	g_return_val_if_fail (name != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (return_type), NULL);
+	g_return_val_if_fail (return_type == NULL || VALA_IS_DATA_TYPE (return_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_SIGNAL, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
@@ -89,52 +89,45 @@ ValaSignal* vala_signal_new (const char* name, ValaTypeReference* return_type, V
  */
 void vala_signal_add_parameter (ValaSignal* self, ValaFormalParameter* param) {
 	g_return_if_fail (VALA_IS_SIGNAL (self));
-	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (param));
+	g_return_if_fail (param == NULL || VALA_IS_FORMAL_PARAMETER (param));
 	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (param)), VALA_SYMBOL (param));
 }
 
 
-static GeeCollection* vala_signal_real_get_parameters (ValaInvokable* base) {
-	ValaSignal * self;
-	self = VALA_SIGNAL (base);
-	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->parameters)));
-}
-
-
-static ValaTypeReference* vala_signal_real_get_return_type (ValaInvokable* base) {
-	ValaSignal * self;
-	self = VALA_SIGNAL (base);
-	return g_object_ref (vala_signal_get_return_type (self));
-}
-
-
-static gboolean vala_signal_real_is_invokable (ValaInvokable* base) {
-	ValaSignal * self;
-	self = VALA_SIGNAL (base);
-	return TRUE;
+GeeCollection* vala_signal_get_parameters (ValaSignal* self) {
+	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->parameters)));
 }
 
 
 /**
- * Returns generated callback to be used for signal handlers.
+ * Returns generated delegate to be used for signal handlers.
  *
- * @return callback
+ * @return delegate
  */
-ValaCallback* vala_signal_get_callback (ValaSignal* self) {
-	ValaCallback* _tmp1;
+ValaDelegate* vala_signal_get_delegate (ValaSignal* self) {
+	ValaDelegate* _tmp3;
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
-	if (self->priv->generated_callback == NULL) {
-		ValaCallback* _tmp0;
-		ValaTypeReference* sender_type;
+	if (self->priv->generated_delegate == NULL) {
+		ValaDelegate* _tmp0;
+		ValaReferenceType* sender_type;
 		ValaFormalParameter* sender_param;
 		_tmp0 = NULL;
-		self->priv->generated_callback = (_tmp0 = vala_callback_new (NULL, vala_signal_get_return_type (self), NULL), (self->priv->generated_callback == NULL ? NULL : (self->priv->generated_callback = (g_object_unref (self->priv->generated_callback), NULL))), _tmp0);
-		vala_callback_set_instance (self->priv->generated_callback, TRUE);
-		sender_type = vala_type_reference_new ();
-		vala_type_reference_set_data_type (sender_type, VALA_DATA_TYPE (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))));
-		sender_param = vala_formal_parameter_new ("sender", sender_type, NULL);
-		vala_callback_add_parameter (self->priv->generated_callback, sender_param);
+		self->priv->generated_delegate = (_tmp0 = vala_delegate_new (NULL, vala_signal_get_return_type (self), NULL), (self->priv->generated_delegate == NULL ? NULL : (self->priv->generated_delegate = (g_object_unref (self->priv->generated_delegate), NULL))), _tmp0);
+		vala_delegate_set_instance (self->priv->generated_delegate, TRUE);
+		sender_type = NULL;
+		if (VALA_IS_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))) {
+			ValaReferenceType* _tmp1;
+			_tmp1 = NULL;
+			sender_type = (_tmp1 = VALA_REFERENCE_TYPE (vala_class_type_new (VALA_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))))), (sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL))), _tmp1);
+		} else {
+			ValaReferenceType* _tmp2;
+			_tmp2 = NULL;
+			sender_type = (_tmp2 = VALA_REFERENCE_TYPE (vala_interface_type_new (VALA_INTERFACE (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))))), (sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL))), _tmp2);
+		}
+		sender_param = vala_formal_parameter_new ("sender", VALA_DATA_TYPE (sender_type), NULL);
+		vala_delegate_add_parameter (self->priv->generated_delegate, sender_param);
 		{
 			GeeList* param_collection;
 			GeeIterator* param_it;
@@ -144,8 +137,8 @@ ValaCallback* vala_signal_get_callback (ValaSignal* self) {
 				ValaFormalParameter* param;
 				param = gee_iterator_get (param_it);
 				{
-					vala_callback_add_parameter (self->priv->generated_callback, param);
-					(param = (g_object_unref (param), NULL));
+					vala_delegate_add_parameter (self->priv->generated_delegate, param);
+					(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 				}
 			}
 			(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
@@ -153,8 +146,8 @@ ValaCallback* vala_signal_get_callback (ValaSignal* self) {
 		(sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL)));
 		(sender_param == NULL ? NULL : (sender_param = (g_object_unref (sender_param), NULL)));
 	}
-	_tmp1 = NULL;
-	return (_tmp1 = self->priv->generated_callback, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	_tmp3 = NULL;
+	return (_tmp3 = self->priv->generated_delegate, (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
 }
 
 
@@ -219,15 +212,13 @@ ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self) {
 	g_string_append_c (str, '"');
 	_tmp3 = NULL;
 	return (_tmp3 = vala_ccode_constant_new (str->str), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), _tmp3);
-	(str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL)));
-	(i = (g_free (i), NULL));
 }
 
 
 static void vala_signal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, VALA_MEMBER (self));
 	vala_code_visitor_visit_signal (visitor, self);
 }
@@ -236,7 +227,7 @@ static void vala_signal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visito
 static void vala_signal_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_signal_get_return_type (self)), visitor);
 	{
 		GeeList* param_collection;
@@ -295,17 +286,31 @@ static void vala_signal_real_set_lock_used (ValaLockable* base, gboolean used) {
 }
 
 
-ValaTypeReference* vala_signal_get_return_type (ValaSignal* self) {
+static void vala_signal_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
+	ValaSignal * self;
+	self = VALA_SIGNAL (base);
+	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	if (vala_signal_get_return_type (self) == old_type) {
+		vala_signal_set_return_type (self, new_type);
+	}
+}
+
+
+ValaDataType* vala_signal_get_return_type (ValaSignal* self) {
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
 	return self->priv->_return_type;
 }
 
 
-void vala_signal_set_return_type (ValaSignal* self, ValaTypeReference* value) {
-	ValaTypeReference* _tmp1;
+void vala_signal_set_return_type (ValaSignal* self, ValaDataType* value) {
+	ValaDataType* _tmp2;
+	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_SIGNAL (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_return_type = (_tmp1 = g_object_ref (value), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), _tmp1);
+	self->priv->_return_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), _tmp2);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_return_type), VALA_CODE_NODE (self));
 }
 
 
@@ -363,19 +368,12 @@ static void vala_signal_class_init (ValaSignalClass * klass) {
 	G_OBJECT_CLASS (klass)->dispose = vala_signal_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_signal_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_signal_real_accept_children;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_RETURN_TYPE, g_param_spec_object ("return-type", "return-type", "return-type", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_signal_real_replace_type;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_RETURN_TYPE, g_param_spec_object ("return-type", "return-type", "return-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_HAS_EMITTER, g_param_spec_boolean ("has-emitter", "has-emitter", "has-emitter", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_signal_vala_invokable_interface_init (ValaInvokableIface * iface) {
-	vala_signal_vala_invokable_parent_iface = g_type_interface_peek_parent (iface);
-	iface->get_parameters = vala_signal_real_get_parameters;
-	iface->get_return_type = vala_signal_real_get_return_type;
-	iface->is_invokable = vala_signal_real_is_invokable;
-}
-
-
 static void vala_signal_vala_lockable_interface_init (ValaLockableIface * iface) {
 	vala_signal_vala_lockable_parent_iface = g_type_interface_peek_parent (iface);
 	iface->get_lock_used = vala_signal_real_get_lock_used;
@@ -385,7 +383,7 @@ static void vala_signal_vala_lockable_interface_init (ValaLockableIface * iface)
 
 static void vala_signal_init (ValaSignal * self) {
 	self->priv = VALA_SIGNAL_GET_PRIVATE (self);
-	self->priv->parameters = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->lock_used = FALSE;
 }
 
@@ -393,10 +391,10 @@ static void vala_signal_init (ValaSignal * self) {
 static void vala_signal_dispose (GObject * obj) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (obj);
-	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
 	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
-	(self->priv->generated_callback == NULL ? NULL : (self->priv->generated_callback = (g_object_unref (self->priv->generated_callback), NULL)));
+	(self->priv->generated_delegate == NULL ? NULL : (self->priv->generated_delegate = (g_object_unref (self->priv->generated_delegate), NULL)));
 	(self->priv->cname = (g_free (self->priv->cname), NULL));
+	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
 	G_OBJECT_CLASS (vala_signal_parent_class)->dispose (obj);
 }
 
@@ -405,10 +403,8 @@ GType vala_signal_get_type (void) {
 	static GType vala_signal_type_id = 0;
 	if (G_UNLIKELY (vala_signal_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSignalClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_signal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSignal), 0, (GInstanceInitFunc) vala_signal_init };
-		static const GInterfaceInfo vala_invokable_info = { (GInterfaceInitFunc) vala_signal_vala_invokable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo vala_lockable_info = { (GInterfaceInitFunc) vala_signal_vala_lockable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_signal_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaSignal", &g_define_type_info, 0);
-		g_type_add_interface_static (vala_signal_type_id, VALA_TYPE_INVOKABLE, &vala_invokable_info);
 		g_type_add_interface_static (vala_signal_type_id, VALA_TYPE_LOCKABLE, &vala_lockable_info);
 	}
 	return vala_signal_type_id;
