@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALASOURCEREFERENCE_H__
-#define __VALASOURCEREFERENCE_H__
+#ifndef __VALA_VALASOURCEREFERENCE_H__
+#define __VALA_VALASOURCEREFERENCE_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -45,11 +45,11 @@ typedef struct _ValaSourceReferencePrivate ValaSourceReferencePrivate;
  * Represents a reference to a location in a source file.
  */
 struct _ValaSourceReference {
-	GObject parent;
+	GObject parent_instance;
 	ValaSourceReferencePrivate * priv;
 };
 struct _ValaSourceReferenceClass {
-	GObjectClass parent;
+	GObjectClass parent_class;
 };
 
 ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column);
