@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,12 +19,9 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
-#include "valastringliteral.h"
-#include <vala/valasourcereference.h>
 #include <vala/valastringliteral.h>
+#include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaStringLiteralPrivate {
@@ -47,17 +44,12 @@ static void vala_string_literal_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created string literal
  */
-ValaStringLiteral* vala_string_literal_new (const char* s, ValaSourceReference* source)
-{
-	GParameter * __params;
-	GParameter * __params_it;
+ValaStringLiteral* vala_string_literal_new (const char* s, ValaSourceReference* source) {
 	ValaStringLiteral * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	(__params_it->name = "value", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, s), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_STRING_LITERAL, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_STRING_LITERAL, 0, NULL);
+	vala_string_literal_set_value (self, s);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
@@ -67,107 +59,98 @@ ValaStringLiteral* vala_string_literal_new (const char* s, ValaSourceReference*
  *
  * @return the unescaped string
  */
-char* vala_string_literal_eval (ValaStringLiteral* self)
-{
+char* vala_string_literal_eval (ValaStringLiteral* self) {
 	char* noquotes;
-	char* __temp1;
+	char* _tmp1;
 	g_return_val_if_fail (VALA_IS_STRING_LITERAL (self), NULL);
 	if (vala_string_literal_get_value (self) == NULL) {
 		return NULL;
 	}
 	/* remove quotes */
 	noquotes = g_strndup (g_utf8_offset_to_pointer (vala_string_literal_get_value (self), 1), ((guint) (g_utf8_strlen (vala_string_literal_get_value (self), -1) - 2)));
-	__temp1 = NULL;
-	return (__temp1 = g_strcompress (noquotes), (noquotes = (g_free (noquotes), NULL)), __temp1);
-	(noquotes = (g_free (noquotes), NULL));
+	_tmp1 = NULL;
+	return (_tmp1 = g_strcompress (noquotes), (noquotes = (g_free (noquotes), NULL)), _tmp1);
 }
 
 
 /* unescape string */
-static void vala_string_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_string_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaStringLiteral * self;
 	self = VALA_STRING_LITERAL (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_string_literal (visitor, self);
 }
 
 
-char* vala_string_literal_get_value (ValaStringLiteral* self)
-{
+char* vala_string_literal_get_value (ValaStringLiteral* self) {
 	g_return_val_if_fail (VALA_IS_STRING_LITERAL (self), NULL);
 	return self->priv->_value;
 }
 
 
-void vala_string_literal_set_value (ValaStringLiteral* self, const char* value)
-{
-	char* __temp4;
-	const char* __temp3;
+void vala_string_literal_set_value (ValaStringLiteral* self, const char* value) {
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_STRING_LITERAL (self));
-	__temp4 = NULL;
-	__temp3 = NULL;
-	self->priv->_value = (__temp4 = (__temp3 = value, (__temp3 == NULL ? NULL : g_strdup (__temp3))), (self->priv->_value = (g_free (self->priv->_value), NULL)), __temp4);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_value = (g_free (self->priv->_value), NULL)), _tmp2);
 }
 
 
-static void vala_string_literal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_string_literal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaStringLiteral * self;
 	self = VALA_STRING_LITERAL (object);
 	switch (property_id) {
 		case VALA_STRING_LITERAL_VALUE:
 		g_value_set_string (value, vala_string_literal_get_value (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_string_literal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_string_literal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaStringLiteral * self;
 	self = VALA_STRING_LITERAL (object);
 	switch (property_id) {
 		case VALA_STRING_LITERAL_VALUE:
 		vala_string_literal_set_value (self, g_value_get_string (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_string_literal_class_init (ValaStringLiteralClass * klass)
-{
+static void vala_string_literal_class_init (ValaStringLiteralClass * klass) {
 	vala_string_literal_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaStringLiteralPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_string_literal_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_string_literal_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_string_literal_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_string_literal_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_STRING_LITERAL_VALUE, g_param_spec_string ("value", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_STRING_LITERAL_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_string_literal_init (ValaStringLiteral * self)
-{
+static void vala_string_literal_init (ValaStringLiteral * self) {
 	self->priv = VALA_STRING_LITERAL_GET_PRIVATE (self);
 }
 
 
-static void vala_string_literal_dispose (GObject * obj)
-{
+static void vala_string_literal_dispose (GObject * obj) {
 	ValaStringLiteral * self;
-	ValaStringLiteralClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_STRING_LITERAL (obj);
 	(self->priv->_value = (g_free (self->priv->_value), NULL));
-	klass = VALA_STRING_LITERAL_CLASS (g_type_class_peek (VALA_TYPE_STRING_LITERAL));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_string_literal_parent_class)->dispose (obj);
 }
 
 
-GType vala_string_literal_get_type ()
-{
+GType vala_string_literal_get_type (void) {
 	static GType vala_string_literal_type_id = 0;
 	if (G_UNLIKELY (vala_string_literal_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaStringLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_string_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaStringLiteral), 0, (GInstanceInitFunc) vala_string_literal_init };
