@@ -1,6 +1,6 @@
 /* valastruct.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,7 +28,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <gee/collection.h>
-#include <vala/valadatatype.h>
+#include <vala/valatypesymbol.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -47,11 +47,11 @@ typedef struct _ValaStructPrivate ValaStructPrivate;
  * Represents a struct declaration in the source code.
  */
 struct _ValaStruct {
-	ValaDataType parent;
+	ValaTypesymbol parent_instance;
 	ValaStructPrivate * priv;
 };
 struct _ValaStructClass {
-	ValaDataTypeClass parent;
+	ValaTypesymbolClass parent_class;
 };
 
 ValaStruct* vala_struct_new (const char* name, ValaSourceReference* source_reference);
@@ -66,9 +66,10 @@ gboolean vala_struct_is_floating_type (ValaStruct* self);
 gint vala_struct_get_rank (ValaStruct* self);
 void vala_struct_process_attributes (ValaStruct* self);
 void vala_struct_set_type_id (ValaStruct* self, const char* name);
-void vala_struct_add_base_type (ValaStruct* self, ValaTypeReference* type);
+void vala_struct_add_base_type (ValaStruct* self, ValaDataType* type);
 GeeCollection* vala_struct_get_base_types (ValaStruct* self);
 gboolean vala_struct_is_simple_type (ValaStruct* self);
+void vala_struct_set_simple_type (ValaStruct* self, gboolean simple_type);
 ValaMethod* vala_struct_get_default_construction_method (ValaStruct* self);
 void vala_struct_set_default_construction_method (ValaStruct* self, ValaMethod* value);
 GType vala_struct_get_type (void);
