@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALASWITCHSECTION_H__
-#define __VALASWITCHSECTION_H__
+#ifndef __VALA_VALASWITCHSECTION_H__
+#define __VALA_VALASWITCHSECTION_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -45,11 +45,11 @@ typedef struct _ValaSwitchSectionPrivate ValaSwitchSectionPrivate;
  * Represents a switch section in the source code.
  */
 struct _ValaSwitchSection {
-	ValaBlock parent;
+	ValaBlock parent_instance;
 	ValaSwitchSectionPrivate * priv;
 };
 struct _ValaSwitchSectionClass {
-	ValaBlockClass parent;
+	ValaBlockClass parent_class;
 };
 
 ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_reference);
