@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,14 +20,15 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valasymbol.h"
+#include <vala/valasymbol.h>
 #include <gee/readonlycollection.h>
 #include <vala/valascope.h>
-#include <vala/valasymbol.h>
 
 struct _ValaSymbolPrivate {
 	char* _name;
 	gboolean _active;
+	ValaSymbolAccessibility _access;
+	gboolean _is_imported;
 	ValaScope* _owner;
 	ValaScope* _scope;
 };
@@ -38,7 +39,9 @@ enum  {
 	VALA_SYMBOL_OWNER,
 	VALA_SYMBOL_NAME,
 	VALA_SYMBOL_ACTIVE,
-	VALA_SYMBOL_SCOPE
+	VALA_SYMBOL_ACCESS,
+	VALA_SYMBOL_SCOPE,
+	VALA_SYMBOL_IS_IMPORTED
 };
 static char* vala_symbol_real_get_cprefix (ValaSymbol* self);
 static char* vala_symbol_real_get_lower_case_cname (ValaSymbol* self, const char* infix);
@@ -49,36 +52,65 @@ static gpointer vala_symbol_parent_class = NULL;
 static void vala_symbol_dispose (GObject * obj);
 
 
+/**
+ * Check if this symbol is just internal API (and therefore doesn't need 
+ * to be listed in header files for instance) by traversing parent symbols
+ * and checking their accessibility.
+ */
+gboolean vala_symbol_is_internal_symbol (ValaSymbol* self) {
+	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
+	{
+		ValaSymbol* sym;
+		ValaSymbol* _tmp3;
+		ValaSymbol* _tmp2;
+		ValaSymbol* _tmp1;
+		ValaSymbol* _tmp0;
+		sym = NULL;
+		_tmp3 = NULL;
+		_tmp2 = NULL;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		for (sym = (_tmp1 = (_tmp0 = self, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp1); NULL != sym; sym = (_tmp3 = (_tmp2 = vala_symbol_get_parent_symbol (sym), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp3)) {
+			if (VALA_SYMBOL_ACCESSIBILITY_PRIVATE == vala_symbol_get_access (sym)) {
+				gboolean _tmp4;
+				return (_tmp4 = TRUE, (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp4);
+			}
+		}
+		(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
+	}
+	return FALSE;
+}
+
+
 /**
  * Returns the fully expanded name of this symbol for use in
  * human-readable messages.
  *
  * @return full name
  */
-char* vala_symbol_get_full_name (ValaSymbol* self)
-{
-	char* __temp3;
-	gboolean __temp4;
-	char* __temp7;
-	char* __temp8;
+char* vala_symbol_get_full_name (ValaSymbol* self) {
+	char* _tmp3;
+	gboolean _tmp4;
+	char* _tmp7;
+	char* _tmp8;
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	if (vala_symbol_get_parent_symbol (self) == NULL) {
-		const char* __temp0;
-		__temp0 = NULL;
-		return (__temp0 = vala_symbol_get_name (self), (__temp0 == NULL ? NULL : g_strdup (__temp0)));
+		const char* _tmp0;
+		_tmp0 = NULL;
+		return (_tmp0 = vala_symbol_get_name (self), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	}
 	if (vala_symbol_get_name (self) == NULL) {
 		return vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self));
 	}
-	__temp3 = NULL;
-	if ((__temp4 = (__temp3 = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self))) == NULL, (__temp3 = (g_free (__temp3), NULL)), __temp4)) {
-		const char* __temp5;
-		__temp5 = NULL;
-		return (__temp5 = vala_symbol_get_name (self), (__temp5 == NULL ? NULL : g_strdup (__temp5)));
+	_tmp3 = NULL;
+	if ((_tmp4 = (_tmp3 = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self))) == NULL, (_tmp3 = (g_free (_tmp3), NULL)), _tmp4)) {
+		const char* _tmp5;
+		_tmp5 = NULL;
+		return (_tmp5 = vala_symbol_get_name (self), (_tmp5 == NULL ? NULL : g_strdup (_tmp5)));
 	}
-	__temp7 = NULL;
-	__temp8 = NULL;
-	return (__temp8 = g_strdup_printf ("%s.%s", (__temp7 = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self))), vala_symbol_get_name (self)), (__temp7 = (g_free (__temp7), NULL)), __temp8);
+	_tmp7 = NULL;
+	_tmp8 = NULL;
+	return (_tmp8 = g_strdup_printf ("%s.%s", (_tmp7 = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self))), vala_symbol_get_name (self)), (_tmp7 = (g_free (_tmp7), NULL)), _tmp8);
 }
 
 
@@ -88,22 +120,22 @@ char* vala_symbol_get_full_name (ValaSymbol* self)
  *
  * @return the camel case prefix to be used in C code
  */
-static char* vala_symbol_real_get_cprefix (ValaSymbol* self)
-{
+static char* vala_symbol_real_get_cprefix (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	if (vala_symbol_get_name (self) == NULL) {
 		return g_strdup ("");
 	} else {
-		const char* __temp11;
-		__temp11 = NULL;
-		return (__temp11 = vala_symbol_get_name (self), (__temp11 == NULL ? NULL : g_strdup (__temp11)));
+		const char* _tmp1;
+		_tmp1 = NULL;
+		return (_tmp1 = vala_symbol_get_name (self), (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 	}
 }
 
 
-char* vala_symbol_get_cprefix (ValaSymbol* self)
-{
-	return VALA_SYMBOL_GET_CLASS (self)->get_cprefix (self);
+char* vala_symbol_get_cprefix (ValaSymbol* self) {
+	char* result;
+	result = VALA_SYMBOL_GET_CLASS (self)->get_cprefix (self);
+	return result;
 }
 
 
@@ -116,16 +148,16 @@ char* vala_symbol_get_cprefix (ValaSymbol* self)
  *              name or null
  * @return      the lower case name to be used in C code
  */
-static char* vala_symbol_real_get_lower_case_cname (ValaSymbol* self, const char* infix)
-{
+static char* vala_symbol_real_get_lower_case_cname (ValaSymbol* self, const char* infix) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	return NULL;
 }
 
 
-char* vala_symbol_get_lower_case_cname (ValaSymbol* self, const char* infix)
-{
-	return VALA_SYMBOL_GET_CLASS (self)->get_lower_case_cname (self, infix);
+char* vala_symbol_get_lower_case_cname (ValaSymbol* self, const char* infix) {
+	char* result;
+	result = VALA_SYMBOL_GET_CLASS (self)->get_lower_case_cname (self, infix);
+	return result;
 }
 
 
@@ -135,16 +167,16 @@ char* vala_symbol_get_lower_case_cname (ValaSymbol* self, const char* infix)
  *
  * @return      the lower case prefix to be used in C code
  */
-static char* vala_symbol_real_get_lower_case_cprefix (ValaSymbol* self)
-{
+static char* vala_symbol_real_get_lower_case_cprefix (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	return g_strdup ("");
 }
 
 
-char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self)
-{
-	return VALA_SYMBOL_GET_CLASS (self)->get_lower_case_cprefix (self);
+char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self) {
+	char* result;
+	result = VALA_SYMBOL_GET_CLASS (self)->get_lower_case_cprefix (self);
+	return result;
 }
 
 
@@ -154,16 +186,16 @@ char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self)
  *
  * @return list of C header filenames for this symbol
  */
-static GeeCollection* vala_symbol_real_get_cheader_filenames (ValaSymbol* self)
-{
+static GeeCollection* vala_symbol_real_get_cheader_filenames (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, NULL));
+	return GEE_COLLECTION (gee_read_only_collection_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, NULL));
 }
 
 
-GeeCollection* vala_symbol_get_cheader_filenames (ValaSymbol* self)
-{
-	return VALA_SYMBOL_GET_CLASS (self)->get_cheader_filenames (self);
+GeeCollection* vala_symbol_get_cheader_filenames (ValaSymbol* self) {
+	GeeCollection* result;
+	result = VALA_SYMBOL_GET_CLASS (self)->get_cheader_filenames (self);
+	return result;
 }
 
 
@@ -173,14 +205,12 @@ GeeCollection* vala_symbol_get_cheader_filenames (ValaSymbol* self)
  * @param camel_case a string in camel case
  * @return           the specified string converted to lower case
  */
-char* vala_symbol_camel_case_to_lower_case (const char* camel_case)
-{
+char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
 	GString* result;
 	const char* i;
 	gboolean first;
-	const char* __temp16;
-	char* __temp17;
-	g_return_val_if_fail (camel_case != NULL, NULL);
+	const char* _tmp0;
+	char* _tmp1;
 	result = g_string_new ("");
 	i = camel_case;
 	first = TRUE;
@@ -212,80 +242,94 @@ char* vala_symbol_camel_case_to_lower_case (const char* camel_case)
 		first = FALSE;
 		i = g_utf8_next_char (i);
 	}
-	__temp16 = NULL;
-	__temp17 = NULL;
-	return (__temp17 = (__temp16 = result->str, (__temp16 == NULL ? NULL : g_strdup (__temp16))), (result == NULL ? NULL : (result = (g_string_free (result, TRUE), NULL))), __temp17);
-	(result == NULL ? NULL : (result = (g_string_free (result, TRUE), NULL)));
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = (_tmp0 = result->str, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (result == NULL ? NULL : (result = (g_string_free (result, TRUE), NULL))), _tmp1);
 }
 
 
-ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self)
-{
+ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	if (vala_symbol_get_owner (self) == NULL) {
-		return VALA_SYMBOL (NULL);
+		return NULL;
 	} else {
 		return vala_scope_get_owner (vala_symbol_get_owner (self));
 	}
 }
 
 
-ValaScope* vala_symbol_get_owner (ValaSymbol* self)
-{
+ValaScope* vala_symbol_get_owner (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	return self->priv->_owner;
 }
 
 
-void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value)
-{
+void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_owner = value;
 	vala_scope_set_parent_scope (self->priv->_scope, value);
 }
 
 
-char* vala_symbol_get_name (ValaSymbol* self)
-{
+char* vala_symbol_get_name (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	return self->priv->_name;
 }
 
 
-void vala_symbol_set_name (ValaSymbol* self, const char* value)
-{
-	char* __temp23;
-	const char* __temp22;
+void vala_symbol_set_name (ValaSymbol* self, const char* value) {
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_SYMBOL (self));
-	__temp23 = NULL;
-	__temp22 = NULL;
-	self->priv->_name = (__temp23 = (__temp22 = value, (__temp22 == NULL ? NULL : g_strdup (__temp22))), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp23);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
 }
 
 
-gboolean vala_symbol_get_active (ValaSymbol* self)
-{
+gboolean vala_symbol_get_active (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
 	return self->priv->_active;
 }
 
 
-void vala_symbol_set_active (ValaSymbol* self, gboolean value)
-{
+void vala_symbol_set_active (ValaSymbol* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
 	self->priv->_active = value;
 }
 
 
-ValaScope* vala_symbol_get_scope (ValaSymbol* self)
-{
+ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self) {
+	g_return_val_if_fail (VALA_IS_SYMBOL (self), 0);
+	return self->priv->_access;
+}
+
+
+void vala_symbol_set_access (ValaSymbol* self, ValaSymbolAccessibility value) {
+	g_return_if_fail (VALA_IS_SYMBOL (self));
+	self->priv->_access = value;
+}
+
+
+ValaScope* vala_symbol_get_scope (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	return self->priv->_scope;
 }
 
 
-static GObject * vala_symbol_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties)
-{
+gboolean vala_symbol_get_is_imported (ValaSymbol* self) {
+	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
+	return self->priv->_is_imported;
+}
+
+
+void vala_symbol_set_is_imported (ValaSymbol* self, gboolean value) {
+	g_return_if_fail (VALA_IS_SYMBOL (self));
+	self->priv->_is_imported = value;
+}
+
+
+static GObject * vala_symbol_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
 	GObject * obj;
 	ValaSymbolClass * klass;
 	GObjectClass * parent_class;
@@ -295,17 +339,16 @@ static GObject * vala_symbol_constructor (GType type, guint n_construct_properti
 	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
 	self = VALA_SYMBOL (obj);
 	{
-		ValaScope* __temp26;
-		__temp26 = NULL;
-		self->priv->_scope = (__temp26 = vala_scope_new (self), (self->priv->_scope == NULL ? NULL : (self->priv->_scope = (g_object_unref (self->priv->_scope), NULL))), __temp26);
+		ValaScope* _tmp0;
+		_tmp0 = NULL;
+		self->priv->_scope = (_tmp0 = vala_scope_new (self), (self->priv->_scope == NULL ? NULL : (self->priv->_scope = (g_object_unref (self->priv->_scope), NULL))), _tmp0);
 		vala_symbol_set_active (self, TRUE);
 	}
 	return obj;
 }
 
 
-static void vala_symbol_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_symbol_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaSymbol * self;
 	self = VALA_SYMBOL (object);
 	switch (property_id) {
@@ -321,15 +364,23 @@ static void vala_symbol_get_property (GObject * object, guint property_id, GValu
 		case VALA_SYMBOL_ACTIVE:
 		g_value_set_boolean (value, vala_symbol_get_active (self));
 		break;
+		case VALA_SYMBOL_ACCESS:
+		g_value_set_int (value, vala_symbol_get_access (self));
+		break;
 		case VALA_SYMBOL_SCOPE:
 		g_value_set_object (value, vala_symbol_get_scope (self));
 		break;
+		case VALA_SYMBOL_IS_IMPORTED:
+		g_value_set_boolean (value, vala_symbol_get_is_imported (self));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_symbol_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_symbol_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaSymbol * self;
 	self = VALA_SYMBOL (object);
 	switch (property_id) {
@@ -342,12 +393,20 @@ static void vala_symbol_set_property (GObject * object, guint property_id, const
 		case VALA_SYMBOL_ACTIVE:
 		vala_symbol_set_active (self, g_value_get_boolean (value));
 		break;
+		case VALA_SYMBOL_ACCESS:
+		vala_symbol_set_access (self, g_value_get_int (value));
+		break;
+		case VALA_SYMBOL_IS_IMPORTED:
+		vala_symbol_set_is_imported (self, g_value_get_boolean (value));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_symbol_class_init (ValaSymbolClass * klass)
-{
+static void vala_symbol_class_init (ValaSymbolClass * klass) {
 	vala_symbol_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaSymbolPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_symbol_get_property;
@@ -358,36 +417,31 @@ static void vala_symbol_class_init (ValaSymbolClass * klass)
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cname = vala_symbol_real_get_lower_case_cname;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cprefix = vala_symbol_real_get_lower_case_cprefix;
 	VALA_SYMBOL_CLASS (klass)->get_cheader_filenames = vala_symbol_real_get_cheader_filenames;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_PARENT_SYMBOL, g_param_spec_object ("parent-symbol", "foo", "bar", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_OWNER, g_param_spec_object ("owner", "foo", "bar", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACTIVE, g_param_spec_boolean ("active", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_SCOPE, g_param_spec_object ("scope", "foo", "bar", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_PARENT_SYMBOL, g_param_spec_object ("parent-symbol", "parent-symbol", "parent-symbol", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_OWNER, g_param_spec_object ("owner", "owner", "owner", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACTIVE, g_param_spec_boolean ("active", "active", "active", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACCESS, g_param_spec_int ("access", "access", "access", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_SCOPE, g_param_spec_object ("scope", "scope", "scope", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_IS_IMPORTED, g_param_spec_boolean ("is-imported", "is-imported", "is-imported", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_symbol_init (ValaSymbol * self)
-{
+static void vala_symbol_init (ValaSymbol * self) {
 	self->priv = VALA_SYMBOL_GET_PRIVATE (self);
 }
 
 
-static void vala_symbol_dispose (GObject * obj)
-{
+static void vala_symbol_dispose (GObject * obj) {
 	ValaSymbol * self;
-	ValaSymbolClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_SYMBOL (obj);
 	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->priv->_scope == NULL ? NULL : (self->priv->_scope = (g_object_unref (self->priv->_scope), NULL)));
-	klass = VALA_SYMBOL_CLASS (g_type_class_peek (VALA_TYPE_SYMBOL));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_symbol_parent_class)->dispose (obj);
 }
 
 
-GType vala_symbol_get_type (void)
-{
+GType vala_symbol_get_type (void) {
 	static GType vala_symbol_type_id = 0;
 	if (G_UNLIKELY (vala_symbol_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSymbolClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_symbol_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSymbol), 0, (GInstanceInitFunc) vala_symbol_init };
