@@ -1,11 +1,11 @@
 /* valasymbolresolver.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,22 +18,22 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
+ * 	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
-#ifndef __VALASYMBOLRESOLVER_H__
-#define __VALASYMBOLRESOLVER_H__
+#ifndef __VALA_VALASYMBOLRESOLVER_H__
+#define __VALA_VALASYMBOLRESOLVER_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valacodecontext.h>
 #include <vala/valasourcefile.h>
-#include <vala/valanamespace.h>
 #include <vala/valaclass.h>
 #include <vala/valastruct.h>
 #include <vala/valainterface.h>
 #include <vala/valaenum.h>
-#include <vala/valacallback.h>
+#include <vala/valadelegate.h>
 #include <vala/valaconstant.h>
 #include <vala/valafield.h>
 #include <vala/valamethod.h>
@@ -44,11 +44,22 @@
 #include <vala/valasignal.h>
 #include <vala/valaconstructor.h>
 #include <vala/valadestructor.h>
+#include <vala/valablock.h>
 #include <vala/valanamespacereference.h>
-#include <vala/valatypereference.h>
+#include <vala/valadatatype.h>
+#include <vala/valavariabledeclarator.h>
+#include <vala/valainitializerlist.h>
+#include <vala/valaswitchsection.h>
+#include <vala/valaforeachstatement.h>
+#include <vala/valareturnstatement.h>
 #include <vala/valathrowstatement.h>
 #include <vala/valatrystatement.h>
 #include <vala/valacatchclause.h>
+#include <vala/valaarraycreationexpression.h>
+#include <vala/valainvocationexpression.h>
+#include <vala/valaobjectcreationexpression.h>
+#include <vala/valalambdaexpression.h>
+#include <vala/valaassignment.h>
 
 G_BEGIN_DECLS
 
@@ -68,15 +79,16 @@ typedef struct _ValaSymbolResolverPrivate ValaSymbolResolverPrivate;
  * Code visitor resolving symbol names.
  */
 struct _ValaSymbolResolver {
-	ValaCodeVisitor parent;
+	ValaCodeVisitor parent_instance;
 	ValaSymbolResolverPrivate * priv;
 };
 struct _ValaSymbolResolverClass {
-	ValaCodeVisitorClass parent;
+	ValaCodeVisitorClass parent_class;
 };
 
 void vala_symbol_resolver_resolve (ValaSymbolResolver* self, ValaCodeContext* context);
-GType vala_symbol_resolver_get_type ();
+ValaSymbolResolver* vala_symbol_resolver_new (void);
+GType vala_symbol_resolver_get_type (void);
 
 G_END_DECLS
 
