@@ -1,11 +1,11 @@
 /* valaunaryexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,15 +20,14 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAUNARYEXPRESSION_H__
-#define __VALAUNARYEXPRESSION_H__
+#ifndef __VALA_VALAUNARYEXPRESSION_H__
+#define __VALA_VALAUNARYEXPRESSION_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
 #include <vala/valaexpression.h>
-#include <vala/valaunaryexpression.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -49,11 +48,11 @@ typedef struct _ValaUnaryExpressionPrivate ValaUnaryExpressionPrivate;
  * Supports +, -, !, ~, ref, out.
  */
 struct _ValaUnaryExpression {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaUnaryExpressionPrivate * priv;
 };
 struct _ValaUnaryExpressionClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 typedef enum  {
 	VALA_UNARY_OPERATOR_PLUS,
