@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,10 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valawhilestatement.h"
+#include <vala/valawhilestatement.h>
 #include <vala/valaexpression.h>
 #include <vala/valablock.h>
 #include <vala/valasourcereference.h>
-#include <vala/valawhilestatement.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaWhileStatementPrivate {
@@ -38,7 +37,7 @@ enum  {
 	VALA_WHILE_STATEMENT_BODY
 };
 static void vala_while_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static void vala_while_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
+static void vala_while_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_while_statement_parent_class = NULL;
 static ValaStatementIface* vala_while_statement_vala_statement_parent_iface = NULL;
 static void vala_while_statement_dispose (GObject * obj);
@@ -52,13 +51,12 @@ static void vala_while_statement_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created while statement
  */
-ValaWhileStatement* vala_while_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference)
-{
+ValaWhileStatement* vala_while_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaWhileStatement * self;
-	g_return_val_if_fail (VALA_IS_EXPRESSION (condition), NULL);
-	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
+	g_return_val_if_fail (condition == NULL || VALA_IS_EXPRESSION (condition), NULL);
+	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -75,11 +73,10 @@ ValaWhileStatement* vala_while_statement_new (ValaExpression* condition, ValaBlo
 }
 
 
-static void vala_while_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_while_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaWhileStatement * self;
-	self = ((ValaWhileStatement*) base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = VALA_WHILE_STATEMENT (base);
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_while_statement_get_condition (self)), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_while_statement_get_condition (self));
 	vala_code_node_accept (VALA_CODE_NODE (vala_while_statement_get_body (self)), visitor);
@@ -87,44 +84,41 @@ static void vala_while_statement_real_accept (ValaCodeNode* base, ValaCodeVisito
 }
 
 
-static void vala_while_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
-{
+static void vala_while_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaWhileStatement * self;
-	self = ((ValaWhileStatement*) base);
-	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
-	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
-	if (VALA_CODE_NODE (vala_while_statement_get_condition (self)) == old_node) {
-		vala_while_statement_set_condition (self, VALA_EXPRESSION (new_node));
+	self = VALA_WHILE_STATEMENT (base);
+	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	if (vala_while_statement_get_condition (self) == old_node) {
+		vala_while_statement_set_condition (self, new_node);
 	}
 }
 
 
-ValaExpression* vala_while_statement_get_condition (ValaWhileStatement* self)
-{
+ValaExpression* vala_while_statement_get_condition (ValaWhileStatement* self) {
 	g_return_val_if_fail (VALA_IS_WHILE_STATEMENT (self), NULL);
 	return self->priv->_condition;
 }
 
 
-void vala_while_statement_set_condition (ValaWhileStatement* self, ValaExpression* value)
-{
+void vala_while_statement_set_condition (ValaWhileStatement* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_WHILE_STATEMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_condition = (_tmp1 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp1);
+	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_condition), VALA_CODE_NODE (self));
 }
 
 
-ValaBlock* vala_while_statement_get_body (ValaWhileStatement* self)
-{
+ValaBlock* vala_while_statement_get_body (ValaWhileStatement* self) {
 	g_return_val_if_fail (VALA_IS_WHILE_STATEMENT (self), NULL);
 	return self->priv->_body;
 }
 
 
-void vala_while_statement_set_body (ValaWhileStatement* self, ValaBlock* value)
-{
+void vala_while_statement_set_body (ValaWhileStatement* self, ValaBlock* value) {
 	ValaBlock* _tmp2;
 	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_WHILE_STATEMENT (self));
@@ -135,8 +129,7 @@ void vala_while_statement_set_body (ValaWhileStatement* self, ValaBlock* value)
 }
 
 
-static void vala_while_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_while_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaWhileStatement * self;
 	self = VALA_WHILE_STATEMENT (object);
 	switch (property_id) {
@@ -153,8 +146,7 @@ static void vala_while_statement_get_property (GObject * object, guint property_
 }
 
 
-static void vala_while_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_while_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaWhileStatement * self;
 	self = VALA_WHILE_STATEMENT (object);
 	switch (property_id) {
@@ -171,48 +163,39 @@ static void vala_while_statement_set_property (GObject * object, guint property_
 }
 
 
-static void vala_while_statement_class_init (ValaWhileStatementClass * klass)
-{
+static void vala_while_statement_class_init (ValaWhileStatementClass * klass) {
 	vala_while_statement_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaWhileStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_while_statement_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_while_statement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_while_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_while_statement_real_accept;
-	VALA_CODE_NODE_CLASS (klass)->replace = vala_while_statement_real_replace;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_WHILE_STATEMENT_CONDITION, g_param_spec_object ("condition", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_WHILE_STATEMENT_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_while_statement_real_replace_expression;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_WHILE_STATEMENT_CONDITION, g_param_spec_object ("condition", "condition", "condition", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_WHILE_STATEMENT_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_while_statement_vala_statement_interface_init (ValaStatementIface * iface)
-{
+static void vala_while_statement_vala_statement_interface_init (ValaStatementIface * iface) {
 	vala_while_statement_vala_statement_parent_iface = g_type_interface_peek_parent (iface);
 }
 
 
-static void vala_while_statement_init (ValaWhileStatement * self)
-{
+static void vala_while_statement_init (ValaWhileStatement * self) {
 	self->priv = VALA_WHILE_STATEMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_while_statement_dispose (GObject * obj)
-{
+static void vala_while_statement_dispose (GObject * obj) {
 	ValaWhileStatement * self;
-	ValaWhileStatementClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_WHILE_STATEMENT (obj);
 	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	klass = VALA_WHILE_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_WHILE_STATEMENT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_while_statement_parent_class)->dispose (obj);
 }
 
 
-GType vala_while_statement_get_type (void)
-{
+GType vala_while_statement_get_type (void) {
 	static GType vala_while_statement_type_id = 0;
 	if (G_UNLIKELY (vala_while_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaWhileStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_while_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaWhileStatement), 0, (GInstanceInitFunc) vala_while_statement_init };
