@@ -1,11 +1,11 @@
 /* valawhilestatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,13 +20,13 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAWHILESTATEMENT_H__
-#define __VALAWHILESTATEMENT_H__
+#ifndef __VALA_VALAWHILESTATEMENT_H__
+#define __VALA_VALAWHILESTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
-#include <vala/valastatement.h>
 #include <vala/valacodenode.h>
+#include <vala/valastatement.h>
 
 G_BEGIN_DECLS
 
@@ -44,19 +44,19 @@ typedef struct _ValaWhileStatementPrivate ValaWhileStatementPrivate;
  * Represents a while iteration statement in the source code.
  */
 struct _ValaWhileStatement {
-	ValaStatement parent;
+	ValaCodeNode parent_instance;
 	ValaWhileStatementPrivate * priv;
 };
 struct _ValaWhileStatementClass {
-	ValaStatementClass parent;
+	ValaCodeNodeClass parent_class;
 };
 
-ValaWhileStatement* vala_while_statement_new (ValaExpression* cond, ValaStatement* _body, ValaSourceReference* source);
+ValaWhileStatement* vala_while_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference);
 ValaExpression* vala_while_statement_get_condition (ValaWhileStatement* self);
 void vala_while_statement_set_condition (ValaWhileStatement* self, ValaExpression* value);
-ValaStatement* vala_while_statement_get_body (ValaWhileStatement* self);
-void vala_while_statement_set_body (ValaWhileStatement* self, ValaStatement* value);
-GType vala_while_statement_get_type ();
+ValaBlock* vala_while_statement_get_body (ValaWhileStatement* self);
+void vala_while_statement_set_body (ValaWhileStatement* self, ValaBlock* value);
+GType vala_while_statement_get_type (void);
 
 G_END_DECLS
 
