@@ -1,11 +1,11 @@
 /* valavapigen.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valavapigen.h"
+#include <vapigen/valavapigen.h>
 #include <stdlib.h>
 #include <string.h>
 #include <vala/valacodecontext.h>
@@ -34,7 +34,7 @@
 #include <vala/valasymbolresolver.h>
 #include <vala/valainterfacewriter.h>
 #include <config.h>
-#include "valagidlparser.h"
+#include "vapigen/valagidlparser.h"
 
 typedef struct _ValaVAPIGen ValaVAPIGen;
 typedef struct _ValaVAPIGenClass ValaVAPIGenClass;
@@ -48,11 +48,11 @@ typedef struct _ValaVAPIGenPrivate ValaVAPIGenPrivate;
 #define VALA_VAPI_GEN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VAPI_GEN, ValaVAPIGenClass))
 
 struct _ValaVAPIGen {
-	GObject parent;
+	GObject parent_instance;
 	ValaVAPIGenPrivate * priv;
 };
 struct _ValaVAPIGenClass {
-	GObjectClass parent;
+	GObjectClass parent_class;
 };
 struct _ValaVAPIGenPrivate {
 	ValaCodeContext* context;
@@ -74,14 +74,14 @@ static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg);
 static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, int* result_length1);
 static gint vala_vapi_gen_run (ValaVAPIGen* self);
 static gint vala_vapi_gen_main (int args_length1, char** args);
+static ValaVAPIGen* vala_vapi_gen_new (void);
 static gpointer vala_vapi_gen_parent_class = NULL;
 static void vala_vapi_gen_dispose (GObject * obj);
 static GType vala_vapi_gen_get_type (void);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
-static gint vala_vapi_gen_quit (ValaVAPIGen* self)
-{
+static gint vala_vapi_gen_quit (ValaVAPIGen* self) {
 	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), 0);
 	if (vala_report_get_errors () == 0) {
 		fprintf (stdout, "Generation succeeded - %d warning(s)\n", vala_report_get_warnings ());
@@ -93,15 +93,13 @@ static gint vala_vapi_gen_quit (ValaVAPIGen* self)
 }
 
 
-static char* vala_vapi_gen_get_package_path (ValaVAPIGen* self, const char* pkg)
-{
+static char* vala_vapi_gen_get_package_path (ValaVAPIGen* self, const char* pkg) {
 	char* basename;
 	char* filename;
 	char* _tmp3;
 	gpointer _tmp5;
 	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), NULL);
-	g_return_val_if_fail (pkg != NULL, NULL);
-	basename = g_strdup_printf ("%s.vala", pkg);
+	basename = g_strdup_printf ("%s.vapi", pkg);
 	if (vala_vapi_gen_vapi_directories != NULL) {
 		{
 			char** vapidir_collection;
@@ -142,18 +140,14 @@ static char* vala_vapi_gen_get_package_path (ValaVAPIGen* self, const char* pkg)
 		return (_tmp4 = filename, (basename = (g_free (basename), NULL)), _tmp4);
 	}
 	return (_tmp5 = NULL, (basename = (g_free (basename), NULL)), (filename = (g_free (filename), NULL)), _tmp5);
-	(basename = (g_free (basename), NULL));
-	(filename = (g_free (filename), NULL));
 }
 
 
-static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg)
-{
+static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg) {
 	char* package_path;
 	ValaSourceFile* _tmp2;
 	gboolean _tmp3;
 	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), FALSE);
-	g_return_val_if_fail (pkg != NULL, FALSE);
 	if (vala_code_context_has_package (self->priv->context, pkg)) {
 		return TRUE;
 	}
@@ -167,32 +161,31 @@ static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg)
 	vala_code_context_add_source_file (self->priv->context, (_tmp2 = vala_source_file_new (self->priv->context, package_path, TRUE)));
 	(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
 	return (_tmp3 = TRUE, (package_path = (g_free (package_path), NULL)), _tmp3);
-	(package_path = (g_free (package_path), NULL));
 }
 
 
-static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, int* result_length1)
-{
+static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, int* result_length1) {
 	GError * inner_error;
 	char* contents;
-	gpointer _tmp2;
-	gpointer _tmp3;
+	gboolean _tmp1;
+	char* _tmp0;
+	gpointer _tmp4;
+	gpointer _tmp5;
 	inner_error = NULL;
 	contents = NULL;
-	if (g_file_get_contents (depsfile, &contents, NULL, &inner_error)) {
-		char** _tmp0;
-		char** _tmp1;
-		_tmp0 = NULL;
-		_tmp1 = NULL;
-		return (_tmp1 = (_tmp0 = g_strsplit (g_strstrip (contents), "\n", 0), *result_length1 = -1, _tmp0), (contents = (g_free (contents), NULL)), _tmp1);
+	_tmp0 = NULL;
+	if ((_tmp1 = g_file_get_contents (depsfile, &_tmp0, NULL, &inner_error), (contents = (g_free (contents), NULL)), contents = _tmp0, _tmp1)) {
+		char** _tmp2;
+		char** _tmp3;
+		_tmp2 = NULL;
+		_tmp3 = NULL;
+		return (_tmp3 = (_tmp2 = g_strsplit (g_strstrip (contents), "\n", 0), *result_length1 = -1, _tmp2), (contents = (g_free (contents), NULL)), _tmp3);
 	}
-	return (_tmp3 = (_tmp2 = NULL, *result_length1 = -1, _tmp2), (contents = (g_free (contents), NULL)), _tmp3);
-	(contents = (g_free (contents), NULL));
+	return (_tmp5 = (_tmp4 = NULL, *result_length1 = -1, _tmp4), (contents = (g_free (contents), NULL)), _tmp5);
 }
 
 
-static gint vala_vapi_gen_run (ValaVAPIGen* self)
-{
+static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 	ValaCodeContext* _tmp0;
 	char** _tmp16;
 	ValaParser* parser;
@@ -202,7 +195,7 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self)
 	gint _tmp24;
 	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), 0);
 	_tmp0 = NULL;
-	self->priv->context = (_tmp0 = g_object_new (VALA_TYPE_CODE_CONTEXT, NULL), (self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL))), _tmp0);
+	self->priv->context = (_tmp0 = vala_code_context_new (), (self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL))), _tmp0);
 	/* default package */
 	if (!vala_vapi_gen_add_package (self, "glib-2.0")) {
 		vala_report_error (NULL, "glib-2.0 not found in specified Vala API directories");
@@ -228,14 +221,14 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self)
 				gint _tmp4;
 				char** deps;
 				/* load packages from .deps file */
-				if (!g_str_has_suffix (source, ".gidl")) {
+				if (!g_str_has_suffix (source, ".gi")) {
 					(source = (g_free (source), NULL));
 					continue;
 				}
 				_tmp2 = NULL;
 				_tmp1 = NULL;
 				_tmp3 = NULL;
-				depsfile = (_tmp3 = g_strconcat ((_tmp2 = g_utf8_offset_to_pointer (source, 0), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (source, -1) - 4) - _tmp2)), "deps", NULL), (_tmp1 = (g_free (_tmp1), NULL)), _tmp3);
+				depsfile = (_tmp3 = g_strconcat ((_tmp2 = g_utf8_offset_to_pointer (source, 0), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (source, -1) - g_utf8_strlen ("gi", -1)) - _tmp2)), "deps", NULL), (_tmp1 = (g_free (_tmp1), NULL)), _tmp3);
 				if (!g_file_test (depsfile, G_FILE_TEST_EXISTS)) {
 					(source = (g_free (source), NULL));
 					(depsfile = (g_free (depsfile), NULL));
@@ -331,25 +324,25 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self)
 	if (vala_report_get_errors () > 0) {
 		return vala_vapi_gen_quit (self);
 	}
-	parser = g_object_new (VALA_TYPE_PARSER, NULL);
+	parser = vala_parser_new ();
 	vala_parser_parse (parser, self->priv->context);
 	if (vala_report_get_errors () > 0) {
 		gint _tmp18;
 		return (_tmp18 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), _tmp18);
 	}
-	attributeprocessor = g_object_new (VALA_TYPE_ATTRIBUTE_PROCESSOR, NULL);
+	attributeprocessor = vala_attribute_processor_new ();
 	vala_attribute_processor_process (attributeprocessor, self->priv->context);
 	if (vala_report_get_errors () > 0) {
 		gint _tmp19;
 		return (_tmp19 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), _tmp19);
 	}
-	gidlparser = g_object_new (VALA_TYPE_GIDL_PARSER, NULL);
+	gidlparser = vala_gidl_parser_new ();
 	vala_gidl_parser_parse (gidlparser, self->priv->context);
 	if (vala_report_get_errors () > 0) {
 		gint _tmp20;
 		return (_tmp20 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL))), _tmp20);
 	}
-	resolver = g_object_new (VALA_TYPE_SYMBOL_RESOLVER, NULL);
+	resolver = vala_symbol_resolver_new ();
 	vala_symbol_resolver_resolve (resolver, self->priv->context);
 	if (vala_report_get_errors () > 0) {
 		gint _tmp21;
@@ -359,24 +352,19 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self)
 		ValaInterfaceWriter* interface_writer;
 		char* _tmp22;
 		char* _tmp23;
-		interface_writer = g_object_new (VALA_TYPE_INTERFACE_WRITER, NULL);
+		interface_writer = vala_interface_writer_new ();
 		_tmp22 = NULL;
-		vala_interface_writer_write_file (interface_writer, self->priv->context, (_tmp22 = g_strdup_printf ("%s.vala", vala_vapi_gen_library)));
+		vala_interface_writer_write_file (interface_writer, self->priv->context, (_tmp22 = g_strdup_printf ("%s.vapi", vala_vapi_gen_library)));
 		(_tmp22 = (g_free (_tmp22), NULL));
 		_tmp23 = NULL;
 		vala_vapi_gen_library = (_tmp23 = NULL, (vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL)), _tmp23);
 		(interface_writer == NULL ? NULL : (interface_writer = (g_object_unref (interface_writer), NULL)));
 	}
 	return (_tmp24 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL))), (resolver == NULL ? NULL : (resolver = (g_object_unref (resolver), NULL))), _tmp24);
-	(parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL)));
-	(attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL)));
-	(gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL)));
-	(resolver == NULL ? NULL : (resolver = (g_object_unref (resolver), NULL)));
 }
 
 
-static gint vala_vapi_gen_main (int args_length1, char** args)
-{
+static gint vala_vapi_gen_main (int args_length1, char** args) {
 	GError * inner_error;
 	ValaVAPIGen* vapigen;
 	gint _tmp3;
@@ -418,48 +406,45 @@ static gint vala_vapi_gen_main (int args_length1, char** args)
 		fprintf (stderr, "No source file specified.\n");
 		return 1;
 	}
-	vapigen = g_object_new (VALA_TYPE_VAPI_GEN, NULL);
+	vapigen = vala_vapi_gen_new ();
 	return (_tmp3 = vala_vapi_gen_run (vapigen), (vapigen == NULL ? NULL : (vapigen = (g_object_unref (vapigen), NULL))), _tmp3);
-	(vapigen == NULL ? NULL : (vapigen = (g_object_unref (vapigen), NULL)));
 }
 
 
-int main (int argc, char ** argv)
-{
+int main (int argc, char ** argv) {
 	g_type_init ();
 	return vala_vapi_gen_main (argc, argv);
 }
 
 
-static void vala_vapi_gen_class_init (ValaVAPIGenClass * klass)
-{
+static ValaVAPIGen* vala_vapi_gen_new (void) {
+	ValaVAPIGen * self;
+	self = g_object_newv (VALA_TYPE_VAPI_GEN, 0, NULL);
+	return self;
+}
+
+
+static void vala_vapi_gen_class_init (ValaVAPIGenClass * klass) {
 	vala_vapi_gen_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaVAPIGenPrivate));
 	G_OBJECT_CLASS (klass)->dispose = vala_vapi_gen_dispose;
 }
 
 
-static void vala_vapi_gen_init (ValaVAPIGen * self)
-{
+static void vala_vapi_gen_init (ValaVAPIGen * self) {
 	self->priv = VALA_VAPI_GEN_GET_PRIVATE (self);
 }
 
 
-static void vala_vapi_gen_dispose (GObject * obj)
-{
+static void vala_vapi_gen_dispose (GObject * obj) {
 	ValaVAPIGen * self;
-	ValaVAPIGenClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_VAPI_GEN (obj);
 	(self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL)));
-	klass = VALA_VAPI_GEN_CLASS (g_type_class_peek (VALA_TYPE_VAPI_GEN));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_vapi_gen_parent_class)->dispose (obj);
 }
 
 
-static GType vala_vapi_gen_get_type (void)
-{
+static GType vala_vapi_gen_get_type (void) {
 	static GType vala_vapi_gen_type_id = 0;
 	if (G_UNLIKELY (vala_vapi_gen_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPIGenClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_gen_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPIGen), 0, (GInstanceInitFunc) vala_vapi_gen_init };
@@ -469,8 +454,7 @@ static GType vala_vapi_gen_get_type (void)
 }
 
 
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func)
-{
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if (array != NULL && destroy_func != NULL) {
 		int i;
 		if (array_length >= 0)
