@@ -1,11 +1,11 @@
 /* valavapigen.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAVAPIGEN_H__
-#define __VALAVAPIGEN_H__
+#ifndef __VAPIGEN_VALAVAPIGEN_H__
+#define __VAPIGEN_VALAVAPIGEN_H__
 
 #include <glib.h>
 #include <glib-object.h>
